/**
 * Application Migration API
 * Application Migration simplifies the migration of applications from Oracle Cloud Infrastructure Classic to Oracle Cloud Infrastructure.
You can use Application Migration API to migrate applications, such as Oracle Java Cloud Service, SOA Cloud Service, and Integration Classic
instances, to Oracle Cloud Infrastructure. For more information, see
[Overview of Application Migration](/iaas/application-migration/appmigrationoverview.htm).

 * OpenAPI spec version: 20191031
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { ApplicationMigrationWaiter } from "./applicationmigration-waiter";
export declare enum ApplicationMigrationApiKeys {
}
export declare class ApplicationMigrationClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ApplicationMigrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ApplicationMigrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ApplicationMigrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ApplicationMigrationWaiter;
    /**
       * Cancels the specified work request. When you cancel a work request, it causes the in-progress task to be canceled.
  * For example, if the create migration work request is in the accepted or in progress state for a long time, you can cancel the work request.
  * <p>
  When you cancel a work request, the state of the work request changes to cancelling, and then to the cancelled state.
  *
       * @param CancelWorkRequestRequest
       * @return CancelWorkRequestResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
       */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves the specified migration into a different compartment within the same tenancy. For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * @param ChangeMigrationCompartmentRequest
     * @return ChangeMigrationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ChangeMigrationCompartment.ts.html |here} to see how to use ChangeMigrationCompartment API.
     */
    changeMigrationCompartment(changeMigrationCompartmentRequest: requests.ChangeMigrationCompartmentRequest): Promise<responses.ChangeMigrationCompartmentResponse>;
    /**
     * Moves the specified source into a different compartment within the same tenancy. For information about moving resources
     * between compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * @param ChangeSourceCompartmentRequest
     * @return ChangeSourceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ChangeSourceCompartment.ts.html |here} to see how to use ChangeSourceCompartment API.
     */
    changeSourceCompartment(changeSourceCompartmentRequest: requests.ChangeSourceCompartmentRequest): Promise<responses.ChangeSourceCompartmentResponse>;
    /**
       * Creates a migration. A migration represents the end-to-end workflow of moving an application from a source environment to Oracle Cloud
  * Infrastructure. Each migration moves a single application to Oracle Cloud Infrastructure. For more information,
  * see [Manage Migrations](https://docs.cloud.oracle.com/iaas/application-migration/manage_migrations.htm).
  * <p>
  When you create a migration, provide the required information to let Application Migration access the source environment.
  * Application Migration uses this information to access the application in the source environment and discover application artifacts.
  * <p>
  All Oracle Cloud Infrastructure resources, including migrations, get an Oracle-assigned, unique ID called an Oracle Cloud Identifier (OCID).
  * When you create a resource, you can find its OCID in the response. You can also retrieve a resource's OCID by using a List API operation on
  * that resource type, or by viewing the resource in the Console. For more information, see Resource Identifiers.
  * <p>
  After you send your request, a migration is created in the compartment that contains the source. The new migration's lifecycle state
  * will temporarily be <code>CREATING</code> and the state of the migration will be <code>DISCOVERING_APPLICATION</code>. During this phase,
  * Application Migration sets the template for the <code>serviceConfig</code> and <code>applicationConfig</code> fields of the migration.
  * When this operation is complete, the state of the migration changes to <code>MISSING_CONFIG_VALUES</code>.
  * Next, you'll need to update the migration to provide configuration values. Before updating the
  * migration, ensure that its state has changed to <code>MISSING_CONFIG_VALUES</code>.
  * <p>
  To track the progress of this operation, you can monitor the status of the Create Migration and Discover Application work requests
  * by using the <code>{@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest}</code> REST API operation on the work request or by viewing the status of the work request in
  * the console.
  *
       * @param CreateMigrationRequest
       * @return CreateMigrationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/CreateMigration.ts.html |here} to see how to use CreateMigration API.
       */
    createMigration(createMigrationRequest: requests.CreateMigrationRequest): Promise<responses.CreateMigrationResponse>;
    /**
       * Creates a source in the specified compartment. In Application Migration, a source refers to the environment from which the application
  * is being migrated. For more information, see [Manage Sources](https://docs.cloud.oracle.com/iaas/application-migration/manage_sources.htm).
  * <p>
  All Oracle Cloud Infrastructure resources, including sources, get an Oracle-assigned, unique ID called an Oracle Cloud Identifier (OCID).
  * When you create a resource, you can find its OCID in the response. You can also retrieve a resource's OCID by using a List API operation
  * on that resource type, or by viewing the resource in the Console.
  * <p>
  After you send your request, a source is created in the specified compartment. The new source's lifecycle state will temporarily be
  * <code>CREATING</code>. Application Migration connects to the source environment with the authentication credentials that you have provided.
  * If the connection is established, the status of the source changes to <code>ACTIVE</code> and Application Migration fetches the list of
  * applications that are available for migration in the source environment.
  * <p>
  To track the progress of the operation, you can monitor the status of the Create Source work request by using the
  * <code>{@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest}</code> REST API operation on the work request or by viewing the status of the work request in the console.
  * <p>
  Ensure that the state of the source has changed to <code>ACTIVE</code>, before you retrieve the list of applications from
  * the source environment using the <code>{@link #listSourceApplications(ListSourceApplicationsRequest) listSourceApplications}</code> REST API call.
  *
       * @param CreateSourceRequest
       * @return CreateSourceResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/CreateSource.ts.html |here} to see how to use CreateSource API.
       */
    createSource(createSourceRequest: requests.CreateSourceRequest): Promise<responses.CreateSourceResponse>;
    /**
       * Deletes the specified migration.
  * <p>
  If you have migrated the application or for any other reason if you no longer require a migration, then you can delete the
  * relevant migration. You can delete a migration, irrespective of its state. If any work request is being processed for the migration
  * that you want to delete, then the associated work requests are cancelled and then the migration is deleted.
  *
       * @param DeleteMigrationRequest
       * @return DeleteMigrationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/DeleteMigration.ts.html |here} to see how to use DeleteMigration API.
       */
    deleteMigration(deleteMigrationRequest: requests.DeleteMigrationRequest): Promise<responses.DeleteMigrationResponse>;
    /**
       * Deletes the specified source.
  * <p>
  Before deleting a source, you must delete all the migrations associated with the source.
  * If you have migrated all the required applications in a source or for any other reason you no longer require a source, then you can
  * delete the relevant source.
  *
       * @param DeleteSourceRequest
       * @return DeleteSourceResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/DeleteSource.ts.html |here} to see how to use DeleteSource API.
       */
    deleteSource(deleteSourceRequest: requests.DeleteSourceRequest): Promise<responses.DeleteSourceResponse>;
    /**
     * Retrieves details of the specified migration.
     * @param GetMigrationRequest
     * @return GetMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/GetMigration.ts.html |here} to see how to use GetMigration API.
     */
    getMigration(getMigrationRequest: requests.GetMigrationRequest): Promise<responses.GetMigrationResponse>;
    /**
     * Retrieves details of the specified source. Specify the OCID of the source for which you want to retrieve details.
     *
     * @param GetSourceRequest
     * @return GetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/GetSource.ts.html |here} to see how to use GetSource API.
     */
    getSource(getSourceRequest: requests.GetSourceRequest): Promise<responses.GetSourceResponse>;
    /**
     * Gets the details of the specified work request.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieves details of all the migrations that are available in the specified compartment.
     *
     * @param ListMigrationsRequest
     * @return ListMigrationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListMigrations.ts.html |here} to see how to use ListMigrations API.
     */
    listMigrations(listMigrationsRequest: requests.ListMigrationsRequest): Promise<responses.ListMigrationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.MigrationSummary objects
     * contained in responses from the listMigrations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMigrations(request: requests.ListMigrationsRequest): AsyncIterableIterator<models.MigrationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMigrations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMigrationsResponses(request: requests.ListMigrationsRequest): AsyncIterableIterator<responses.ListMigrationsResponse>;
    /**
     * Retrieves details of all the applications associated with the specified source.
     * This list is generated dynamically by interrogating the source and the list changes as applications are started or
     * stopped in the source environment.
     *
     * @param ListSourceApplicationsRequest
     * @return ListSourceApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListSourceApplications.ts.html |here} to see how to use ListSourceApplications API.
     */
    listSourceApplications(listSourceApplicationsRequest: requests.ListSourceApplicationsRequest): Promise<responses.ListSourceApplicationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SourceApplicationSummary objects
     * contained in responses from the listSourceApplications operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourceApplications(request: requests.ListSourceApplicationsRequest): AsyncIterableIterator<models.SourceApplicationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSourceApplications operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourceApplicationsResponses(request: requests.ListSourceApplicationsRequest): AsyncIterableIterator<responses.ListSourceApplicationsResponse>;
    /**
     * Retrieves details of all the sources that are available in the specified compartment and match the specified query criteria.
     * If you don't specify any query criteria, then details of all the sources are displayed.
     * To filter the retrieved results, you can pass one or more of the following query parameters, by appending them to the URI
     * as shown in the following example.
     *
     * @param ListSourcesRequest
     * @return ListSourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListSources.ts.html |here} to see how to use ListSources API.
     */
    listSources(listSourcesRequest: requests.ListSourcesRequest): Promise<responses.ListSourcesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SourceSummary objects
     * contained in responses from the listSources operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSources(request: requests.ListSourcesRequest): AsyncIterableIterator<models.SourceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSources operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourcesResponses(request: requests.ListSourcesRequest): AsyncIterableIterator<responses.ListSourcesResponse>;
    /**
     * Retrieves details of the errors encountered while executing an operation that is tracked by the specified work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieves logs for the specified work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Retrieves details of all the work requests and match the specified query criteria. To filter the retrieved results, you can pass one or more of the following query parameters, by appending them to the URI as shown in the following example.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
       * Starts migrating the specified application to Oracle Cloud Infrastructure.
  * <p>
  Before sending this request, ensure that you have provided configuration details to update the migration and the state of the migration
  * is <code>READY</code>.
  * <p>
  After you send this request, the migration's state will temporarily be <code>MIGRATING</code>.
  * <p>
  To track the progress of the operation, you can monitor the status of the Migrate Application work request by using the
  * <code>{@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest}</code> REST API operation on the work request or by viewing the status of the work request in the console.
  * When this work request is processed successfully, Application Migration creates the required resources in the target environment
  * and the state of the migration changes to <code>MIGRATION_SUCCEEDED</code>.
  *
       * @param MigrateApplicationRequest
       * @return MigrateApplicationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/MigrateApplication.ts.html |here} to see how to use MigrateApplication API.
       */
    migrateApplication(migrateApplicationRequest: requests.MigrateApplicationRequest): Promise<responses.MigrateApplicationResponse>;
    /**
       * Updates the configuration details for the specified migration.
  * <p>
  When you create a migration, Application Migration sets the template for the <code>serviceConfig</code> and <code>applicationConfig</code>
  * attributes of the migration.
  * When you update the migration, you must provide values for these fields to specify configuration information for the application in the
  * target environment.
  * <p>
  
  * <p>
  Before updating the migration, complete the following tasks:
  * <ol>
  * <li>Identify the migration that you want to update and ensure that the migration is in the <code>MISSING_CONFIG_VALUES</code> state.</li>
  * <li>Get details of the migration using the <code>GetMigration</code> command. This returns the  template for the <code>serviceConfig</code>
  * and <code>applicationConfig</code> attributes of the migration.</li>
  * <li>You must fill out the required details for the <code>serviceConfig</code> and <code>applicationConfig</code> attributes.
  * The <code>isRequired</code> attribute of a configuration property indicates whether it is mandatory to provide a value.</li>
  * <li>You can provide values for the optional configuration properties or you can delete the optional properties for which you do not
  * provide values. Note that you cannot add any property that is not present in the template.</li>
  * </ol>
  * <p>
  To update the migration, pass the configuration values in the request body. The information that you must provide depends on the type
  * of application that you are migrating. For reference information about configuration fields, see
  * [Provide Configuration Information](https://docs.cloud.oracle.com/iaas/application-migration/manage_migrations.htm#provide_configuration_details).
  * <p>
  To track the progress of the operation, you can monitor the status of the Update Migration work request by using the
  * <code>{@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest}</code> REST API operation on the work request or by viewing the status of the work request in the console.
  * <p>
  When the migration has been updated, the state of the migration changes to <code>READY</code>. After updating the migration,
  * you can start the migration whenever you are ready.
  *
       * @param UpdateMigrationRequest
       * @return UpdateMigrationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/UpdateMigration.ts.html |here} to see how to use UpdateMigration API.
       */
    updateMigration(updateMigrationRequest: requests.UpdateMigrationRequest): Promise<responses.UpdateMigrationResponse>;
    /**
     * You can update the authorization details to access the source environment from which you want to migrate applications to Oracle Cloud
     * Infrastructure. You can also update the description and tags of a source.
     * <p>
     **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
     *
     * @param UpdateSourceRequest
     * @return UpdateSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/applicationmigration/UpdateSource.ts.html |here} to see how to use UpdateSource API.
     */
    updateSource(updateSourceRequest: requests.UpdateSourceRequest): Promise<responses.UpdateSourceResponse>;
}
