/**
 * Support Management API
 * Use the Support Management API to manage support requests. For more information, see [Getting Help and Contacting Support](/iaas/Content/GSG/Tasks/contactingsupport.htm). **Note**: Before you can create service requests with this API, you need to have an Oracle Single Sign On (SSO) account, and you need to register your Customer Support Identifier (CSI) with My Oracle Support.
 * OpenAPI spec version: 20181231
 * Contact: oci_ops_cims_dev_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
export declare enum IncidentApiKeys {
}
export declare class IncidentClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Enables the customer to create an support ticket.
     * @param CreateIncidentRequest
     * @return CreateIncidentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/CreateIncident.ts.html |here} to see how to use CreateIncident API.
     */
    createIncident(createIncidentRequest: requests.CreateIncidentRequest): Promise<responses.CreateIncidentResponse>;
    /**
     * Gets the details of the support ticket.
     * @param GetIncidentRequest
     * @return GetIncidentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/GetIncident.ts.html |here} to see how to use GetIncident API.
     */
    getIncident(getIncidentRequest: requests.GetIncidentRequest): Promise<responses.GetIncidentResponse>;
    /**
     * Gets the status of the service.
     * @param GetStatusRequest
     * @return GetStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/GetStatus.ts.html |here} to see how to use GetStatus API.
     */
    getStatus(getStatusRequest: requests.GetStatusRequest): Promise<responses.GetStatusResponse>;
    /**
     * During support ticket creation, returns the list of all possible products that Oracle Cloud Infrastructure supports.
     * @param ListIncidentResourceTypesRequest
     * @return ListIncidentResourceTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/ListIncidentResourceTypes.ts.html |here} to see how to use ListIncidentResourceTypes API.
     */
    listIncidentResourceTypes(listIncidentResourceTypesRequest: requests.ListIncidentResourceTypesRequest): Promise<responses.ListIncidentResourceTypesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.IncidentResourceType objects
     * contained in responses from the listIncidentResourceTypes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIncidentResourceTypes(request: requests.ListIncidentResourceTypesRequest): AsyncIterableIterator<models.IncidentResourceType>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIncidentResourceTypes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIncidentResourceTypesResponses(request: requests.ListIncidentResourceTypesRequest): AsyncIterableIterator<responses.ListIncidentResourceTypesResponse>;
    /**
     * Returns the list of support tickets raised by the tenancy.
     * @param ListIncidentsRequest
     * @return ListIncidentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/ListIncidents.ts.html |here} to see how to use ListIncidents API.
     */
    listIncidents(listIncidentsRequest: requests.ListIncidentsRequest): Promise<responses.ListIncidentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.IncidentSummary objects
     * contained in responses from the listIncidents operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIncidents(request: requests.ListIncidentsRequest): AsyncIterableIterator<models.IncidentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIncidents operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIncidentsResponses(request: requests.ListIncidentsRequest): AsyncIterableIterator<responses.ListIncidentsResponse>;
    /**
     * Updates the specified support ticket's information.
     * @param UpdateIncidentRequest
     * @return UpdateIncidentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/UpdateIncident.ts.html |here} to see how to use UpdateIncident API.
     */
    updateIncident(updateIncidentRequest: requests.UpdateIncidentRequest): Promise<responses.UpdateIncidentResponse>;
    /**
     * Checks whether the requested user is valid.
     * @param ValidateUserRequest
     * @return ValidateUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/ValidateUser.ts.html |here} to see how to use ValidateUser API.
     */
    validateUser(validateUserRequest: requests.ValidateUserRequest): Promise<responses.ValidateUserResponse>;
}
export declare enum UserApiKeys {
}
export declare class UserClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Create user to request Customer Support Identifier(CSI) to Customer User Administrator(CUA).
     * @param CreateUserRequest
     * @return CreateUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/cims/CreateUser.ts.html |here} to see how to use CreateUser API.
     */
    createUser(createUserRequest: requests.CreateUserRequest): Promise<responses.CreateUserResponse>;
}
