"use strict";
/**
 * Copyright (c) 2020, 2021 Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Realm = void 0;
class Realm {
    constructor(realmId, secondLevelDomain) {
        this._secondLevelDomain = secondLevelDomain;
        this._realmId = realmId;
        Realm.KNOWN_REALMS.set(realmId, this);
    }
    get secondLevelDomain() {
        return this._secondLevelDomain;
    }
    get realmId() {
        return this._realmId;
    }
    static register(realmId, secondLevelDomain) {
        if (!realmId)
            throw Error("Realm Id can not be empty or undefined");
        if (!secondLevelDomain)
            throw Error("secondLevelDomain can not be empty or undefined");
        realmId = realmId.trim().toLocaleLowerCase("en-US");
        secondLevelDomain = secondLevelDomain.trim().toLocaleLowerCase("en-US");
        const realm = Realm.KNOWN_REALMS.get(realmId);
        if (realm) {
            if (realm.secondLevelDomain !== secondLevelDomain) {
                throw Error("RealmId " +
                    realmId +
                    " is already registered with  " +
                    realm.secondLevelDomain +
                    " It cannot be re-registered with a different secondLevelDomain");
            }
            return realm;
        }
        return new Realm(realmId, secondLevelDomain);
    }
}
exports.Realm = Realm;
Realm.KNOWN_REALMS = new Map();
Realm.OC1 = Realm.register("oc1", "oraclecloud.com");
Realm.OC2 = Realm.register("oc2", "oraclegovcloud.com");
Realm.OC3 = Realm.register("oc3", "oraclegovcloud.com");
Realm.OC4 = Realm.register("oc4", "oraclegovcloud.uk");
Realm.OC8 = Realm.register("oc8", "oraclecloud8.com");
//# sourceMappingURL=realm.js.map