/**
 * Oracle Cloud Agent API
 * API for the Oracle Cloud Agent software running on compute instances. Oracle Cloud Agent
is a lightweight process that monitors and manages compute instances.

 * OpenAPI spec version: 20180530
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A command's execution summary.
 */
export interface InstanceAgentCommandExecution {
    /**
     * The OCID of the command
     */
    "instanceAgentCommandId": string;
    /**
     * The OCID of the instance
     */
    "instanceId": string;
    /**
     * Specifies the command delivery state.
     *  * `VISIBLE` - The command is visible to instance.
     *  * `PENDING` - The command is pending ack from the instance.
     *  * `ACKED` - The command has been received and acked by the instance.
     *  * `ACKED_CANCELED` - The canceled command has been received and acked by the instance.
     *  * `EXPIRED` - The instance has not requested for commands and its delivery has expired.
     *
     */
    "deliveryState": InstanceAgentCommandExecution.DeliveryState;
    /**
     * command execution life cycle state.
     * * `ACCEPTED` - The command execution has been accepted to run.
     * * `IN_PROGRESS` - The command execution is in progress.
     * * `SUCCEEDED` - The command execution is successful.
     * * `FAILED` - The command execution has failed.
     * * `TIMED_OUT` - The command execution has timedout.
     * * `CANCELED` - The command execution has canceled.
     *
     */
    "lifecycleState": InstanceAgentCommandExecution.LifecycleState;
    /**
     * The command creation date
     */
    "timeCreated": Date;
    /**
     * The command last updated at date.
     */
    "timeUpdated": Date;
    /**
     * The large non-consecutive number that Run Command Service assigns to each created command. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sequenceNumber": number;
    /**
     * The user friendly display name of the command.
     */
    "displayName"?: string;
    "content": model.InstanceAgentCommandExecutionOutputViaTextDetails | model.InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails | model.InstanceAgentCommandExecutionOutputViaObjectStorageTupleDetails;
}
export declare namespace InstanceAgentCommandExecution {
    enum DeliveryState {
        Visible = "VISIBLE",
        Pending = "PENDING",
        Acked = "ACKED",
        AckedCanceled = "ACKED_CANCELED",
        Expired = "EXPIRED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Succeeded = "SUCCEEDED",
        Failed = "FAILED",
        TimedOut = "TIMED_OUT",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: InstanceAgentCommandExecution): object;
}
