/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A link between a DRG and VCN. For more information, see
 * [Overview of the Networking Service](https://docs.cloud.oracle.com/Content/Network/Concepts/overview.htm).
 *
 */
export interface DrgAttachment {
    /**
     * The OCID of the compartment containing the DRG attachment.
     */
    "compartmentId": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
     * The OCID of the DRG.
     */
    "drgId": string;
    /**
     * The DRG attachment's Oracle ID (OCID).
     */
    "id": string;
    /**
     * The DRG attachment's current state.
     */
    "lifecycleState": DrgAttachment.LifecycleState;
    /**
      * The date and time the DRG attachment was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: `2016-08-25T21:10:29.600Z`
  *
      */
    "timeCreated"?: Date;
    /**
      * The OCID of the route table the DRG attachment is using.
  * <p>
  For information about why you would associate a route table with a DRG attachment, see:
  * <p>
    * [Transit Routing: Access to Multiple VCNs in Same Region](https://docs.cloud.oracle.com/Content/Network/Tasks/transitrouting.htm)
  *   * [Transit Routing: Private Access to Oracle Services](https://docs.cloud.oracle.com/Content/Network/Tasks/transitroutingoracleservices.htm)
  *
      */
    "routeTableId"?: string;
    /**
     * The OCID of the VCN.
     *
     */
    "vcnId": string;
}
export declare namespace DrgAttachment {
    enum LifecycleState {
        Attaching = "ATTACHING",
        Attached = "ATTACHED",
        Detaching = "DETACHING",
        Detached = "DETACHED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DrgAttachment): object;
}
