/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A compute instance shape that can be used in {@link #launchInstance(LaunchInstanceRequest) launchInstance}.
 * For more information, see [Overview of the Compute Service](https://docs.cloud.oracle.com/Content/Compute/Concepts/computeoverview.htm) and
 * [Compute Shapes](https://docs.cloud.oracle.com/Content/Compute/References/computeshapes.htm).
 *
 */
export interface Shape {
    /**
     * The name of the shape. You can enumerate all available shapes by calling
     * {@link #listShapes(ListShapesRequest) listShapes}.
     *
     */
    "shape": string;
    /**
     * A short description of the shape's processor (CPU).
     *
     */
    "processorDescription"?: string;
    /**
     * The default number of OCPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ocpus"?: number;
    /**
     * The default amount of memory available for this shape, in gigabytes.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memoryInGBs"?: number;
    /**
     * The networking bandwidth available for this shape, in gigabits per second.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "networkingBandwidthInGbps"?: number;
    /**
     * The maximum number of VNIC attachments available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxVnicAttachments"?: number;
    /**
     * The number of GPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "gpus"?: number;
    /**
      * A short description of the graphics processing unit (GPU) available for this shape.
  * <p>
  If the shape does not have any GPUs, this field is `null`.
  *
      */
    "gpuDescription"?: string;
    /**
     * The number of local disks available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "localDisks"?: number;
    /**
      * The aggregate size of the local disks available for this shape, in gigabytes.
  * <p>
  If the shape does not have any local disks, this field is `null`.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "localDisksTotalSizeInGBs"?: number;
    /**
      * A short description of the local disks available for this shape.
  * <p>
  If the shape does not have any local disks, this field is `null`.
  *
      */
    "localDiskDescription"?: string;
    "ocpuOptions"?: model.ShapeOcpuOptions;
    "memoryOptions"?: model.ShapeMemoryOptions;
    "networkingBandwidthOptions"?: model.ShapeNetworkingBandwidthOptions;
    "maxVnicAttachmentOptions"?: model.ShapeMaxVnicAttachmentOptions;
}
export declare namespace Shape {
    function getJsonObj(obj: Shape): object;
}
