/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
* A point-in-time copy of a volume group that can then be used to create a new volume group
* or restore a volume group. For more information, see [Volume Groups](https://docs.cloud.oracle.com/Content/Block/Concepts/volumegroups.htm).
* <p>
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
* talk to an administrator. If you're an administrator who needs to write policies to give users access, see
* [Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
* <p>
**Warning:** Oracle recommends that you avoid using any confidential information when you
* supply string values using the API.
*
*/
export interface VolumeGroupBackup {
    /**
     * The OCID of the compartment that contains the volume group backup.
     */
    "compartmentId": string;
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A user-friendly name for the volume group backup. Does not have
     * to be unique and it's changeable. Avoid entering confidential information.
     *
     */
    "displayName": string;
    /**
     * The date and time the volume group backup will expire and be automatically deleted.
     * Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). This parameter will always be present for volume group
     * backups that were created automatically by a scheduled-backup policy. For manually
     * created volume group backups, it will be absent, signifying that there is no expiration
     * time and the backup will last forever until manually deleted.
     *
     */
    "expirationTime"?: Date;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: `{\"Department\": \"Finance\"}`
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * The OCID of the volume group backup.
     */
    "id": string;
    /**
     * The current state of a volume group backup.
     */
    "lifecycleState": VolumeGroupBackup.LifecycleState;
    /**
     * The aggregate size of the volume group backup, in MBs.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sizeInMBs"?: number;
    /**
     * The aggregate size of the volume group backup, in GBs.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sizeInGBs"?: number;
    /**
     * Specifies whether the volume group backup was created manually, or via scheduled
     * backup policy.
     *
     */
    "sourceType"?: VolumeGroupBackup.SourceType;
    /**
     * The date and time the volume group backup was created. This is the time the actual point-in-time image
     * of the volume group data was taken. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeCreated": Date;
    /**
     * The date and time the request to create the volume group backup was received. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeRequestReceived"?: Date;
    /**
     * The type of backup.
     */
    "type": VolumeGroupBackup.Type;
    /**
      * The aggregate size used by the volume group backup, in MBs.
  * <p>
  It is typically smaller than sizeInMBs, depending on the spaceconsumed
  * on the volume group and whether the volume backup is full or incremental.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "uniqueSizeInMbs"?: number;
    /**
      * The aggregate size used by the volume group backup, in GBs.
  * <p>
  It is typically smaller than sizeInGBs, depending on the spaceconsumed
  * on the volume group and whether the volume backup is full or incremental.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "uniqueSizeInGbs"?: number;
    /**
     * OCIDs for the volume backups in this volume group backup.
     */
    "volumeBackupIds": Array<string>;
    /**
     * The OCID of the source volume group.
     */
    "volumeGroupId"?: string;
    /**
     * The OCID of the source volume group backup.
     */
    "sourceVolumeGroupBackupId"?: string;
}
export declare namespace VolumeGroupBackup {
    enum LifecycleState {
        Creating = "CREATING",
        Committed = "COMMITTED",
        Available = "AVAILABLE",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Faulty = "FAULTY",
        RequestReceived = "REQUEST_RECEIVED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SourceType {
        Manual = "MANUAL",
        Scheduled = "SCHEDULED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Type {
        Full = "FULL",
        Incremental = "INCREMENTAL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: VolumeGroupBackup): object;
}
