/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The properties that define Autonomous Data Guard association between two different Autonomous Container Databases.
 *
 */
export interface AutonomousContainerDatabaseDataguardAssociation {
    /**
     * The OCID of the Autonomous Data Guard created for a given Autonomous Container Database.
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Container Database that has a relationship with the peer Autonomous Container Database.
     *
     */
    "autonomousContainerDatabaseId": string;
    /**
     * The role of the Autonomous Data Guard-enabled Autonomous Container Database.
     */
    "role": AutonomousContainerDatabaseDataguardAssociation.Role;
    /**
     * The current state of Autonomous Data Guard.
     */
    "lifecycleState": AutonomousContainerDatabaseDataguardAssociation.LifecycleState;
    /**
     * Additional information about the current lifecycleState, if available.
     *
     */
    "lifecycleDetails"?: string;
    /**
     * The OCID of the peer Autonomous Container Database-Autonomous Data Guard association.
     */
    "peerAutonomousContainerDatabaseDataguardAssociationId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer Autonomous Container Database.
     *
     */
    "peerAutonomousContainerDatabaseId"?: string;
    /**
     * The role of the Autonomous Data Guard-enabled Autonomous Container Database.
     */
    "peerRole": AutonomousContainerDatabaseDataguardAssociation.PeerRole;
    /**
     * The current state of Autonomous Data Guard.
     */
    "peerLifecycleState"?: AutonomousContainerDatabaseDataguardAssociation.PeerLifecycleState;
    /**
     * The protection mode of this Autonomous Data Guard association. For more information, see
     * [Oracle Data Guard Protection Modes](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000)
     * in the Oracle Data Guard documentation.
     *
     */
    "protectionMode"?: AutonomousContainerDatabaseDataguardAssociation.ProtectionMode;
    /**
      * The lag time between updates to the primary Autonomous Container Database and application of the redo data on the standby Autonomous Container Database,
  * as computed by the reporting database.
  * <p>
  Example: `9 seconds`
  *
      */
    "applyLag"?: string;
    /**
      * The rate at which redo logs are synchronized between the associated Autonomous Container Databases.
  * <p>
  Example: `180 Mb per second`
  *
      */
    "applyRate"?: string;
    /**
      * The approximate number of seconds of redo data not yet available on the standby Autonomous Container Database,
  * as computed by the reporting database.
  * <p>
  Example: `7 seconds`
  *
      */
    "transportLag"?: string;
    /**
     * The date and time of the last update to the apply lag, apply rate, and transport lag values.
     */
    "timeLastSynced"?: Date;
    /**
     * The date and time the Autonomous DataGuard association was created.
     */
    "timeCreated"?: Date;
    /**
     * The date and time when the last role change action happened.
     */
    "timeLastRoleChanged"?: Date;
}
export declare namespace AutonomousContainerDatabaseDataguardAssociation {
    enum Role {
        Primary = "PRIMARY",
        Standby = "STANDBY",
        DisabledStandby = "DISABLED_STANDBY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Provisioning = "PROVISIONING",
        Available = "AVAILABLE",
        RoleChangeInProgress = "ROLE_CHANGE_IN_PROGRESS",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Failed = "FAILED",
        Unavailable = "UNAVAILABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum PeerRole {
        Primary = "PRIMARY",
        Standby = "STANDBY",
        DisabledStandby = "DISABLED_STANDBY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum PeerLifecycleState {
        Provisioning = "PROVISIONING",
        Available = "AVAILABLE",
        RoleChangeInProgress = "ROLE_CHANGE_IN_PROGRESS",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Failed = "FAILED",
        Unavailable = "UNAVAILABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ProtectionMode {
        MaximumAvailability = "MAXIMUM_AVAILABILITY",
        MaximumPerformance = "MAXIMUM_PERFORMANCE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AutonomousContainerDatabaseDataguardAssociation): object;
}
