/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * An Autonomous Database backup.
 *
 */
export interface AutonomousDatabaseBackup {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database backup.
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
     */
    "autonomousDatabaseId": string;
    /**
     * The user-friendly name for the backup. The name does not have to be unique.
     */
    "displayName": string;
    /**
     * The type of backup.
     */
    "type": AutonomousDatabaseBackup.Type;
    /**
     * Indicates whether the backup is user-initiated or automatic.
     */
    "isAutomatic": boolean;
    /**
     * The date and time the backup started.
     */
    "timeStarted"?: Date;
    /**
     * The date and time the backup completed.
     */
    "timeEnded"?: Date;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The size of the database in terabytes at the time the backup was taken.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "databaseSizeInTBs"?: number;
    /**
     * The current state of the backup.
     */
    "lifecycleState": AutonomousDatabaseBackup.LifecycleState;
    /**
     * Indicates whether the backup can be used to restore the associated Autonomous Database.
     */
    "isRestorable"?: boolean;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
     */
    "keyStoreId"?: string;
    /**
     * The wallet name for Oracle Key Vault.
     */
    "keyStoreWalletName"?: string;
}
export declare namespace AutonomousDatabaseBackup {
    enum Type {
        Incremental = "INCREMENTAL",
        Full = "FULL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AutonomousDatabaseBackup): object;
}
