/**
 * Data Catalog API
 * Use the Data Catalog APIs to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
 * OpenAPI spec version: 20190325
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { DataCatalogWaiter } from "./datacatalog-waiter";
export declare enum DataCatalogApiKeys {
}
export declare class DataCatalogClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataCatalogWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataCatalogWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataCatalogWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataCatalogWaiter;
    /**
     * Add data selector pattern to the data asset.
     * @param AddDataSelectorPatternsRequest
     * @return AddDataSelectorPatternsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/AddDataSelectorPatterns.ts.html |here} to see how to use AddDataSelectorPatterns API.
     */
    addDataSelectorPatterns(addDataSelectorPatternsRequest: requests.AddDataSelectorPatternsRequest): Promise<responses.AddDataSelectorPatternsResponse>;
    /**
     * Associate the custom property for the given type
     * @param AssociateCustomPropertyRequest
     * @return AssociateCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/AssociateCustomProperty.ts.html |here} to see how to use AssociateCustomProperty API.
     */
    associateCustomProperty(associateCustomPropertyRequest: requests.AssociateCustomPropertyRequest): Promise<responses.AssociateCustomPropertyResponse>;
    /**
     * Attaches a private reverse connection endpoint resource to a data catalog resource. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * @param AttachCatalogPrivateEndpointRequest
     * @return AttachCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/AttachCatalogPrivateEndpoint.ts.html |here} to see how to use AttachCatalogPrivateEndpoint API.
     */
    attachCatalogPrivateEndpoint(attachCatalogPrivateEndpointRequest: requests.AttachCatalogPrivateEndpointRequest): Promise<responses.AttachCatalogPrivateEndpointResponse>;
    /**
     * Moves a resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * @param ChangeCatalogCompartmentRequest
     * @return ChangeCatalogCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ChangeCatalogCompartment.ts.html |here} to see how to use ChangeCatalogCompartment API.
     */
    changeCatalogCompartment(changeCatalogCompartmentRequest: requests.ChangeCatalogCompartmentRequest): Promise<responses.ChangeCatalogCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * @param ChangeCatalogPrivateEndpointCompartmentRequest
     * @return ChangeCatalogPrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ChangeCatalogPrivateEndpointCompartment.ts.html |here} to see how to use ChangeCatalogPrivateEndpointCompartment API.
     */
    changeCatalogPrivateEndpointCompartment(changeCatalogPrivateEndpointCompartmentRequest: requests.ChangeCatalogPrivateEndpointCompartmentRequest): Promise<responses.ChangeCatalogPrivateEndpointCompartmentResponse>;
    /**
     * Creates a new entity attribute.
     * @param CreateAttributeRequest
     * @return CreateAttributeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateAttribute.ts.html |here} to see how to use CreateAttribute API.
     */
    createAttribute(createAttributeRequest: requests.CreateAttributeRequest): Promise<responses.CreateAttributeResponse>;
    /**
     * Creates a new entity attribute tag.
     * @param CreateAttributeTagRequest
     * @return CreateAttributeTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateAttributeTag.ts.html |here} to see how to use CreateAttributeTag API.
     */
    createAttributeTag(createAttributeTagRequest: requests.CreateAttributeTagRequest): Promise<responses.CreateAttributeTagResponse>;
    /**
     * Creates a new data catalog instance that includes a console and an API URL for managing metadata operations.
     * For more information, please see the documentation.
     *
     * @param CreateCatalogRequest
     * @return CreateCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateCatalog.ts.html |here} to see how to use CreateCatalog API.
     */
    createCatalog(createCatalogRequest: requests.CreateCatalogRequest): Promise<responses.CreateCatalogResponse>;
    /**
     * Create a new private reverse connection endpoint.
     * @param CreateCatalogPrivateEndpointRequest
     * @return CreateCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateCatalogPrivateEndpoint.ts.html |here} to see how to use CreateCatalogPrivateEndpoint API.
     */
    createCatalogPrivateEndpoint(createCatalogPrivateEndpointRequest: requests.CreateCatalogPrivateEndpointRequest): Promise<responses.CreateCatalogPrivateEndpointResponse>;
    /**
     * Creates a new connection.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Create a new Custom Property
     * @param CreateCustomPropertyRequest
     * @return CreateCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateCustomProperty.ts.html |here} to see how to use CreateCustomProperty API.
     */
    createCustomProperty(createCustomPropertyRequest: requests.CreateCustomPropertyRequest): Promise<responses.CreateCustomPropertyResponse>;
    /**
     * Create a new data asset.
     * @param CreateDataAssetRequest
     * @return CreateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateDataAsset.ts.html |here} to see how to use CreateDataAsset API.
     */
    createDataAsset(createDataAssetRequest: requests.CreateDataAssetRequest): Promise<responses.CreateDataAssetResponse>;
    /**
     * Creates a new data asset tag.
     * @param CreateDataAssetTagRequest
     * @return CreateDataAssetTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateDataAssetTag.ts.html |here} to see how to use CreateDataAssetTag API.
     */
    createDataAssetTag(createDataAssetTagRequest: requests.CreateDataAssetTagRequest): Promise<responses.CreateDataAssetTagResponse>;
    /**
     * Creates a new data entity.
     * @param CreateEntityRequest
     * @return CreateEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateEntity.ts.html |here} to see how to use CreateEntity API.
     */
    createEntity(createEntityRequest: requests.CreateEntityRequest): Promise<responses.CreateEntityResponse>;
    /**
     * Creates a new entity tag.
     * @param CreateEntityTagRequest
     * @return CreateEntityTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateEntityTag.ts.html |here} to see how to use CreateEntityTag API.
     */
    createEntityTag(createEntityTagRequest: requests.CreateEntityTagRequest): Promise<responses.CreateEntityTagResponse>;
    /**
     * Creates a new folder.
     * @param CreateFolderRequest
     * @return CreateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateFolder.ts.html |here} to see how to use CreateFolder API.
     */
    createFolder(createFolderRequest: requests.CreateFolderRequest): Promise<responses.CreateFolderResponse>;
    /**
     * Creates a new folder tag.
     * @param CreateFolderTagRequest
     * @return CreateFolderTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateFolderTag.ts.html |here} to see how to use CreateFolderTag API.
     */
    createFolderTag(createFolderTagRequest: requests.CreateFolderTagRequest): Promise<responses.CreateFolderTagResponse>;
    /**
     * Creates a new glossary.
     * @param CreateGlossaryRequest
     * @return CreateGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateGlossary.ts.html |here} to see how to use CreateGlossary API.
     */
    createGlossary(createGlossaryRequest: requests.CreateGlossaryRequest): Promise<responses.CreateGlossaryResponse>;
    /**
     * Creates a new job.
     * @param CreateJobRequest
     * @return CreateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateJob.ts.html |here} to see how to use CreateJob API.
     */
    createJob(createJobRequest: requests.CreateJobRequest): Promise<responses.CreateJobResponse>;
    /**
     * Creates a new job definition.
     * @param CreateJobDefinitionRequest
     * @return CreateJobDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateJobDefinition.ts.html |here} to see how to use CreateJobDefinition API.
     */
    createJobDefinition(createJobDefinitionRequest: requests.CreateJobDefinitionRequest): Promise<responses.CreateJobDefinitionResponse>;
    /**
     * Creates a new job execution.
     * @param CreateJobExecutionRequest
     * @return CreateJobExecutionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateJobExecution.ts.html |here} to see how to use CreateJobExecution API.
     */
    createJobExecution(createJobExecutionRequest: requests.CreateJobExecutionRequest): Promise<responses.CreateJobExecutionResponse>;
    /**
     * Create a new Namespace to be used by a custom property
     * @param CreateNamespaceRequest
     * @return CreateNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateNamespace.ts.html |here} to see how to use CreateNamespace API.
     */
    createNamespace(createNamespaceRequest: requests.CreateNamespaceRequest): Promise<responses.CreateNamespaceResponse>;
    /**
     * Create a new pattern.
     * @param CreatePatternRequest
     * @return CreatePatternResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreatePattern.ts.html |here} to see how to use CreatePattern API.
     */
    createPattern(createPatternRequest: requests.CreatePatternRequest): Promise<responses.CreatePatternResponse>;
    /**
     * Create a new term within a glossary.
     * @param CreateTermRequest
     * @return CreateTermResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateTerm.ts.html |here} to see how to use CreateTerm API.
     */
    createTerm(createTermRequest: requests.CreateTermRequest): Promise<responses.CreateTermResponse>;
    /**
     * Creates a new term relationship for this term within a glossary.
     * @param CreateTermRelationshipRequest
     * @return CreateTermRelationshipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/CreateTermRelationship.ts.html |here} to see how to use CreateTermRelationship API.
     */
    createTermRelationship(createTermRelationshipRequest: requests.CreateTermRelationshipRequest): Promise<responses.CreateTermRelationshipResponse>;
    /**
     * Deletes a specific entity attribute.
     * @param DeleteAttributeRequest
     * @return DeleteAttributeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteAttribute.ts.html |here} to see how to use DeleteAttribute API.
     */
    deleteAttribute(deleteAttributeRequest: requests.DeleteAttributeRequest): Promise<responses.DeleteAttributeResponse>;
    /**
     * Deletes a specific entity attribute tag.
     * @param DeleteAttributeTagRequest
     * @return DeleteAttributeTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteAttributeTag.ts.html |here} to see how to use DeleteAttributeTag API.
     */
    deleteAttributeTag(deleteAttributeTagRequest: requests.DeleteAttributeTagRequest): Promise<responses.DeleteAttributeTagResponse>;
    /**
     * Deletes a data catalog resource by identifier.
     * @param DeleteCatalogRequest
     * @return DeleteCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteCatalog.ts.html |here} to see how to use DeleteCatalog API.
     */
    deleteCatalog(deleteCatalogRequest: requests.DeleteCatalogRequest): Promise<responses.DeleteCatalogResponse>;
    /**
     * Deletes a private reverse connection endpoint by identifier.
     * @param DeleteCatalogPrivateEndpointRequest
     * @return DeleteCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteCatalogPrivateEndpoint.ts.html |here} to see how to use DeleteCatalogPrivateEndpoint API.
     */
    deleteCatalogPrivateEndpoint(deleteCatalogPrivateEndpointRequest: requests.DeleteCatalogPrivateEndpointRequest): Promise<responses.DeleteCatalogPrivateEndpointResponse>;
    /**
     * Deletes a specific connection of a data asset.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a specific custom property identified by it's key.
     * @param DeleteCustomPropertyRequest
     * @return DeleteCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteCustomProperty.ts.html |here} to see how to use DeleteCustomProperty API.
     */
    deleteCustomProperty(deleteCustomPropertyRequest: requests.DeleteCustomPropertyRequest): Promise<responses.DeleteCustomPropertyResponse>;
    /**
     * Deletes a specific data asset identified by it's key.
     * @param DeleteDataAssetRequest
     * @return DeleteDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteDataAsset.ts.html |here} to see how to use DeleteDataAsset API.
     */
    deleteDataAsset(deleteDataAssetRequest: requests.DeleteDataAssetRequest): Promise<responses.DeleteDataAssetResponse>;
    /**
     * Deletes a specific data asset tag.
     * @param DeleteDataAssetTagRequest
     * @return DeleteDataAssetTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteDataAssetTag.ts.html |here} to see how to use DeleteDataAssetTag API.
     */
    deleteDataAssetTag(deleteDataAssetTagRequest: requests.DeleteDataAssetTagRequest): Promise<responses.DeleteDataAssetTagResponse>;
    /**
     * Deletes a specific data entity.
     * @param DeleteEntityRequest
     * @return DeleteEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteEntity.ts.html |here} to see how to use DeleteEntity API.
     */
    deleteEntity(deleteEntityRequest: requests.DeleteEntityRequest): Promise<responses.DeleteEntityResponse>;
    /**
     * Deletes a specific entity tag.
     * @param DeleteEntityTagRequest
     * @return DeleteEntityTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteEntityTag.ts.html |here} to see how to use DeleteEntityTag API.
     */
    deleteEntityTag(deleteEntityTagRequest: requests.DeleteEntityTagRequest): Promise<responses.DeleteEntityTagResponse>;
    /**
     * Deletes a specific folder of a data asset identified by it's key.
     * @param DeleteFolderRequest
     * @return DeleteFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteFolder.ts.html |here} to see how to use DeleteFolder API.
     */
    deleteFolder(deleteFolderRequest: requests.DeleteFolderRequest): Promise<responses.DeleteFolderResponse>;
    /**
     * Deletes a specific folder tag.
     * @param DeleteFolderTagRequest
     * @return DeleteFolderTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteFolderTag.ts.html |here} to see how to use DeleteFolderTag API.
     */
    deleteFolderTag(deleteFolderTagRequest: requests.DeleteFolderTagRequest): Promise<responses.DeleteFolderTagResponse>;
    /**
     * Deletes a specific glossary identified by it's key.
     * @param DeleteGlossaryRequest
     * @return DeleteGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteGlossary.ts.html |here} to see how to use DeleteGlossary API.
     */
    deleteGlossary(deleteGlossaryRequest: requests.DeleteGlossaryRequest): Promise<responses.DeleteGlossaryResponse>;
    /**
     * Deletes a specific job identified by it's key.
     * @param DeleteJobRequest
     * @return DeleteJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteJob.ts.html |here} to see how to use DeleteJob API.
     */
    deleteJob(deleteJobRequest: requests.DeleteJobRequest): Promise<responses.DeleteJobResponse>;
    /**
     * Deletes a specific job definition identified by it's key.
     * @param DeleteJobDefinitionRequest
     * @return DeleteJobDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteJobDefinition.ts.html |here} to see how to use DeleteJobDefinition API.
     */
    deleteJobDefinition(deleteJobDefinitionRequest: requests.DeleteJobDefinitionRequest): Promise<responses.DeleteJobDefinitionResponse>;
    /**
     * Deletes a specific Namespace identified by it's key.
     * @param DeleteNamespaceRequest
     * @return DeleteNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteNamespace.ts.html |here} to see how to use DeleteNamespace API.
     */
    deleteNamespace(deleteNamespaceRequest: requests.DeleteNamespaceRequest): Promise<responses.DeleteNamespaceResponse>;
    /**
     * Deletes a specific pattern identified by it's key.
     * @param DeletePatternRequest
     * @return DeletePatternResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeletePattern.ts.html |here} to see how to use DeletePattern API.
     */
    deletePattern(deletePatternRequest: requests.DeletePatternRequest): Promise<responses.DeletePatternResponse>;
    /**
     * Deletes a specific glossary term.
     * @param DeleteTermRequest
     * @return DeleteTermResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteTerm.ts.html |here} to see how to use DeleteTerm API.
     */
    deleteTerm(deleteTermRequest: requests.DeleteTermRequest): Promise<responses.DeleteTermResponse>;
    /**
     * Deletes a specific glossary term relationship.
     * @param DeleteTermRelationshipRequest
     * @return DeleteTermRelationshipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DeleteTermRelationship.ts.html |here} to see how to use DeleteTermRelationship API.
     */
    deleteTermRelationship(deleteTermRelationshipRequest: requests.DeleteTermRelationshipRequest): Promise<responses.DeleteTermRelationshipResponse>;
    /**
     * Detaches a private reverse connection endpoint resource to a data catalog resource. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * @param DetachCatalogPrivateEndpointRequest
     * @return DetachCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DetachCatalogPrivateEndpoint.ts.html |here} to see how to use DetachCatalogPrivateEndpoint API.
     */
    detachCatalogPrivateEndpoint(detachCatalogPrivateEndpointRequest: requests.DetachCatalogPrivateEndpointRequest): Promise<responses.DetachCatalogPrivateEndpointResponse>;
    /**
     * Remove the custom property for the given type
     * @param DisassociateCustomPropertyRequest
     * @return DisassociateCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/DisassociateCustomProperty.ts.html |here} to see how to use DisassociateCustomProperty API.
     */
    disassociateCustomProperty(disassociateCustomPropertyRequest: requests.DisassociateCustomPropertyRequest): Promise<responses.DisassociateCustomPropertyResponse>;
    /**
     * Returns the fully expanded tree hierarchy of parent and child terms in this glossary.
     * @param ExpandTreeForGlossaryRequest
     * @return ExpandTreeForGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ExpandTreeForGlossary.ts.html |here} to see how to use ExpandTreeForGlossary API.
     */
    expandTreeForGlossary(expandTreeForGlossaryRequest: requests.ExpandTreeForGlossaryRequest): Promise<responses.ExpandTreeForGlossaryResponse>;
    /**
     * Export the glossary and the terms and return the exported glossary as csv or json.
     * @param ExportGlossaryRequest
     * @return ExportGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ExportGlossary.ts.html |here} to see how to use ExportGlossary API.
     */
    exportGlossary(exportGlossaryRequest: requests.ExportGlossaryRequest): Promise<responses.ExportGlossaryResponse>;
    /**
     * Gets a specific entity attribute by key.
     * @param GetAttributeRequest
     * @return GetAttributeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetAttribute.ts.html |here} to see how to use GetAttribute API.
     */
    getAttribute(getAttributeRequest: requests.GetAttributeRequest): Promise<responses.GetAttributeResponse>;
    /**
     * Gets a specific entity attribute tag by key.
     * @param GetAttributeTagRequest
     * @return GetAttributeTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetAttributeTag.ts.html |here} to see how to use GetAttributeTag API.
     */
    getAttributeTag(getAttributeTagRequest: requests.GetAttributeTagRequest): Promise<responses.GetAttributeTagResponse>;
    /**
     * Gets a data catalog by identifier.
     * @param GetCatalogRequest
     * @return GetCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetCatalog.ts.html |here} to see how to use GetCatalog API.
     */
    getCatalog(getCatalogRequest: requests.GetCatalogRequest): Promise<responses.GetCatalogResponse>;
    /**
     * Gets a specific private reverse connection by identifier.
     * @param GetCatalogPrivateEndpointRequest
     * @return GetCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetCatalogPrivateEndpoint.ts.html |here} to see how to use GetCatalogPrivateEndpoint API.
     */
    getCatalogPrivateEndpoint(getCatalogPrivateEndpointRequest: requests.GetCatalogPrivateEndpointRequest): Promise<responses.GetCatalogPrivateEndpointResponse>;
    /**
     * Gets a specific data asset connection by key.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Gets a specific custom property for the given key within a data catalog.
     * @param GetCustomPropertyRequest
     * @return GetCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetCustomProperty.ts.html |here} to see how to use GetCustomProperty API.
     */
    getCustomProperty(getCustomPropertyRequest: requests.GetCustomPropertyRequest): Promise<responses.GetCustomPropertyResponse>;
    /**
     * Gets a specific data asset for the given key within a data catalog.
     * @param GetDataAssetRequest
     * @return GetDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetDataAsset.ts.html |here} to see how to use GetDataAsset API.
     */
    getDataAsset(getDataAssetRequest: requests.GetDataAssetRequest): Promise<responses.GetDataAssetResponse>;
    /**
     * Gets a specific data asset tag by key.
     * @param GetDataAssetTagRequest
     * @return GetDataAssetTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetDataAssetTag.ts.html |here} to see how to use GetDataAssetTag API.
     */
    getDataAssetTag(getDataAssetTagRequest: requests.GetDataAssetTagRequest): Promise<responses.GetDataAssetTagResponse>;
    /**
     * Gets a specific data entity by key for a data asset.
     * @param GetEntityRequest
     * @return GetEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetEntity.ts.html |here} to see how to use GetEntity API.
     */
    getEntity(getEntityRequest: requests.GetEntityRequest): Promise<responses.GetEntityResponse>;
    /**
     * Gets a specific entity tag by key.
     * @param GetEntityTagRequest
     * @return GetEntityTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetEntityTag.ts.html |here} to see how to use GetEntityTag API.
     */
    getEntityTag(getEntityTagRequest: requests.GetEntityTagRequest): Promise<responses.GetEntityTagResponse>;
    /**
     * Gets a specific data asset folder by key.
     * @param GetFolderRequest
     * @return GetFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetFolder.ts.html |here} to see how to use GetFolder API.
     */
    getFolder(getFolderRequest: requests.GetFolderRequest): Promise<responses.GetFolderResponse>;
    /**
     * Gets a specific folder tag by key.
     * @param GetFolderTagRequest
     * @return GetFolderTagResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetFolderTag.ts.html |here} to see how to use GetFolderTag API.
     */
    getFolderTag(getFolderTagRequest: requests.GetFolderTagRequest): Promise<responses.GetFolderTagResponse>;
    /**
     * Gets a specific glossary by key within a data catalog.
     * @param GetGlossaryRequest
     * @return GetGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetGlossary.ts.html |here} to see how to use GetGlossary API.
     */
    getGlossary(getGlossaryRequest: requests.GetGlossaryRequest): Promise<responses.GetGlossaryResponse>;
    /**
     * Gets a specific job by key within a data catalog.
     * @param GetJobRequest
     * @return GetJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetJob.ts.html |here} to see how to use GetJob API.
     */
    getJob(getJobRequest: requests.GetJobRequest): Promise<responses.GetJobResponse>;
    /**
     * Gets a specific job definition by key within a data catalog.
     * @param GetJobDefinitionRequest
     * @return GetJobDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetJobDefinition.ts.html |here} to see how to use GetJobDefinition API.
     */
    getJobDefinition(getJobDefinitionRequest: requests.GetJobDefinitionRequest): Promise<responses.GetJobDefinitionResponse>;
    /**
     * Gets a specific job execution by key.
     * @param GetJobExecutionRequest
     * @return GetJobExecutionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetJobExecution.ts.html |here} to see how to use GetJobExecution API.
     */
    getJobExecution(getJobExecutionRequest: requests.GetJobExecutionRequest): Promise<responses.GetJobExecutionResponse>;
    /**
     * Gets a specific job log by key.
     * @param GetJobLogRequest
     * @return GetJobLogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetJobLog.ts.html |here} to see how to use GetJobLog API.
     */
    getJobLog(getJobLogRequest: requests.GetJobLogRequest): Promise<responses.GetJobLogResponse>;
    /**
     * Gets a specific job metric by key.
     * @param GetJobMetricsRequest
     * @return GetJobMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetJobMetrics.ts.html |here} to see how to use GetJobMetrics API.
     */
    getJobMetrics(getJobMetricsRequest: requests.GetJobMetricsRequest): Promise<responses.GetJobMetricsResponse>;
    /**
     * Gets a specific namespace for the given key within a data catalog.
     * @param GetNamespaceRequest
     * @return GetNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetNamespace.ts.html |here} to see how to use GetNamespace API.
     */
    getNamespace(getNamespaceRequest: requests.GetNamespaceRequest): Promise<responses.GetNamespaceResponse>;
    /**
     * Gets a specific pattern for the given key within a data catalog.
     * @param GetPatternRequest
     * @return GetPatternResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetPattern.ts.html |here} to see how to use GetPattern API.
     */
    getPattern(getPatternRequest: requests.GetPatternRequest): Promise<responses.GetPatternResponse>;
    /**
     * Gets a specific glossary term by key.
     * @param GetTermRequest
     * @return GetTermResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetTerm.ts.html |here} to see how to use GetTerm API.
     */
    getTerm(getTermRequest: requests.GetTermRequest): Promise<responses.GetTermResponse>;
    /**
     * Gets a specific glossary term relationship by key.
     * @param GetTermRelationshipRequest
     * @return GetTermRelationshipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetTermRelationship.ts.html |here} to see how to use GetTermRelationship API.
     */
    getTermRelationship(getTermRelationshipRequest: requests.GetTermRelationshipRequest): Promise<responses.GetTermRelationshipResponse>;
    /**
     * Gets a specific type by key within a data catalog.
     * @param GetTypeRequest
     * @return GetTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetType.ts.html |here} to see how to use GetType API.
     */
    getType(getTypeRequest: requests.GetTypeRequest): Promise<responses.GetTypeResponse>;
    /**
     * Gets the status of the work request with the given OCID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Import new connection for this data asset.
     * @param ImportConnectionRequest
     * @return ImportConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ImportConnection.ts.html |here} to see how to use ImportConnection API.
     */
    importConnection(importConnectionRequest: requests.ImportConnectionRequest): Promise<responses.ImportConnectionResponse>;
    /**
     * Import the glossary and the terms from csv or json files and return the imported glossary resource.
     * @param ImportGlossaryRequest
     * @return ImportGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ImportGlossary.ts.html |here} to see how to use ImportGlossary API.
     */
    importGlossary(importGlossaryRequest: requests.ImportGlossaryRequest): Promise<responses.ImportGlossaryResponse>;
    /**
     * List the physical entities aggregated by this logical entity.
     * @param ListAggregatedPhysicalEntitiesRequest
     * @return ListAggregatedPhysicalEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListAggregatedPhysicalEntities.ts.html |here} to see how to use ListAggregatedPhysicalEntities API.
     */
    listAggregatedPhysicalEntities(listAggregatedPhysicalEntitiesRequest: requests.ListAggregatedPhysicalEntitiesRequest): Promise<responses.ListAggregatedPhysicalEntitiesResponse>;
    /**
     * Returns a list of all tags for an entity attribute.
     * @param ListAttributeTagsRequest
     * @return ListAttributeTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListAttributeTags.ts.html |here} to see how to use ListAttributeTags API.
     */
    listAttributeTags(listAttributeTagsRequest: requests.ListAttributeTagsRequest): Promise<responses.ListAttributeTagsResponse>;
    /**
     * Returns a list of all attributes of an data entity.
     * @param ListAttributesRequest
     * @return ListAttributesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListAttributes.ts.html |here} to see how to use ListAttributes API.
     */
    listAttributes(listAttributesRequest: requests.ListAttributesRequest): Promise<responses.ListAttributesResponse>;
    /**
     * Returns a list of all the catalog private endpoints in the specified compartment.
     *
     * @param ListCatalogPrivateEndpointsRequest
     * @return ListCatalogPrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListCatalogPrivateEndpoints.ts.html |here} to see how to use ListCatalogPrivateEndpoints API.
     */
    listCatalogPrivateEndpoints(listCatalogPrivateEndpointsRequest: requests.ListCatalogPrivateEndpointsRequest): Promise<responses.ListCatalogPrivateEndpointsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CatalogPrivateEndpointSummary objects
     * contained in responses from the listCatalogPrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCatalogPrivateEndpoints(request: requests.ListCatalogPrivateEndpointsRequest): AsyncIterableIterator<models.CatalogPrivateEndpointSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCatalogPrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCatalogPrivateEndpointsResponses(request: requests.ListCatalogPrivateEndpointsRequest): AsyncIterableIterator<responses.ListCatalogPrivateEndpointsResponse>;
    /**
     * Returns a list of all the data catalogs in the specified compartment.
     *
     * @param ListCatalogsRequest
     * @return ListCatalogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListCatalogs.ts.html |here} to see how to use ListCatalogs API.
     */
    listCatalogs(listCatalogsRequest: requests.ListCatalogsRequest): Promise<responses.ListCatalogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CatalogSummary objects
     * contained in responses from the listCatalogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCatalogs(request: requests.ListCatalogsRequest): AsyncIterableIterator<models.CatalogSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCatalogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCatalogsResponses(request: requests.ListCatalogsRequest): AsyncIterableIterator<responses.ListCatalogsResponse>;
    /**
     * Returns a list of all Connections for a data asset.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * Returns a list of custom properties within a data catalog.
     * @param ListCustomPropertiesRequest
     * @return ListCustomPropertiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListCustomProperties.ts.html |here} to see how to use ListCustomProperties API.
     */
    listCustomProperties(listCustomPropertiesRequest: requests.ListCustomPropertiesRequest): Promise<responses.ListCustomPropertiesResponse>;
    /**
     * Returns a list of all tags for a data asset.
     * @param ListDataAssetTagsRequest
     * @return ListDataAssetTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListDataAssetTags.ts.html |here} to see how to use ListDataAssetTags API.
     */
    listDataAssetTags(listDataAssetTagsRequest: requests.ListDataAssetTagsRequest): Promise<responses.ListDataAssetTagsResponse>;
    /**
     * Returns a list of data assets within a data catalog.
     * @param ListDataAssetsRequest
     * @return ListDataAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListDataAssets.ts.html |here} to see how to use ListDataAssets API.
     */
    listDataAssets(listDataAssetsRequest: requests.ListDataAssetsRequest): Promise<responses.ListDataAssetsResponse>;
    /**
     * List logical entities derived from this pattern.
     * @param ListDerivedLogicalEntitiesRequest
     * @return ListDerivedLogicalEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListDerivedLogicalEntities.ts.html |here} to see how to use ListDerivedLogicalEntities API.
     */
    listDerivedLogicalEntities(listDerivedLogicalEntitiesRequest: requests.ListDerivedLogicalEntitiesRequest): Promise<responses.ListDerivedLogicalEntitiesResponse>;
    /**
     * Returns a list of all entities of a data asset.
     * @param ListEntitiesRequest
     * @return ListEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListEntities.ts.html |here} to see how to use ListEntities API.
     */
    listEntities(listEntitiesRequest: requests.ListEntitiesRequest): Promise<responses.ListEntitiesResponse>;
    /**
     * Returns a list of all tags for a data entity.
     * @param ListEntityTagsRequest
     * @return ListEntityTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListEntityTags.ts.html |here} to see how to use ListEntityTags API.
     */
    listEntityTags(listEntityTagsRequest: requests.ListEntityTagsRequest): Promise<responses.ListEntityTagsResponse>;
    /**
     * Returns a list of all tags for a folder.
     * @param ListFolderTagsRequest
     * @return ListFolderTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListFolderTags.ts.html |here} to see how to use ListFolderTags API.
     */
    listFolderTags(listFolderTagsRequest: requests.ListFolderTagsRequest): Promise<responses.ListFolderTagsResponse>;
    /**
     * Returns a list of all folders.
     * @param ListFoldersRequest
     * @return ListFoldersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListFolders.ts.html |here} to see how to use ListFolders API.
     */
    listFolders(listFoldersRequest: requests.ListFoldersRequest): Promise<responses.ListFoldersResponse>;
    /**
     * Returns a list of all glossaries within a data catalog.
     * @param ListGlossariesRequest
     * @return ListGlossariesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListGlossaries.ts.html |here} to see how to use ListGlossaries API.
     */
    listGlossaries(listGlossariesRequest: requests.ListGlossariesRequest): Promise<responses.ListGlossariesResponse>;
    /**
     * Returns a list of job definitions within a data catalog.
     * @param ListJobDefinitionsRequest
     * @return ListJobDefinitionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListJobDefinitions.ts.html |here} to see how to use ListJobDefinitions API.
     */
    listJobDefinitions(listJobDefinitionsRequest: requests.ListJobDefinitionsRequest): Promise<responses.ListJobDefinitionsResponse>;
    /**
     * Returns a list of job executions for a job.
     * @param ListJobExecutionsRequest
     * @return ListJobExecutionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListJobExecutions.ts.html |here} to see how to use ListJobExecutions API.
     */
    listJobExecutions(listJobExecutionsRequest: requests.ListJobExecutionsRequest): Promise<responses.ListJobExecutionsResponse>;
    /**
     * Returns a list of job logs.
     * @param ListJobLogsRequest
     * @return ListJobLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListJobLogs.ts.html |here} to see how to use ListJobLogs API.
     */
    listJobLogs(listJobLogsRequest: requests.ListJobLogsRequest): Promise<responses.ListJobLogsResponse>;
    /**
     * Returns a list of job metrics.
     * @param ListJobMetricsRequest
     * @return ListJobMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListJobMetrics.ts.html |here} to see how to use ListJobMetrics API.
     */
    listJobMetrics(listJobMetricsRequest: requests.ListJobMetricsRequest): Promise<responses.ListJobMetricsResponse>;
    /**
     * Returns a list of jobs within a data catalog.
     * @param ListJobsRequest
     * @return ListJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListJobs.ts.html |here} to see how to use ListJobs API.
     */
    listJobs(listJobsRequest: requests.ListJobsRequest): Promise<responses.ListJobsResponse>;
    /**
     * Returns a list of namespaces within a data catalog.
     * @param ListNamespacesRequest
     * @return ListNamespacesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListNamespaces.ts.html |here} to see how to use ListNamespaces API.
     */
    listNamespaces(listNamespacesRequest: requests.ListNamespacesRequest): Promise<responses.ListNamespacesResponse>;
    /**
     * Returns a list of patterns within a data catalog.
     * @param ListPatternsRequest
     * @return ListPatternsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListPatterns.ts.html |here} to see how to use ListPatterns API.
     */
    listPatterns(listPatternsRequest: requests.ListPatternsRequest): Promise<responses.ListPatternsResponse>;
    /**
     * Returns a list of all rules of a data entity.
     * @param ListRulesRequest
     * @return ListRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListRules.ts.html |here} to see how to use ListRules API.
     */
    listRules(listRulesRequest: requests.ListRulesRequest): Promise<responses.ListRulesResponse>;
    /**
     * Returns a list of all user created tags in the system.
     * @param ListTagsRequest
     * @return ListTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListTags.ts.html |here} to see how to use ListTags API.
     */
    listTags(listTagsRequest: requests.ListTagsRequest): Promise<responses.ListTagsResponse>;
    /**
     * Returns a list of all term relationships within a glossary.
     * @param ListTermRelationshipsRequest
     * @return ListTermRelationshipsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListTermRelationships.ts.html |here} to see how to use ListTermRelationships API.
     */
    listTermRelationships(listTermRelationshipsRequest: requests.ListTermRelationshipsRequest): Promise<responses.ListTermRelationshipsResponse>;
    /**
     * Returns a list of all terms within a glossary.
     * @param ListTermsRequest
     * @return ListTermsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListTerms.ts.html |here} to see how to use ListTerms API.
     */
    listTerms(listTermsRequest: requests.ListTermsRequest): Promise<responses.ListTermsResponse>;
    /**
     * Returns a list of all types within a data catalog.
     * @param ListTypesRequest
     * @return ListTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListTypes.ts.html |here} to see how to use ListTypes API.
     */
    listTypes(listTypesRequest: requests.ListTypesRequest): Promise<responses.ListTypesResponse>;
    /**
     * Returns a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLog objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLog>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequest>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Returns stats on objects by type in the repository.
     * @param ObjectStatsRequest
     * @return ObjectStatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ObjectStats.ts.html |here} to see how to use ObjectStats API.
     */
    objectStats(objectStatsRequest: requests.ObjectStatsRequest): Promise<responses.ObjectStatsResponse>;
    /**
     * Parse data asset references through connections from this data asset.
     * @param ParseConnectionRequest
     * @return ParseConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ParseConnection.ts.html |here} to see how to use ParseConnection API.
     */
    parseConnection(parseConnectionRequest: requests.ParseConnectionRequest): Promise<responses.ParseConnectionResponse>;
    /**
     * Act on a recommendation. A recommendation can be accepted or rejected. For example, if a recommendation of type LINK_GLOSSARY_TERM
     * is accepted, the system will link the source object (e.g. an attribute) to a target glossary term.
     *
     * @param ProcessRecommendationRequest
     * @return ProcessRecommendationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ProcessRecommendation.ts.html |here} to see how to use ProcessRecommendation API.
     */
    processRecommendation(processRecommendationRequest: requests.ProcessRecommendationRequest): Promise<responses.ProcessRecommendationResponse>;
    /**
     * Returns a list of recommendations for the given object and recommendation type.
     * By default, it will return inferred recommendations for review. The optional query param 'RecommendationStatus' can be set,
     * to return only recommendations having that status.
     *
     * @param RecommendationsRequest
     * @return RecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/Recommendations.ts.html |here} to see how to use Recommendations API.
     */
    recommendations(recommendationsRequest: requests.RecommendationsRequest): Promise<responses.RecommendationsResponse>;
    /**
     * Remove data selector pattern from the data asset.
     * @param RemoveDataSelectorPatternsRequest
     * @return RemoveDataSelectorPatternsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/RemoveDataSelectorPatterns.ts.html |here} to see how to use RemoveDataSelectorPatterns API.
     */
    removeDataSelectorPatterns(removeDataSelectorPatternsRequest: requests.RemoveDataSelectorPatternsRequest): Promise<responses.RemoveDataSelectorPatternsResponse>;
    /**
     * Returns a list of search results within a data catalog.
     * @param SearchCriteriaRequest
     * @return SearchCriteriaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/SearchCriteria.ts.html |here} to see how to use SearchCriteria API.
     */
    searchCriteria(searchCriteriaRequest: requests.SearchCriteriaRequest): Promise<responses.SearchCriteriaResponse>;
    /**
     * Test the connection by connecting to the data asset using credentials in the metadata.
     * @param TestConnectionRequest
     * @return TestConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/TestConnection.ts.html |here} to see how to use TestConnection API.
     */
    testConnection(testConnectionRequest: requests.TestConnectionRequest): Promise<responses.TestConnectionResponse>;
    /**
     * Updates a specific data asset attribute.
     * @param UpdateAttributeRequest
     * @return UpdateAttributeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateAttribute.ts.html |here} to see how to use UpdateAttribute API.
     */
    updateAttribute(updateAttributeRequest: requests.UpdateAttributeRequest): Promise<responses.UpdateAttributeResponse>;
    /**
     * Updates the data catalog.
     * @param UpdateCatalogRequest
     * @return UpdateCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateCatalog.ts.html |here} to see how to use UpdateCatalog API.
     */
    updateCatalog(updateCatalogRequest: requests.UpdateCatalogRequest): Promise<responses.UpdateCatalogResponse>;
    /**
     * Updates the private reverse connection endpoint.
     * @param UpdateCatalogPrivateEndpointRequest
     * @return UpdateCatalogPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateCatalogPrivateEndpoint.ts.html |here} to see how to use UpdateCatalogPrivateEndpoint API.
     */
    updateCatalogPrivateEndpoint(updateCatalogPrivateEndpointRequest: requests.UpdateCatalogPrivateEndpointRequest): Promise<responses.UpdateCatalogPrivateEndpointResponse>;
    /**
     * Updates a specific connection of a data asset.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Updates a specific custom property identified by the given key.
     * @param UpdateCustomPropertyRequest
     * @return UpdateCustomPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateCustomProperty.ts.html |here} to see how to use UpdateCustomProperty API.
     */
    updateCustomProperty(updateCustomPropertyRequest: requests.UpdateCustomPropertyRequest): Promise<responses.UpdateCustomPropertyResponse>;
    /**
     * Updates a specific data asset identified by the given key.
     * @param UpdateDataAssetRequest
     * @return UpdateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateDataAsset.ts.html |here} to see how to use UpdateDataAsset API.
     */
    updateDataAsset(updateDataAssetRequest: requests.UpdateDataAssetRequest): Promise<responses.UpdateDataAssetResponse>;
    /**
     * Updates a specific data entity.
     * @param UpdateEntityRequest
     * @return UpdateEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateEntity.ts.html |here} to see how to use UpdateEntity API.
     */
    updateEntity(updateEntityRequest: requests.UpdateEntityRequest): Promise<responses.UpdateEntityResponse>;
    /**
     * Updates a specific folder of a data asset.
     * @param UpdateFolderRequest
     * @return UpdateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateFolder.ts.html |here} to see how to use UpdateFolder API.
     */
    updateFolder(updateFolderRequest: requests.UpdateFolderRequest): Promise<responses.UpdateFolderResponse>;
    /**
     * Updates a specific glossary identified by the given key.
     * @param UpdateGlossaryRequest
     * @return UpdateGlossaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateGlossary.ts.html |here} to see how to use UpdateGlossary API.
     */
    updateGlossary(updateGlossaryRequest: requests.UpdateGlossaryRequest): Promise<responses.UpdateGlossaryResponse>;
    /**
     * Updates a specific job identified by the given key.
     * @param UpdateJobRequest
     * @return UpdateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateJob.ts.html |here} to see how to use UpdateJob API.
     */
    updateJob(updateJobRequest: requests.UpdateJobRequest): Promise<responses.UpdateJobResponse>;
    /**
     * Update a specific job definition identified by the given key.
     * @param UpdateJobDefinitionRequest
     * @return UpdateJobDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateJobDefinition.ts.html |here} to see how to use UpdateJobDefinition API.
     */
    updateJobDefinition(updateJobDefinitionRequest: requests.UpdateJobDefinitionRequest): Promise<responses.UpdateJobDefinitionResponse>;
    /**
     * Updates a specific namespace identified by the given key.
     * @param UpdateNamespaceRequest
     * @return UpdateNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateNamespace.ts.html |here} to see how to use UpdateNamespace API.
     */
    updateNamespace(updateNamespaceRequest: requests.UpdateNamespaceRequest): Promise<responses.UpdateNamespaceResponse>;
    /**
     * Updates a specific pattern identified by the given key.
     * @param UpdatePatternRequest
     * @return UpdatePatternResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdatePattern.ts.html |here} to see how to use UpdatePattern API.
     */
    updatePattern(updatePatternRequest: requests.UpdatePatternRequest): Promise<responses.UpdatePatternResponse>;
    /**
     * Updates a specific glossary term.
     * @param UpdateTermRequest
     * @return UpdateTermResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateTerm.ts.html |here} to see how to use UpdateTerm API.
     */
    updateTerm(updateTermRequest: requests.UpdateTermRequest): Promise<responses.UpdateTermResponse>;
    /**
     * Updates a specific glossary term relationship.
     * @param UpdateTermRelationshipRequest
     * @return UpdateTermRelationshipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UpdateTermRelationship.ts.html |here} to see how to use UpdateTermRelationship API.
     */
    updateTermRelationship(updateTermRelationshipRequest: requests.UpdateTermRelationshipRequest): Promise<responses.UpdateTermRelationshipResponse>;
    /**
     * Upload connection credentails and metadata for this connection.
     * @param UploadCredentialsRequest
     * @return UploadCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/UploadCredentials.ts.html |here} to see how to use UploadCredentials API.
     */
    uploadCredentials(uploadCredentialsRequest: requests.UploadCredentialsRequest): Promise<responses.UploadCredentialsResponse>;
    /**
     * Returns active users in the system.
     * @param UsersRequest
     * @return UsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/Users.ts.html |here} to see how to use Users API.
     */
    users(usersRequest: requests.UsersRequest): Promise<responses.UsersResponse>;
    /**
     * Validate connection by connecting to the data asset using credentials in metadata.
     * @param ValidateConnectionRequest
     * @return ValidateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ValidateConnection.ts.html |here} to see how to use ValidateConnection API.
     */
    validateConnection(validateConnectionRequest: requests.ValidateConnectionRequest): Promise<responses.ValidateConnectionResponse>;
    /**
     * Validate pattern by deriving file groups representing logical entities using the expression
     * @param ValidatePatternRequest
     * @return ValidatePatternResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/datacatalog/ValidatePattern.ts.html |here} to see how to use ValidatePattern API.
     */
    validatePattern(validatePatternRequest: requests.ValidatePatternRequest): Promise<responses.ValidatePatternResponse>;
}
