/**
 * Data Catalog API
 * Use the Data Catalog APIs to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
 * OpenAPI spec version: 20190325
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A set of metrics are collected periodically to assess the state and performance characteristics of the execution
 * instance of a job. The metrics are grouped based on their category and sub categories and aggregated based on
 * their batch information.
 *
 */
export interface JobMetric {
    /**
     * Key of the job metric that is immutable.
     */
    "key": string;
    /**
     * Detailed description of the metric.
     */
    "description"?: string;
    /**
     * The unique key of the parent job execution for which the job metric resource is being created.
     */
    "jobExecutionKey"?: string;
    /**
     * The time the metric was logged or captured in the system where the job executed.
     * An [RFC3339](https://tools.ietf.org/html/rfc3339) formatted datetime string.
     *
     */
    "timeInserted"?: Date;
    /**
     * Category of this metric.
     */
    "category"?: string;
    /**
     * A user-friendly display name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
     * Sub category of this metric under the category. Used for aggregating values. May be null.
     */
    "subCategory"?: string;
    /**
     * Unit of this metric.
     */
    "unit"?: string;
    /**
     * Value of this metric.
     */
    "value"?: string;
    /**
     * Batch key for grouping, may be null.
     */
    "batchKey"?: string;
    /**
     * URI to the job metric instance in the API.
     */
    "uri"?: string;
    /**
     * The date and time the job metric was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     * Example: `2019-03-25T21:10:29.600Z`
     *
     */
    "timeCreated"?: Date;
    /**
     * The last time that this metric was updated. An [RFC3339](https://tools.ietf.org/html/rfc3339) formatted datetime string.
     */
    "timeUpdated"?: Date;
    /**
     * OCID of the user who created the metric for this job. Usually the executor of the job instance.
     *
     */
    "createdById"?: string;
    /**
     * OCID of the user who created the metric for this job. Usually the executor of the job instance.
     *
     */
    "updatedById"?: string;
}
export declare namespace JobMetric {
    function getJsonObj(obj: JobMetric): object;
}
