/**
 * Data Integration API
 * Use the Data Integration Service APIs to perform common extract, load, and transform (ETL) tasks.
 * OpenAPI spec version: 20200430
 * Contact: di_dis_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { DataIntegrationWaiter } from "./dataintegration-waiter";
export declare enum DataIntegrationApiKeys {
}
export declare class DataIntegrationClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataIntegrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataIntegrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataIntegrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataIntegrationWaiter;
    /**
     * Moves a workspace to a specified compartment.
     *
     * @param ChangeCompartmentRequest
     * @return ChangeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ChangeCompartment.ts.html |here} to see how to use ChangeCompartment API.
     */
    changeCompartment(changeCompartmentRequest: requests.ChangeCompartmentRequest): Promise<responses.ChangeCompartmentResponse>;
    /**
     * Creates an application.
     *
     * @param CreateApplicationRequest
     * @return CreateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateApplication.ts.html |here} to see how to use CreateApplication API.
     */
    createApplication(createApplicationRequest: requests.CreateApplicationRequest): Promise<responses.CreateApplicationResponse>;
    /**
     * Creates a connection under an existing data asset.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Creates a connection validation.
     * @param CreateConnectionValidationRequest
     * @return CreateConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateConnectionValidation.ts.html |here} to see how to use CreateConnectionValidation API.
     */
    createConnectionValidation(createConnectionValidationRequest: requests.CreateConnectionValidationRequest): Promise<responses.CreateConnectionValidationResponse>;
    /**
     * Creates a data asset with default connection.
     * @param CreateDataAssetRequest
     * @return CreateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateDataAsset.ts.html |here} to see how to use CreateDataAsset API.
     */
    createDataAsset(createDataAssetRequest: requests.CreateDataAssetRequest): Promise<responses.CreateDataAssetResponse>;
    /**
     * Creates a new data flow in a project or folder ready for performing data integrations.
     *
     * @param CreateDataFlowRequest
     * @return CreateDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateDataFlow.ts.html |here} to see how to use CreateDataFlow API.
     */
    createDataFlow(createDataFlowRequest: requests.CreateDataFlowRequest): Promise<responses.CreateDataFlowResponse>;
    /**
     * Accepts the data flow definition in the request payload and creates a data flow validation.
     *
     * @param CreateDataFlowValidationRequest
     * @return CreateDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateDataFlowValidation.ts.html |here} to see how to use CreateDataFlowValidation API.
     */
    createDataFlowValidation(createDataFlowValidationRequest: requests.CreateDataFlowValidationRequest): Promise<responses.CreateDataFlowValidationResponse>;
    /**
     * Creates the data entity shape using the shape from the data asset.
     * @param CreateEntityShapeRequest
     * @return CreateEntityShapeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateEntityShape.ts.html |here} to see how to use CreateEntityShape API.
     */
    createEntityShape(createEntityShapeRequest: requests.CreateEntityShapeRequest): Promise<responses.CreateEntityShapeResponse>;
    /**
     * Publish a DataFlow in a OCI DataFlow application.
     * @param CreateExternalPublicationRequest
     * @return CreateExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateExternalPublication.ts.html |here} to see how to use CreateExternalPublication API.
     */
    createExternalPublication(createExternalPublicationRequest: requests.CreateExternalPublicationRequest): Promise<responses.CreateExternalPublicationResponse>;
    /**
     * Validates a specific task.
     * @param CreateExternalPublicationValidationRequest
     * @return CreateExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateExternalPublicationValidation.ts.html |here} to see how to use CreateExternalPublicationValidation API.
     */
    createExternalPublicationValidation(createExternalPublicationValidationRequest: requests.CreateExternalPublicationValidationRequest): Promise<responses.CreateExternalPublicationValidationResponse>;
    /**
     * Creates a folder in a project or in another folder, limited to two levels of folders. |
     * Folders are used to organize your design-time resources, such as tasks or data flows.
     *
     * @param CreateFolderRequest
     * @return CreateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateFolder.ts.html |here} to see how to use CreateFolder API.
     */
    createFolder(createFolderRequest: requests.CreateFolderRequest): Promise<responses.CreateFolderResponse>;
    /**
     * Creates a patch in an application.
     * @param CreatePatchRequest
     * @return CreatePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreatePatch.ts.html |here} to see how to use CreatePatch API.
     */
    createPatch(createPatchRequest: requests.CreatePatchRequest): Promise<responses.CreatePatchResponse>;
    /**
     * Creates a project. Projects are organizational constructs within a workspace that you use to organize your design-time resources, such as tasks or data flows. Projects can be organized into folders.
     *
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Creates a new task ready for performing data integrations. There are specialized types of tasks that include data loader and integration tasks.
     *
     * @param CreateTaskRequest
     * @return CreateTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateTask.ts.html |here} to see how to use CreateTask API.
     */
    createTask(createTaskRequest: requests.CreateTaskRequest): Promise<responses.CreateTaskResponse>;
    /**
     * Creates a data integration task run for the specified task.
     * @param CreateTaskRunRequest
     * @return CreateTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateTaskRun.ts.html |here} to see how to use CreateTaskRun API.
     */
    createTaskRun(createTaskRunRequest: requests.CreateTaskRunRequest): Promise<responses.CreateTaskRunResponse>;
    /**
     * Validates a specific task.
     * @param CreateTaskValidationRequest
     * @return CreateTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateTaskValidation.ts.html |here} to see how to use CreateTaskValidation API.
     */
    createTaskValidation(createTaskValidationRequest: requests.CreateTaskValidationRequest): Promise<responses.CreateTaskValidationResponse>;
    /**
     * Creates a new Data Integration workspace ready for performing data integration tasks.
     *
     * @param CreateWorkspaceRequest
     * @return CreateWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/CreateWorkspace.ts.html |here} to see how to use CreateWorkspace API.
     */
    createWorkspace(createWorkspaceRequest: requests.CreateWorkspaceRequest): Promise<responses.CreateWorkspaceResponse>;
    /**
     * Removes an application using the specified identifier.
     * @param DeleteApplicationRequest
     * @return DeleteApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteApplication.ts.html |here} to see how to use DeleteApplication API.
     */
    deleteApplication(deleteApplicationRequest: requests.DeleteApplicationRequest): Promise<responses.DeleteApplicationResponse>;
    /**
     * Removes a connection using the specified identifier.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a connection validation.
     * @param DeleteConnectionValidationRequest
     * @return DeleteConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteConnectionValidation.ts.html |here} to see how to use DeleteConnectionValidation API.
     */
    deleteConnectionValidation(deleteConnectionValidationRequest: requests.DeleteConnectionValidationRequest): Promise<responses.DeleteConnectionValidationResponse>;
    /**
     * Removes a data asset using the specified identifier.
     * @param DeleteDataAssetRequest
     * @return DeleteDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteDataAsset.ts.html |here} to see how to use DeleteDataAsset API.
     */
    deleteDataAsset(deleteDataAssetRequest: requests.DeleteDataAssetRequest): Promise<responses.DeleteDataAssetResponse>;
    /**
     * Removes a data flow from a project or folder using the specified identifier.
     * @param DeleteDataFlowRequest
     * @return DeleteDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteDataFlow.ts.html |here} to see how to use DeleteDataFlow API.
     */
    deleteDataFlow(deleteDataFlowRequest: requests.DeleteDataFlowRequest): Promise<responses.DeleteDataFlowResponse>;
    /**
     * Removes a data flow validation using the specified identifier.
     * @param DeleteDataFlowValidationRequest
     * @return DeleteDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteDataFlowValidation.ts.html |here} to see how to use DeleteDataFlowValidation API.
     */
    deleteDataFlowValidation(deleteDataFlowValidationRequest: requests.DeleteDataFlowValidationRequest): Promise<responses.DeleteDataFlowValidationResponse>;
    /**
     * Removes a published object using the specified identifier.
     * @param DeleteExternalPublicationRequest
     * @return DeleteExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteExternalPublication.ts.html |here} to see how to use DeleteExternalPublication API.
     */
    deleteExternalPublication(deleteExternalPublicationRequest: requests.DeleteExternalPublicationRequest): Promise<responses.DeleteExternalPublicationResponse>;
    /**
     * Removes a task validation using the specified identifier.
     *
     * @param DeleteExternalPublicationValidationRequest
     * @return DeleteExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteExternalPublicationValidation.ts.html |here} to see how to use DeleteExternalPublicationValidation API.
     */
    deleteExternalPublicationValidation(deleteExternalPublicationValidationRequest: requests.DeleteExternalPublicationValidationRequest): Promise<responses.DeleteExternalPublicationValidationResponse>;
    /**
     * Removes a folder from a project using the specified identifier.
     * @param DeleteFolderRequest
     * @return DeleteFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteFolder.ts.html |here} to see how to use DeleteFolder API.
     */
    deleteFolder(deleteFolderRequest: requests.DeleteFolderRequest): Promise<responses.DeleteFolderResponse>;
    /**
     * Removes a patch using the specified identifier.
     * @param DeletePatchRequest
     * @return DeletePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeletePatch.ts.html |here} to see how to use DeletePatch API.
     */
    deletePatch(deletePatchRequest: requests.DeletePatchRequest): Promise<responses.DeletePatchResponse>;
    /**
     * Removes a project from the workspace using the specified identifier.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Removes a task using the specified identifier.
     * @param DeleteTaskRequest
     * @return DeleteTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteTask.ts.html |here} to see how to use DeleteTask API.
     */
    deleteTask(deleteTaskRequest: requests.DeleteTaskRequest): Promise<responses.DeleteTaskResponse>;
    /**
     * Deletes a task run using the specified identifier.
     * @param DeleteTaskRunRequest
     * @return DeleteTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteTaskRun.ts.html |here} to see how to use DeleteTaskRun API.
     */
    deleteTaskRun(deleteTaskRunRequest: requests.DeleteTaskRunRequest): Promise<responses.DeleteTaskRunResponse>;
    /**
     * Removes a task validation using the specified identifier.
     *
     * @param DeleteTaskValidationRequest
     * @return DeleteTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteTaskValidation.ts.html |here} to see how to use DeleteTaskValidation API.
     */
    deleteTaskValidation(deleteTaskValidationRequest: requests.DeleteTaskValidationRequest): Promise<responses.DeleteTaskValidationResponse>;
    /**
     * Deletes a Data Integration workspace resource using the specified identifier.
     * @param DeleteWorkspaceRequest
     * @return DeleteWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/DeleteWorkspace.ts.html |here} to see how to use DeleteWorkspace API.
     */
    deleteWorkspace(deleteWorkspaceRequest: requests.DeleteWorkspaceRequest): Promise<responses.DeleteWorkspaceResponse>;
    /**
     * Retrieves an application using the specified identifier.
     * @param GetApplicationRequest
     * @return GetApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetApplication.ts.html |here} to see how to use GetApplication API.
     */
    getApplication(getApplicationRequest: requests.GetApplicationRequest): Promise<responses.GetApplicationResponse>;
    /**
     * Retrieves the connection details using the specified identifier.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Retrieves a connection validation using the specified identifier.
     * @param GetConnectionValidationRequest
     * @return GetConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetConnectionValidation.ts.html |here} to see how to use GetConnectionValidation API.
     */
    getConnectionValidation(getConnectionValidationRequest: requests.GetConnectionValidationRequest): Promise<responses.GetConnectionValidationResponse>;
    /**
     * Retrieves statistics on a workspace. It returns an object with an array of property values, such as the number of projects, |
     *        applications, data assets, and so on.
     *
     * @param GetCountStatisticRequest
     * @return GetCountStatisticResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetCountStatistic.ts.html |here} to see how to use GetCountStatistic API.
     */
    getCountStatistic(getCountStatisticRequest: requests.GetCountStatisticRequest): Promise<responses.GetCountStatisticResponse>;
    /**
     * Retrieves details of a data asset using the specified identifier.
     * @param GetDataAssetRequest
     * @return GetDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetDataAsset.ts.html |here} to see how to use GetDataAsset API.
     */
    getDataAsset(getDataAssetRequest: requests.GetDataAssetRequest): Promise<responses.GetDataAssetResponse>;
    /**
     * Retrieves the data entity details with the given name from live schema.
     * @param GetDataEntityRequest
     * @return GetDataEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetDataEntity.ts.html |here} to see how to use GetDataEntity API.
     */
    getDataEntity(getDataEntityRequest: requests.GetDataEntityRequest): Promise<responses.GetDataEntityResponse>;
    /**
     * Retrieves a data flow using the specified identifier.
     * @param GetDataFlowRequest
     * @return GetDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetDataFlow.ts.html |here} to see how to use GetDataFlow API.
     */
    getDataFlow(getDataFlowRequest: requests.GetDataFlowRequest): Promise<responses.GetDataFlowResponse>;
    /**
     * Retrieves a data flow validation using the specified identifier.
     * @param GetDataFlowValidationRequest
     * @return GetDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetDataFlowValidation.ts.html |here} to see how to use GetDataFlowValidation API.
     */
    getDataFlowValidation(getDataFlowValidationRequest: requests.GetDataFlowValidationRequest): Promise<responses.GetDataFlowValidationResponse>;
    /**
     * Retrieves the details of a dependent object from an application.
     * @param GetDependentObjectRequest
     * @return GetDependentObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetDependentObject.ts.html |here} to see how to use GetDependentObject API.
     */
    getDependentObject(getDependentObjectRequest: requests.GetDependentObjectRequest): Promise<responses.GetDependentObjectResponse>;
    /**
     * Retrieves a publshed object in an task using the specified identifier.
     * @param GetExternalPublicationRequest
     * @return GetExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetExternalPublication.ts.html |here} to see how to use GetExternalPublication API.
     */
    getExternalPublication(getExternalPublicationRequest: requests.GetExternalPublicationRequest): Promise<responses.GetExternalPublicationResponse>;
    /**
     * Retrieves an external publication validation using the specified identifier.
     * @param GetExternalPublicationValidationRequest
     * @return GetExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetExternalPublicationValidation.ts.html |here} to see how to use GetExternalPublicationValidation API.
     */
    getExternalPublicationValidation(getExternalPublicationValidationRequest: requests.GetExternalPublicationValidationRequest): Promise<responses.GetExternalPublicationValidationResponse>;
    /**
     * Retrieves a folder using the specified identifier.
     * @param GetFolderRequest
     * @return GetFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetFolder.ts.html |here} to see how to use GetFolder API.
     */
    getFolder(getFolderRequest: requests.GetFolderRequest): Promise<responses.GetFolderResponse>;
    /**
     * Retrieves a patch in an application using the specified identifier.
     * @param GetPatchRequest
     * @return GetPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetPatch.ts.html |here} to see how to use GetPatch API.
     */
    getPatch(getPatchRequest: requests.GetPatchRequest): Promise<responses.GetPatchResponse>;
    /**
     * Retrieves a project using the specified identifier.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Retrieves the details of a published object from an application.
     * @param GetPublishedObjectRequest
     * @return GetPublishedObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetPublishedObject.ts.html |here} to see how to use GetPublishedObject API.
     */
    getPublishedObject(getPublishedObjectRequest: requests.GetPublishedObjectRequest): Promise<responses.GetPublishedObjectResponse>;
    /**
     * Retrieves a reference in an application.
     * @param GetReferenceRequest
     * @return GetReferenceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetReference.ts.html |here} to see how to use GetReference API.
     */
    getReference(getReferenceRequest: requests.GetReferenceRequest): Promise<responses.GetReferenceResponse>;
    /**
     * Retrieves a schema that can be accessed using the specified connection.
     * @param GetSchemaRequest
     * @return GetSchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetSchema.ts.html |here} to see how to use GetSchema API.
     */
    getSchema(getSchemaRequest: requests.GetSchemaRequest): Promise<responses.GetSchemaResponse>;
    /**
     * Retrieves a task using the specified identifier.
     * @param GetTaskRequest
     * @return GetTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetTask.ts.html |here} to see how to use GetTask API.
     */
    getTask(getTaskRequest: requests.GetTaskRequest): Promise<responses.GetTaskResponse>;
    /**
     * Retrieves a task run using the specified identifier.
     * @param GetTaskRunRequest
     * @return GetTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetTaskRun.ts.html |here} to see how to use GetTaskRun API.
     */
    getTaskRun(getTaskRunRequest: requests.GetTaskRunRequest): Promise<responses.GetTaskRunResponse>;
    /**
     * Retrieves a task validation using the specified identifier.
     *
     * @param GetTaskValidationRequest
     * @return GetTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetTaskValidation.ts.html |here} to see how to use GetTaskValidation API.
     */
    getTaskValidation(getTaskValidationRequest: requests.GetTaskValidationRequest): Promise<responses.GetTaskValidationResponse>;
    /**
     * Retrieves the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieves a Data Integration workspace using the specified identifier.
     * @param GetWorkspaceRequest
     * @return GetWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/GetWorkspace.ts.html |here} to see how to use GetWorkspace API.
     */
    getWorkspace(getWorkspaceRequest: requests.GetWorkspaceRequest): Promise<responses.GetWorkspaceResponse>;
    /**
     * Retrieves a list of applications and provides options to filter the list.
     * @param ListApplicationsRequest
     * @return ListApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListApplications.ts.html |here} to see how to use ListApplications API.
     */
    listApplications(listApplicationsRequest: requests.ListApplicationsRequest): Promise<responses.ListApplicationsResponse>;
    /**
     * Retrieves a list of connection validations within the specified workspace.
     * @param ListConnectionValidationsRequest
     * @return ListConnectionValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListConnectionValidations.ts.html |here} to see how to use ListConnectionValidations API.
     */
    listConnectionValidations(listConnectionValidationsRequest: requests.ListConnectionValidationsRequest): Promise<responses.ListConnectionValidationsResponse>;
    /**
     * Retrieves a list of all connections.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * Retrieves a list of all data asset summaries.
     *
     * @param ListDataAssetsRequest
     * @return ListDataAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListDataAssets.ts.html |here} to see how to use ListDataAssets API.
     */
    listDataAssets(listDataAssetsRequest: requests.ListDataAssetsRequest): Promise<responses.ListDataAssetsResponse>;
    /**
     * Lists a summary of data entities from the data asset using the specified connection.
     *
     * @param ListDataEntitiesRequest
     * @return ListDataEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListDataEntities.ts.html |here} to see how to use ListDataEntities API.
     */
    listDataEntities(listDataEntitiesRequest: requests.ListDataEntitiesRequest): Promise<responses.ListDataEntitiesResponse>;
    /**
     * Retrieves a list of data flow validations within the specified workspace.
     * @param ListDataFlowValidationsRequest
     * @return ListDataFlowValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListDataFlowValidations.ts.html |here} to see how to use ListDataFlowValidations API.
     */
    listDataFlowValidations(listDataFlowValidationsRequest: requests.ListDataFlowValidationsRequest): Promise<responses.ListDataFlowValidationsResponse>;
    /**
     * Retrieves a list of data flows in a project or folder.
     *
     * @param ListDataFlowsRequest
     * @return ListDataFlowsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListDataFlows.ts.html |here} to see how to use ListDataFlows API.
     */
    listDataFlows(listDataFlowsRequest: requests.ListDataFlowsRequest): Promise<responses.ListDataFlowsResponse>;
    /**
     * Retrieves a list of all dependent objects for a specific application.
     * @param ListDependentObjectsRequest
     * @return ListDependentObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListDependentObjects.ts.html |here} to see how to use ListDependentObjects API.
     */
    listDependentObjects(listDependentObjectsRequest: requests.ListDependentObjectsRequest): Promise<responses.ListDependentObjectsResponse>;
    /**
     * Retrieves a lists of external publication validations in a workspace and provides options to filter the list.
     *
     * @param ListExternalPublicationValidationsRequest
     * @return ListExternalPublicationValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListExternalPublicationValidations.ts.html |here} to see how to use ListExternalPublicationValidations API.
     */
    listExternalPublicationValidations(listExternalPublicationValidationsRequest: requests.ListExternalPublicationValidationsRequest): Promise<responses.ListExternalPublicationValidationsResponse>;
    /**
     * Retrieves a list of external publications in an application and provides options to filter the list.
     * @param ListExternalPublicationsRequest
     * @return ListExternalPublicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListExternalPublications.ts.html |here} to see how to use ListExternalPublications API.
     */
    listExternalPublications(listExternalPublicationsRequest: requests.ListExternalPublicationsRequest): Promise<responses.ListExternalPublicationsResponse>;
    /**
     * Retrieves a list of folders in a project and provides options to filter the list.
     *
     * @param ListFoldersRequest
     * @return ListFoldersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListFolders.ts.html |here} to see how to use ListFolders API.
     */
    listFolders(listFoldersRequest: requests.ListFoldersRequest): Promise<responses.ListFoldersResponse>;
    /**
     * Retrieves a list of patches in an application and provides options to filter the list.
     * @param ListPatchChangesRequest
     * @return ListPatchChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListPatchChanges.ts.html |here} to see how to use ListPatchChanges API.
     */
    listPatchChanges(listPatchChangesRequest: requests.ListPatchChangesRequest): Promise<responses.ListPatchChangesResponse>;
    /**
     * Retrieves a list of patches in an application and provides options to filter the list. For listing changes based on a period and logical objects changed, see ListPatchChanges API.
     * @param ListPatchesRequest
     * @return ListPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListPatches.ts.html |here} to see how to use ListPatches API.
     */
    listPatches(listPatchesRequest: requests.ListPatchesRequest): Promise<responses.ListPatchesResponse>;
    /**
     * Retrieves a lists of projects in a workspace and provides options to filter the list.
     *
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * Retrieves a list of all the published objects for a specified application.
     * @param ListPublishedObjectsRequest
     * @return ListPublishedObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListPublishedObjects.ts.html |here} to see how to use ListPublishedObjects API.
     */
    listPublishedObjects(listPublishedObjectsRequest: requests.ListPublishedObjectsRequest): Promise<responses.ListPublishedObjectsResponse>;
    /**
     * Retrieves a list of references in an application. Reference objects are created when dataflows and tasks use objects, such as data assets and connections.
     * @param ListReferencesRequest
     * @return ListReferencesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListReferences.ts.html |here} to see how to use ListReferences API.
     */
    listReferences(listReferencesRequest: requests.ListReferencesRequest): Promise<responses.ListReferencesResponse>;
    /**
     * Retrieves a list of all the schemas that can be accessed using the specified connection.
     * @param ListSchemasRequest
     * @return ListSchemasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListSchemas.ts.html |here} to see how to use ListSchemas API.
     */
    listSchemas(listSchemasRequest: requests.ListSchemasRequest): Promise<responses.ListSchemasResponse>;
    /**
     * Gets log entries for task runs using its key.
     * @param ListTaskRunLogsRequest
     * @return ListTaskRunLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListTaskRunLogs.ts.html |here} to see how to use ListTaskRunLogs API.
     */
    listTaskRunLogs(listTaskRunLogsRequest: requests.ListTaskRunLogsRequest): Promise<responses.ListTaskRunLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TaskRunLogSummary objects
     * contained in responses from the listTaskRunLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTaskRunLogs(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<models.TaskRunLogSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listTaskRunLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTaskRunLogsResponses(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<responses.ListTaskRunLogsResponse>;
    /**
     * Retrieves a list of task runs and provides options to filter the list.
     * @param ListTaskRunsRequest
     * @return ListTaskRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListTaskRuns.ts.html |here} to see how to use ListTaskRuns API.
     */
    listTaskRuns(listTaskRunsRequest: requests.ListTaskRunsRequest): Promise<responses.ListTaskRunsResponse>;
    /**
     * Retrieves a list of task validations within the specified workspace.
     *
     * @param ListTaskValidationsRequest
     * @return ListTaskValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListTaskValidations.ts.html |here} to see how to use ListTaskValidations API.
     */
    listTaskValidations(listTaskValidationsRequest: requests.ListTaskValidationsRequest): Promise<responses.ListTaskValidationsResponse>;
    /**
     * Retrieves a list of all tasks in a specified project or folder.
     *
     * @param ListTasksRequest
     * @return ListTasksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListTasks.ts.html |here} to see how to use ListTasks API.
     */
    listTasks(listTasksRequest: requests.ListTasksRequest): Promise<responses.ListTasksResponse>;
    /**
     * Retrieves a paginated list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieves a paginated list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Retrieves a list of Data Integration workspaces.
     *
     * @param ListWorkspacesRequest
     * @return ListWorkspacesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/ListWorkspaces.ts.html |here} to see how to use ListWorkspaces API.
     */
    listWorkspaces(listWorkspacesRequest: requests.ListWorkspacesRequest): Promise<responses.ListWorkspacesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkspaceSummary objects
     * contained in responses from the listWorkspaces operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkspaces(request: requests.ListWorkspacesRequest): AsyncIterableIterator<models.WorkspaceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkspaces operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkspacesResponses(request: requests.ListWorkspacesRequest): AsyncIterableIterator<responses.ListWorkspacesResponse>;
    /**
     * Starts a workspace.
     *
     * @param StartWorkspaceRequest
     * @return StartWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/StartWorkspace.ts.html |here} to see how to use StartWorkspace API.
     */
    startWorkspace(startWorkspaceRequest: requests.StartWorkspaceRequest): Promise<responses.StartWorkspaceResponse>;
    /**
     * Stops a workspace.
     *
     * @param StopWorkspaceRequest
     * @return StopWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/StopWorkspace.ts.html |here} to see how to use StopWorkspace API.
     */
    stopWorkspace(stopWorkspaceRequest: requests.StopWorkspaceRequest): Promise<responses.StopWorkspaceResponse>;
    /**
     * Updates an application.
     * @param UpdateApplicationRequest
     * @return UpdateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateApplication.ts.html |here} to see how to use UpdateApplication API.
     */
    updateApplication(updateApplicationRequest: requests.UpdateApplicationRequest): Promise<responses.UpdateApplicationResponse>;
    /**
     * Updates a connection under a data asset.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Updates a specific data asset with default connection.
     * @param UpdateDataAssetRequest
     * @return UpdateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateDataAsset.ts.html |here} to see how to use UpdateDataAsset API.
     */
    updateDataAsset(updateDataAssetRequest: requests.UpdateDataAssetRequest): Promise<responses.UpdateDataAssetResponse>;
    /**
     * Updates a specific data flow.
     * @param UpdateDataFlowRequest
     * @return UpdateDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateDataFlow.ts.html |here} to see how to use UpdateDataFlow API.
     */
    updateDataFlow(updateDataFlowRequest: requests.UpdateDataFlowRequest): Promise<responses.UpdateDataFlowResponse>;
    /**
     * Updates the external publication object.
     * @param UpdateExternalPublicationRequest
     * @return UpdateExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateExternalPublication.ts.html |here} to see how to use UpdateExternalPublication API.
     */
    updateExternalPublication(updateExternalPublicationRequest: requests.UpdateExternalPublicationRequest): Promise<responses.UpdateExternalPublicationResponse>;
    /**
     * Updates a specific folder.
     * @param UpdateFolderRequest
     * @return UpdateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateFolder.ts.html |here} to see how to use UpdateFolder API.
     */
    updateFolder(updateFolderRequest: requests.UpdateFolderRequest): Promise<responses.UpdateFolderResponse>;
    /**
     * Updates a specific project.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
    /**
     * Updates the application references. For example, to map a data asset to a different target object.
     * @param UpdateReferenceRequest
     * @return UpdateReferenceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateReference.ts.html |here} to see how to use UpdateReference API.
     */
    updateReference(updateReferenceRequest: requests.UpdateReferenceRequest): Promise<responses.UpdateReferenceResponse>;
    /**
     * Updates a specific task. For example, you can update the task description or move the task to a different folder by changing the `aggregatorKey` to a different folder in the registry.
     * @param UpdateTaskRequest
     * @return UpdateTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateTask.ts.html |here} to see how to use UpdateTask API.
     */
    updateTask(updateTaskRequest: requests.UpdateTaskRequest): Promise<responses.UpdateTaskResponse>;
    /**
     * Updates the status of the task run. For example, aborts a task run.
     * @param UpdateTaskRunRequest
     * @return UpdateTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateTaskRun.ts.html |here} to see how to use UpdateTaskRun API.
     */
    updateTaskRun(updateTaskRunRequest: requests.UpdateTaskRunRequest): Promise<responses.UpdateTaskRunResponse>;
    /**
     * Updates the specified Data Integration workspace.
     * @param UpdateWorkspaceRequest
     * @return UpdateWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/dataintegration/UpdateWorkspace.ts.html |here} to see how to use UpdateWorkspace API.
     */
    updateWorkspace(updateWorkspaceRequest: requests.UpdateWorkspaceRequest): Promise<responses.UpdateWorkspaceResponse>;
}
