/**
 * LogAnalytics API
 * The LogAnalytics API for the LogAnalytics service.

 * OpenAPI spec version: 20200601
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { LogAnalyticsWaiter } from "./loganalytics-waiter";
export declare enum LogAnalyticsApiKeys {
}
export declare class LogAnalyticsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": LogAnalyticsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new LogAnalyticsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): LogAnalyticsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): LogAnalyticsWaiter;
    /**
     * Adds association between input source log analytics entity and one or more existing destination entities.
     * @param AddEntityAssociationRequest
     * @return AddEntityAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/AddEntityAssociation.ts.html |here} to see how to use AddEntityAssociation API.
     */
    addEntityAssociation(addEntityAssociationRequest: requests.AddEntityAssociationRequest): Promise<responses.AddEntityAssociationResponse>;
    /**
     * Append data to a lookup.  The file containing the information to append
     * must be provided.
     *
     * @param AppendLookupDataRequest
     * @return AppendLookupDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/AppendLookupData.ts.html |here} to see how to use AppendLookupData API.
     */
    appendLookupData(appendLookupDataRequest: requests.AppendLookupDataRequest): Promise<responses.AppendLookupDataResponse>;
    /**
     * get basic information about a specified set of labels
     * @param BatchGetBasicInfoRequest
     * @return BatchGetBasicInfoResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/BatchGetBasicInfo.ts.html |here} to see how to use BatchGetBasicInfo API.
     */
    batchGetBasicInfo(batchGetBasicInfoRequest: requests.BatchGetBasicInfoRequest): Promise<responses.BatchGetBasicInfoResponse>;
    /**
     * Cancel/Remove query job work request.
     * @param CancelQueryWorkRequestRequest
     * @return CancelQueryWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CancelQueryWorkRequest.ts.html |here} to see how to use CancelQueryWorkRequest API.
     */
    cancelQueryWorkRequest(cancelQueryWorkRequestRequest: requests.CancelQueryWorkRequestRequest): Promise<responses.CancelQueryWorkRequestResponse>;
    /**
     * Update the compartment of the log analytics entity with the given id.
     * @param ChangeLogAnalyticsEntityCompartmentRequest
     * @return ChangeLogAnalyticsEntityCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ChangeLogAnalyticsEntityCompartment.ts.html |here} to see how to use ChangeLogAnalyticsEntityCompartment API.
     */
    changeLogAnalyticsEntityCompartment(changeLogAnalyticsEntityCompartmentRequest: requests.ChangeLogAnalyticsEntityCompartmentRequest): Promise<responses.ChangeLogAnalyticsEntityCompartmentResponse>;
    /**
     * Updates the compartment of the Log-Analytics group with the given id.
     * @param ChangeLogAnalyticsLogGroupCompartmentRequest
     * @return ChangeLogAnalyticsLogGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ChangeLogAnalyticsLogGroupCompartment.ts.html |here} to see how to use ChangeLogAnalyticsLogGroupCompartment API.
     */
    changeLogAnalyticsLogGroupCompartment(changeLogAnalyticsLogGroupCompartmentRequest: requests.ChangeLogAnalyticsLogGroupCompartmentRequest): Promise<responses.ChangeLogAnalyticsLogGroupCompartmentResponse>;
    /**
     * Move the rule from it's current compartment to the given compartment.
     * @param ChangeLogAnalyticsObjectCollectionRuleCompartmentRequest
     * @return ChangeLogAnalyticsObjectCollectionRuleCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ChangeLogAnalyticsObjectCollectionRuleCompartment.ts.html |here} to see how to use ChangeLogAnalyticsObjectCollectionRuleCompartment API.
     */
    changeLogAnalyticsObjectCollectionRuleCompartment(changeLogAnalyticsObjectCollectionRuleCompartmentRequest: requests.ChangeLogAnalyticsObjectCollectionRuleCompartmentRequest): Promise<responses.ChangeLogAnalyticsObjectCollectionRuleCompartmentResponse>;
    /**
     * Move the scheduled task into a different compartment within the same tenancy.
     *
     * @param ChangeScheduledTaskCompartmentRequest
     * @return ChangeScheduledTaskCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ChangeScheduledTaskCompartment.ts.html |here} to see how to use ChangeScheduledTaskCompartment API.
     */
    changeScheduledTaskCompartment(changeScheduledTaskCompartmentRequest: requests.ChangeScheduledTaskCompartmentRequest): Promise<responses.ChangeScheduledTaskCompartmentResponse>;
    /**
     * Clean accumulated acceleration data stored for the accelerated saved search.
     * The ScheduledTask taskType must be ACCELERATION.
     *
     * @param CleanRequest
     * @return CleanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/Clean.ts.html |here} to see how to use Clean API.
     */
    clean(cleanRequest: requests.CleanRequest): Promise<responses.CleanResponse>;
    /**
     * Create a new log analytics entity.
     * @param CreateLogAnalyticsEntityRequest
     * @return CreateLogAnalyticsEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CreateLogAnalyticsEntity.ts.html |here} to see how to use CreateLogAnalyticsEntity API.
     */
    createLogAnalyticsEntity(createLogAnalyticsEntityRequest: requests.CreateLogAnalyticsEntityRequest): Promise<responses.CreateLogAnalyticsEntityResponse>;
    /**
     * Add custom log analytics entity type.
     * @param CreateLogAnalyticsEntityTypeRequest
     * @return CreateLogAnalyticsEntityTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CreateLogAnalyticsEntityType.ts.html |here} to see how to use CreateLogAnalyticsEntityType API.
     */
    createLogAnalyticsEntityType(createLogAnalyticsEntityTypeRequest: requests.CreateLogAnalyticsEntityTypeRequest): Promise<responses.CreateLogAnalyticsEntityTypeResponse>;
    /**
     * Creates a new Log-Analytics group.
     * @param CreateLogAnalyticsLogGroupRequest
     * @return CreateLogAnalyticsLogGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CreateLogAnalyticsLogGroup.ts.html |here} to see how to use CreateLogAnalyticsLogGroup API.
     */
    createLogAnalyticsLogGroup(createLogAnalyticsLogGroupRequest: requests.CreateLogAnalyticsLogGroupRequest): Promise<responses.CreateLogAnalyticsLogGroupResponse>;
    /**
     * Creates a rule to collect logs from an object storage bucket.
     * @param CreateLogAnalyticsObjectCollectionRuleRequest
     * @return CreateLogAnalyticsObjectCollectionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CreateLogAnalyticsObjectCollectionRule.ts.html |here} to see how to use CreateLogAnalyticsObjectCollectionRule API.
     */
    createLogAnalyticsObjectCollectionRule(createLogAnalyticsObjectCollectionRuleRequest: requests.CreateLogAnalyticsObjectCollectionRuleRequest): Promise<responses.CreateLogAnalyticsObjectCollectionRuleResponse>;
    /**
     * Schedule a task as specified and return task info.
     * @param CreateScheduledTaskRequest
     * @return CreateScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/CreateScheduledTask.ts.html |here} to see how to use CreateScheduledTask API.
     */
    createScheduledTask(createScheduledTaskRequest: requests.CreateScheduledTaskRequest): Promise<responses.CreateScheduledTaskResponse>;
    /**
     * delete associations
     * @param DeleteAssociationsRequest
     * @return DeleteAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteAssociations.ts.html |here} to see how to use DeleteAssociations API.
     */
    deleteAssociations(deleteAssociationsRequest: requests.DeleteAssociationsRequest): Promise<responses.DeleteAssociationsResponse>;
    /**
     * delete field with specified name
     * @param DeleteFieldRequest
     * @return DeleteFieldResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteField.ts.html |here} to see how to use DeleteField API.
     */
    deleteField(deleteFieldRequest: requests.DeleteFieldRequest): Promise<responses.DeleteFieldResponse>;
    /**
     * delete a label
     * @param DeleteLabelRequest
     * @return DeleteLabelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLabel.ts.html |here} to see how to use DeleteLabel API.
     */
    deleteLabel(deleteLabelRequest: requests.DeleteLabelRequest): Promise<responses.DeleteLabelResponse>;
    /**
     * Delete log analytics entity with the given id.
     * @param DeleteLogAnalyticsEntityRequest
     * @return DeleteLogAnalyticsEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLogAnalyticsEntity.ts.html |here} to see how to use DeleteLogAnalyticsEntity API.
     */
    deleteLogAnalyticsEntity(deleteLogAnalyticsEntityRequest: requests.DeleteLogAnalyticsEntityRequest): Promise<responses.DeleteLogAnalyticsEntityResponse>;
    /**
     * Delete log analytics entity type with the given name.
     * @param DeleteLogAnalyticsEntityTypeRequest
     * @return DeleteLogAnalyticsEntityTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLogAnalyticsEntityType.ts.html |here} to see how to use DeleteLogAnalyticsEntityType API.
     */
    deleteLogAnalyticsEntityType(deleteLogAnalyticsEntityTypeRequest: requests.DeleteLogAnalyticsEntityTypeRequest): Promise<responses.DeleteLogAnalyticsEntityTypeResponse>;
    /**
     * Deletes the Log-Analytics group with the given id.
     * @param DeleteLogAnalyticsLogGroupRequest
     * @return DeleteLogAnalyticsLogGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLogAnalyticsLogGroup.ts.html |here} to see how to use DeleteLogAnalyticsLogGroup API.
     */
    deleteLogAnalyticsLogGroup(deleteLogAnalyticsLogGroupRequest: requests.DeleteLogAnalyticsLogGroupRequest): Promise<responses.DeleteLogAnalyticsLogGroupResponse>;
    /**
     * Deletes the configured object storage bucket based collection rule and stop the log collection.
     * It will not delete the existing processed data associated with this bucket from logging analytics storage.
     *
     * @param DeleteLogAnalyticsObjectCollectionRuleRequest
     * @return DeleteLogAnalyticsObjectCollectionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLogAnalyticsObjectCollectionRule.ts.html |here} to see how to use DeleteLogAnalyticsObjectCollectionRule API.
     */
    deleteLogAnalyticsObjectCollectionRule(deleteLogAnalyticsObjectCollectionRuleRequest: requests.DeleteLogAnalyticsObjectCollectionRuleRequest): Promise<responses.DeleteLogAnalyticsObjectCollectionRuleResponse>;
    /**
     * Delete the specified lookup.
     *
     * @param DeleteLookupRequest
     * @return DeleteLookupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteLookup.ts.html |here} to see how to use DeleteLookup API.
     */
    deleteLookup(deleteLookupRequest: requests.DeleteLookupRequest): Promise<responses.DeleteLookupResponse>;
    /**
     * delete parser with specified name
     * @param DeleteParserRequest
     * @return DeleteParserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteParser.ts.html |here} to see how to use DeleteParser API.
     */
    deleteParser(deleteParserRequest: requests.DeleteParserRequest): Promise<responses.DeleteParserResponse>;
    /**
     * Delete the scheduled task.
     * @param DeleteScheduledTaskRequest
     * @return DeleteScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteScheduledTask.ts.html |here} to see how to use DeleteScheduledTask API.
     */
    deleteScheduledTask(deleteScheduledTaskRequest: requests.DeleteScheduledTaskRequest): Promise<responses.DeleteScheduledTaskResponse>;
    /**
     * delete source with specified ID
     * @param DeleteSourceRequest
     * @return DeleteSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteSource.ts.html |here} to see how to use DeleteSource API.
     */
    deleteSource(deleteSourceRequest: requests.DeleteSourceRequest): Promise<responses.DeleteSourceResponse>;
    /**
     * Deletes an Upload by its reference.
     * It deletes all the logs in storage asscoiated with the upload and the corresponding upload metadata.
     *
     * @param DeleteUploadRequest
     * @return DeleteUploadResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteUpload.ts.html |here} to see how to use DeleteUpload API.
     */
    deleteUpload(deleteUploadRequest: requests.DeleteUploadRequest): Promise<responses.DeleteUploadResponse>;
    /**
     * Deletes a specific log file inside an upload by upload file reference.
     * It deletes all the logs from storage associated with the file and the corresponding metadata.
     *
     * @param DeleteUploadFileRequest
     * @return DeleteUploadFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteUploadFile.ts.html |here} to see how to use DeleteUploadFile API.
     */
    deleteUploadFile(deleteUploadFileRequest: requests.DeleteUploadFileRequest): Promise<responses.DeleteUploadFileResponse>;
    /**
     * Suppresses a specific warning inside an upload.
     *
     * @param DeleteUploadWarningRequest
     * @return DeleteUploadWarningResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DeleteUploadWarning.ts.html |here} to see how to use DeleteUploadWarning API.
     */
    deleteUploadWarning(deleteUploadWarningRequest: requests.DeleteUploadWarningRequest): Promise<responses.DeleteUploadWarningResponse>;
    /**
     * This API disables archiving.
     *
     * @param DisableArchivingRequest
     * @return DisableArchivingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/DisableArchiving.ts.html |here} to see how to use DisableArchiving API.
     */
    disableArchiving(disableArchivingRequest: requests.DisableArchivingRequest): Promise<responses.DisableArchivingResponse>;
    /**
     * THis API enables archiving.
     *
     * @param EnableArchivingRequest
     * @return EnableArchivingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/EnableArchiving.ts.html |here} to see how to use EnableArchiving API.
     */
    enableArchiving(enableArchivingRequest: requests.EnableArchivingRequest): Promise<responses.EnableArchivingResponse>;
    /**
     * This API estimates the size of data to be purged based based on time interval, purge query etc.
     *
     * @param EstimatePurgeDataSizeRequest
     * @return EstimatePurgeDataSizeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/EstimatePurgeDataSize.ts.html |here} to see how to use EstimatePurgeDataSize API.
     */
    estimatePurgeDataSize(estimatePurgeDataSizeRequest: requests.EstimatePurgeDataSizeRequest): Promise<responses.EstimatePurgeDataSizeResponse>;
    /**
     * This API gives an active storage usage estimate for archived data to be recalled and the time range of such data.
     *
     * @param EstimateRecallDataSizeRequest
     * @return EstimateRecallDataSizeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/EstimateRecallDataSize.ts.html |here} to see how to use EstimateRecallDataSize API.
     */
    estimateRecallDataSize(estimateRecallDataSizeRequest: requests.EstimateRecallDataSizeRequest): Promise<responses.EstimateRecallDataSizeResponse>;
    /**
     * This API gives an active storage usage estimate for recalled data to be released and the time range of such data.
     *
     * @param EstimateReleaseDataSizeRequest
     * @return EstimateReleaseDataSizeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/EstimateReleaseDataSize.ts.html |here} to see how to use EstimateReleaseDataSize API.
     */
    estimateReleaseDataSize(estimateReleaseDataSizeRequest: requests.EstimateReleaseDataSizeRequest): Promise<responses.EstimateReleaseDataSizeResponse>;
    /**
     * export
     * @param ExportCustomContentRequest
     * @return ExportCustomContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ExportCustomContent.ts.html |here} to see how to use ExportCustomContent API.
     */
    exportCustomContent(exportCustomContentRequest: requests.ExportCustomContentRequest): Promise<responses.ExportCustomContentResponse>;
    /**
     * Export data based on query. Endpoint returns a stream of data. Endpoint is synchronous. Queries must deliver first result within 60 seconds or calls are subject to timeout.
     * @param ExportQueryResultRequest
     * @return ExportQueryResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ExportQueryResult.ts.html |here} to see how to use ExportQueryResult API.
     */
    exportQueryResult(exportQueryResultRequest: requests.ExportQueryResultRequest): Promise<responses.ExportQueryResultResponse>;
    /**
     * structured log fieldpaths
     * @param ExtractStructuredLogFieldPathsRequest
     * @return ExtractStructuredLogFieldPathsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ExtractStructuredLogFieldPaths.ts.html |here} to see how to use ExtractStructuredLogFieldPaths API.
     */
    extractStructuredLogFieldPaths(extractStructuredLogFieldPathsRequest: requests.ExtractStructuredLogFieldPathsRequest): Promise<responses.ExtractStructuredLogFieldPathsResponse>;
    /**
     * structured log header paths
     * @param ExtractStructuredLogHeaderPathsRequest
     * @return ExtractStructuredLogHeaderPathsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ExtractStructuredLogHeaderPaths.ts.html |here} to see how to use ExtractStructuredLogHeaderPaths API.
     */
    extractStructuredLogHeaderPaths(extractStructuredLogHeaderPathsRequest: requests.ExtractStructuredLogHeaderPathsRequest): Promise<responses.ExtractStructuredLogHeaderPathsResponse>;
    /**
     * Each filter specifies an operator, a field and one or more values to be inserted into the provided query as criteria.
     * @param FilterRequest
     * @return FilterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/Filter.ts.html |here} to see how to use Filter API.
     */
    filter(filterRequest: requests.FilterRequest): Promise<responses.FilterResponse>;
    /**
     * association summary
     * @param GetAssociationSummaryRequest
     * @return GetAssociationSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetAssociationSummary.ts.html |here} to see how to use GetAssociationSummary API.
     */
    getAssociationSummary(getAssociationSummaryRequest: requests.GetAssociationSummaryRequest): Promise<responses.GetAssociationSummaryResponse>;
    /**
     * extract column names from SQL query
     * @param GetColumnNamesRequest
     * @return GetColumnNamesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetColumnNames.ts.html |here} to see how to use GetColumnNames API.
     */
    getColumnNames(getColumnNamesRequest: requests.GetColumnNamesRequest): Promise<responses.GetColumnNamesResponse>;
    /**
     * association summary by source
     * @param GetConfigWorkRequestRequest
     * @return GetConfigWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetConfigWorkRequest.ts.html |here} to see how to use GetConfigWorkRequest API.
     */
    getConfigWorkRequest(getConfigWorkRequestRequest: requests.GetConfigWorkRequestRequest): Promise<responses.GetConfigWorkRequestResponse>;
    /**
     * get common field with specified name
     * @param GetFieldRequest
     * @return GetFieldResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetField.ts.html |here} to see how to use GetField API.
     */
    getField(getFieldRequest: requests.GetFieldRequest): Promise<responses.GetFieldResponse>;
    /**
     * get field summary
     * @param GetFieldsSummaryRequest
     * @return GetFieldsSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetFieldsSummary.ts.html |here} to see how to use GetFieldsSummary API.
     */
    getFieldsSummary(getFieldsSummaryRequest: requests.GetFieldsSummaryRequest): Promise<responses.GetFieldsSummaryResponse>;
    /**
     * get label with specified name
     * @param GetLabelRequest
     * @return GetLabelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLabel.ts.html |here} to see how to use GetLabel API.
     */
    getLabel(getLabelRequest: requests.GetLabelRequest): Promise<responses.GetLabelResponse>;
    /**
     * get total count
     * @param GetLabelSummaryRequest
     * @return GetLabelSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLabelSummary.ts.html |here} to see how to use GetLabelSummary API.
     */
    getLabelSummary(getLabelSummaryRequest: requests.GetLabelSummaryRequest): Promise<responses.GetLabelSummaryResponse>;
    /**
     * Returns log analytics entities count summary report.
     * @param GetLogAnalyticsEntitiesSummaryRequest
     * @return GetLogAnalyticsEntitiesSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsEntitiesSummary.ts.html |here} to see how to use GetLogAnalyticsEntitiesSummary API.
     */
    getLogAnalyticsEntitiesSummary(getLogAnalyticsEntitiesSummaryRequest: requests.GetLogAnalyticsEntitiesSummaryRequest): Promise<responses.GetLogAnalyticsEntitiesSummaryResponse>;
    /**
     * Retrieve the log analytics entity with the given id.
     * @param GetLogAnalyticsEntityRequest
     * @return GetLogAnalyticsEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsEntity.ts.html |here} to see how to use GetLogAnalyticsEntity API.
     */
    getLogAnalyticsEntity(getLogAnalyticsEntityRequest: requests.GetLogAnalyticsEntityRequest): Promise<responses.GetLogAnalyticsEntityResponse>;
    /**
     * Retrieve the log analytics entity type with the given name.
     * @param GetLogAnalyticsEntityTypeRequest
     * @return GetLogAnalyticsEntityTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsEntityType.ts.html |here} to see how to use GetLogAnalyticsEntityType API.
     */
    getLogAnalyticsEntityType(getLogAnalyticsEntityTypeRequest: requests.GetLogAnalyticsEntityTypeRequest): Promise<responses.GetLogAnalyticsEntityTypeResponse>;
    /**
     * Retrieves the Log-Analytics group with the given id.
     * @param GetLogAnalyticsLogGroupRequest
     * @return GetLogAnalyticsLogGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsLogGroup.ts.html |here} to see how to use GetLogAnalyticsLogGroup API.
     */
    getLogAnalyticsLogGroup(getLogAnalyticsLogGroupRequest: requests.GetLogAnalyticsLogGroupRequest): Promise<responses.GetLogAnalyticsLogGroupResponse>;
    /**
     * Returns a count of Log-Analytics groups.
     * @param GetLogAnalyticsLogGroupsSummaryRequest
     * @return GetLogAnalyticsLogGroupsSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsLogGroupsSummary.ts.html |here} to see how to use GetLogAnalyticsLogGroupsSummary API.
     */
    getLogAnalyticsLogGroupsSummary(getLogAnalyticsLogGroupsSummaryRequest: requests.GetLogAnalyticsLogGroupsSummaryRequest): Promise<responses.GetLogAnalyticsLogGroupsSummaryResponse>;
    /**
     * Gets a configured object storage based collection rule by given id
     * @param GetLogAnalyticsObjectCollectionRuleRequest
     * @return GetLogAnalyticsObjectCollectionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLogAnalyticsObjectCollectionRule.ts.html |here} to see how to use GetLogAnalyticsObjectCollectionRule API.
     */
    getLogAnalyticsObjectCollectionRule(getLogAnalyticsObjectCollectionRuleRequest: requests.GetLogAnalyticsObjectCollectionRuleRequest): Promise<responses.GetLogAnalyticsObjectCollectionRuleResponse>;
    /**
     * Obtains the lookup with the specified reference.
     *
     * @param GetLookupRequest
     * @return GetLookupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetLookup.ts.html |here} to see how to use GetLookup API.
     */
    getLookup(getLookupRequest: requests.GetLookupRequest): Promise<responses.GetLookupResponse>;
    /**
     * This API gets the namespace details of a tenancy already onboarded in Logging Analytics Application
     *
     * @param GetNamespaceRequest
     * @return GetNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetNamespace.ts.html |here} to see how to use GetNamespace API.
     */
    getNamespace(getNamespaceRequest: requests.GetNamespaceRequest): Promise<responses.GetNamespaceResponse>;
    /**
     * get parser with fields by Name
     * @param GetParserRequest
     * @return GetParserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetParser.ts.html |here} to see how to use GetParser API.
     */
    getParser(getParserRequest: requests.GetParserRequest): Promise<responses.GetParserResponse>;
    /**
     * parser summary
     * @param GetParserSummaryRequest
     * @return GetParserSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetParserSummary.ts.html |here} to see how to use GetParserSummary API.
     */
    getParserSummary(getParserSummaryRequest: requests.GetParserSummaryRequest): Promise<responses.GetParserSummaryResponse>;
    /**
     * Returns the intermediate results for a query that was specified to run asynchronously if the query has not completed,
     * otherwise the final query results identified by a queryWorkRequestId returned when submitting the query execute asynchronously.
     *
     * @param GetQueryResultRequest
     * @return GetQueryResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetQueryResult.ts.html |here} to see how to use GetQueryResult API.
     */
    getQueryResult(getQueryResultRequest: requests.GetQueryResultRequest): Promise<responses.GetQueryResultResponse>;
    /**
     * Retrieve work request details by workRequestId. This endpoint can be polled for status tracking of work request. Clients should poll using the interval returned in the retry-after header.
     * @param GetQueryWorkRequestRequest
     * @return GetQueryWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetQueryWorkRequest.ts.html |here} to see how to use GetQueryWorkRequest API.
     */
    getQueryWorkRequest(getQueryWorkRequestRequest: requests.GetQueryWorkRequestRequest): Promise<responses.GetQueryWorkRequestResponse>;
    /**
     * Get the scheduled task for the specified task identifier.
     * @param GetScheduledTaskRequest
     * @return GetScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetScheduledTask.ts.html |here} to see how to use GetScheduledTask API.
     */
    getScheduledTask(getScheduledTaskRequest: requests.GetScheduledTaskRequest): Promise<responses.GetScheduledTaskResponse>;
    /**
     * get source with specified name
     * @param GetSourceRequest
     * @return GetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetSource.ts.html |here} to see how to use GetSource API.
     */
    getSource(getSourceRequest: requests.GetSourceRequest): Promise<responses.GetSourceResponse>;
    /**
     * source summary
     * @param GetSourceSummaryRequest
     * @return GetSourceSummaryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetSourceSummary.ts.html |here} to see how to use GetSourceSummary API.
     */
    getSourceSummary(getSourceSummaryRequest: requests.GetSourceSummaryRequest): Promise<responses.GetSourceSummaryResponse>;
    /**
     * This API gets the storage configuration of a tenancy
     *
     * @param GetStorageRequest
     * @return GetStorageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetStorage.ts.html |here} to see how to use GetStorage API.
     */
    getStorage(getStorageRequest: requests.GetStorageRequest): Promise<responses.GetStorageResponse>;
    /**
     * This API gets storage usage information of a tenancy.  Storage usage information includes active, archived or recalled
     * data.  The unit of return data is in bytes.
     *
     * @param GetStorageUsageRequest
     * @return GetStorageUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetStorageUsage.ts.html |here} to see how to use GetStorageUsage API.
     */
    getStorageUsage(getStorageUsageRequest: requests.GetStorageUsageRequest): Promise<responses.GetStorageUsageResponse>;
    /**
     * This API returns work request details specified by {workRequestId}. This API can be polled for status tracking of
     * work request.  Clients should poll using the interval returned in retry-after header.
     *
     * @param GetStorageWorkRequestRequest
     * @return GetStorageWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetStorageWorkRequest.ts.html |here} to see how to use GetStorageWorkRequest API.
     */
    getStorageWorkRequest(getStorageWorkRequestRequest: requests.GetStorageWorkRequestRequest): Promise<responses.GetStorageWorkRequestResponse>;
    /**
     * Gets an On-Demand Upload info by reference.
     * @param GetUploadRequest
     * @return GetUploadResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetUpload.ts.html |here} to see how to use GetUpload API.
     */
    getUpload(getUploadRequest: requests.GetUploadRequest): Promise<responses.GetUploadResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * register custom content
     * @param ImportCustomContentRequest
     * @return ImportCustomContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ImportCustomContent.ts.html |here} to see how to use ImportCustomContent API.
     */
    importCustomContent(importCustomContentRequest: requests.ImportCustomContentRequest): Promise<responses.ImportCustomContentResponse>;
    /**
     * list of entities that have been associated to at least one source
     * @param ListAssociatedEntitiesRequest
     * @return ListAssociatedEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListAssociatedEntities.ts.html |here} to see how to use ListAssociatedEntities API.
     */
    listAssociatedEntities(listAssociatedEntitiesRequest: requests.ListAssociatedEntitiesRequest): Promise<responses.ListAssociatedEntitiesResponse>;
    /**
     * association summary by source
     * @param ListConfigWorkRequestsRequest
     * @return ListConfigWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListConfigWorkRequests.ts.html |here} to see how to use ListConfigWorkRequests API.
     */
    listConfigWorkRequests(listConfigWorkRequestsRequest: requests.ListConfigWorkRequestsRequest): Promise<responses.ListConfigWorkRequestsResponse>;
    /**
     * Return a list of log analytics entities associated with input source log analytics entity.
     * @param ListEntityAssociationsRequest
     * @return ListEntityAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListEntityAssociations.ts.html |here} to see how to use ListEntityAssociations API.
     */
    listEntityAssociations(listEntityAssociationsRequest: requests.ListEntityAssociationsRequest): Promise<responses.ListEntityAssociationsResponse>;
    /**
     * entity associations summary
     * @param ListEntitySourceAssociationsRequest
     * @return ListEntitySourceAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListEntitySourceAssociations.ts.html |here} to see how to use ListEntitySourceAssociations API.
     */
    listEntitySourceAssociations(listEntitySourceAssociationsRequest: requests.ListEntitySourceAssociationsRequest): Promise<responses.ListEntitySourceAssociationsResponse>;
    /**
     * get all common field with specified display name and description
     * @param ListFieldsRequest
     * @return ListFieldsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListFields.ts.html |here} to see how to use ListFields API.
     */
    listFields(listFieldsRequest: requests.ListFieldsRequest): Promise<responses.ListFieldsResponse>;
    /**
     * get list of priorities
     * @param ListLabelPrioritiesRequest
     * @return ListLabelPrioritiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLabelPriorities.ts.html |here} to see how to use ListLabelPriorities API.
     */
    listLabelPriorities(listLabelPrioritiesRequest: requests.ListLabelPrioritiesRequest): Promise<responses.ListLabelPrioritiesResponse>;
    /**
     * get details of sources using the label
     * @param ListLabelSourceDetailsRequest
     * @return ListLabelSourceDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLabelSourceDetails.ts.html |here} to see how to use ListLabelSourceDetails API.
     */
    listLabelSourceDetails(listLabelSourceDetailsRequest: requests.ListLabelSourceDetailsRequest): Promise<responses.ListLabelSourceDetailsResponse>;
    /**
     * get labels passing specified filter
     * @param ListLabelsRequest
     * @return ListLabelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLabels.ts.html |here} to see how to use ListLabels API.
     */
    listLabels(listLabelsRequest: requests.ListLabelsRequest): Promise<responses.ListLabelsResponse>;
    /**
     * Return a list of log analytics entities.
     * @param ListLogAnalyticsEntitiesRequest
     * @return ListLogAnalyticsEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLogAnalyticsEntities.ts.html |here} to see how to use ListLogAnalyticsEntities API.
     */
    listLogAnalyticsEntities(listLogAnalyticsEntitiesRequest: requests.ListLogAnalyticsEntitiesRequest): Promise<responses.ListLogAnalyticsEntitiesResponse>;
    /**
     * Return a list of log analytics entity types.
     * @param ListLogAnalyticsEntityTypesRequest
     * @return ListLogAnalyticsEntityTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLogAnalyticsEntityTypes.ts.html |here} to see how to use ListLogAnalyticsEntityTypes API.
     */
    listLogAnalyticsEntityTypes(listLogAnalyticsEntityTypesRequest: requests.ListLogAnalyticsEntityTypesRequest): Promise<responses.ListLogAnalyticsEntityTypesResponse>;
    /**
     * Returns a list of Log-Analytics groups.
     * @param ListLogAnalyticsLogGroupsRequest
     * @return ListLogAnalyticsLogGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLogAnalyticsLogGroups.ts.html |here} to see how to use ListLogAnalyticsLogGroups API.
     */
    listLogAnalyticsLogGroups(listLogAnalyticsLogGroupsRequest: requests.ListLogAnalyticsLogGroupsRequest): Promise<responses.ListLogAnalyticsLogGroupsResponse>;
    /**
     * Gets list of collection rules.
     * @param ListLogAnalyticsObjectCollectionRulesRequest
     * @return ListLogAnalyticsObjectCollectionRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLogAnalyticsObjectCollectionRules.ts.html |here} to see how to use ListLogAnalyticsObjectCollectionRules API.
     */
    listLogAnalyticsObjectCollectionRules(listLogAnalyticsObjectCollectionRulesRequest: requests.ListLogAnalyticsObjectCollectionRulesRequest): Promise<responses.ListLogAnalyticsObjectCollectionRulesResponse>;
    /**
     * Obtains a list of lookups.  The list is filtered according to the filter criteria
     * specified by the user, and sorted according to the ordering criteria specified.
     *
     * @param ListLookupsRequest
     * @return ListLookupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListLookups.ts.html |here} to see how to use ListLookups API.
     */
    listLookups(listLookupsRequest: requests.ListLookupsRequest): Promise<responses.ListLookupsResponse>;
    /**
     * get all meta source types
     * @param ListMetaSourceTypesRequest
     * @return ListMetaSourceTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListMetaSourceTypes.ts.html |here} to see how to use ListMetaSourceTypes API.
     */
    listMetaSourceTypes(listMetaSourceTypesRequest: requests.ListMetaSourceTypesRequest): Promise<responses.ListMetaSourceTypesResponse>;
    /**
     * Given a tenancy OCID, this API returns the namespace of the tenancy if it is valid and subscribed to the region.  The
     * result also indicates if the tenancy is onboarded with Logging Analytics.
     *
     * @param ListNamespacesRequest
     * @return ListNamespacesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListNamespaces.ts.html |here} to see how to use ListNamespaces API.
     */
    listNamespaces(listNamespacesRequest: requests.ListNamespacesRequest): Promise<responses.ListNamespacesResponse>;
    /**
     * get pre-process plugin instance
     * @param ListParserFunctionsRequest
     * @return ListParserFunctionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListParserFunctions.ts.html |here} to see how to use ListParserFunctions API.
     */
    listParserFunctions(listParserFunctionsRequest: requests.ListParserFunctionsRequest): Promise<responses.ListParserFunctionsResponse>;
    /**
     * get pre-process Meta plugins
     * @param ListParserMetaPluginsRequest
     * @return ListParserMetaPluginsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListParserMetaPlugins.ts.html |here} to see how to use ListParserMetaPlugins API.
     */
    listParserMetaPlugins(listParserMetaPluginsRequest: requests.ListParserMetaPluginsRequest): Promise<responses.ListParserMetaPluginsResponse>;
    /**
     * List parsers passing specified filter
     * @param ListParsersRequest
     * @return ListParsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListParsers.ts.html |here} to see how to use ListParsers API.
     */
    listParsers(listParsersRequest: requests.ListParsersRequest): Promise<responses.ListParsersResponse>;
    /**
     * List active asynchronous queries.
     * @param ListQueryWorkRequestsRequest
     * @return ListQueryWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListQueryWorkRequests.ts.html |here} to see how to use ListQueryWorkRequests API.
     */
    listQueryWorkRequests(listQueryWorkRequestsRequest: requests.ListQueryWorkRequestsRequest): Promise<responses.ListQueryWorkRequestsResponse>;
    /**
     * This API returns the list of recalled data of a tenancy.
     *
     * @param ListRecalledDataRequest
     * @return ListRecalledDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListRecalledData.ts.html |here} to see how to use ListRecalledData API.
     */
    listRecalledData(listRecalledDataRequest: requests.ListRecalledDataRequest): Promise<responses.ListRecalledDataResponse>;
    /**
     * Lists scheduled tasks.
     * @param ListScheduledTasksRequest
     * @return ListScheduledTasksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListScheduledTasks.ts.html |here} to see how to use ListScheduledTasks API.
     */
    listScheduledTasks(listScheduledTasksRequest: requests.ListScheduledTasksRequest): Promise<responses.ListScheduledTasksResponse>;
    /**
     * association summary by source
     * @param ListSourceAssociationsRequest
     * @return ListSourceAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSourceAssociations.ts.html |here} to see how to use ListSourceAssociations API.
     */
    listSourceAssociations(listSourceAssociationsRequest: requests.ListSourceAssociationsRequest): Promise<responses.ListSourceAssociationsResponse>;
    /**
     * get source extended fields for source with specified Id
     * @param ListSourceExtendedFieldDefinitionsRequest
     * @return ListSourceExtendedFieldDefinitionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSourceExtendedFieldDefinitions.ts.html |here} to see how to use ListSourceExtendedFieldDefinitions API.
     */
    listSourceExtendedFieldDefinitions(listSourceExtendedFieldDefinitionsRequest: requests.ListSourceExtendedFieldDefinitionsRequest): Promise<responses.ListSourceExtendedFieldDefinitionsResponse>;
    /**
     * list source label operators
     * @param ListSourceLabelOperatorsRequest
     * @return ListSourceLabelOperatorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSourceLabelOperators.ts.html |here} to see how to use ListSourceLabelOperators API.
     */
    listSourceLabelOperators(listSourceLabelOperatorsRequest: requests.ListSourceLabelOperatorsRequest): Promise<responses.ListSourceLabelOperatorsResponse>;
    /**
     * get source meta functions
     * @param ListSourceMetaFunctionsRequest
     * @return ListSourceMetaFunctionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSourceMetaFunctions.ts.html |here} to see how to use ListSourceMetaFunctions API.
     */
    listSourceMetaFunctions(listSourceMetaFunctionsRequest: requests.ListSourceMetaFunctionsRequest): Promise<responses.ListSourceMetaFunctionsResponse>;
    /**
     * get source patterns for source with specified Id
     * @param ListSourcePatternsRequest
     * @return ListSourcePatternsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSourcePatterns.ts.html |here} to see how to use ListSourcePatterns API.
     */
    listSourcePatterns(listSourcePatternsRequest: requests.ListSourcePatternsRequest): Promise<responses.ListSourcePatternsResponse>;
    /**
     * source list
     * @param ListSourcesRequest
     * @return ListSourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSources.ts.html |here} to see how to use ListSources API.
     */
    listSources(listSourcesRequest: requests.ListSourcesRequest): Promise<responses.ListSourcesResponse>;
    /**
     * This API returns the list of work request errors if any.
     * @param ListStorageWorkRequestErrorsRequest
     * @return ListStorageWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListStorageWorkRequestErrors.ts.html |here} to see how to use ListStorageWorkRequestErrors API.
     */
    listStorageWorkRequestErrors(listStorageWorkRequestErrorsRequest: requests.ListStorageWorkRequestErrorsRequest): Promise<responses.ListStorageWorkRequestErrorsResponse>;
    /**
     * This API lists storage work requests.  Use query parameters to narrow down or sort the result list.
     *
     * @param ListStorageWorkRequestsRequest
     * @return ListStorageWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListStorageWorkRequests.ts.html |here} to see how to use ListStorageWorkRequests API.
     */
    listStorageWorkRequests(listStorageWorkRequestsRequest: requests.ListStorageWorkRequestsRequest): Promise<responses.ListStorageWorkRequestsResponse>;
    /**
     * Gets list of character encodings which are supported by on-demand upload.
     * @param ListSupportedCharEncodingsRequest
     * @return ListSupportedCharEncodingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSupportedCharEncodings.ts.html |here} to see how to use ListSupportedCharEncodings API.
     */
    listSupportedCharEncodings(listSupportedCharEncodingsRequest: requests.ListSupportedCharEncodingsRequest): Promise<responses.ListSupportedCharEncodingsResponse>;
    /**
     * Gets list of timezones which are supported by on-demand upload.
     * @param ListSupportedTimezonesRequest
     * @return ListSupportedTimezonesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListSupportedTimezones.ts.html |here} to see how to use ListSupportedTimezones API.
     */
    listSupportedTimezones(listSupportedTimezonesRequest: requests.ListSupportedTimezonesRequest): Promise<responses.ListSupportedTimezonesResponse>;
    /**
     * Gets list of files in an upload along with its processing state.
     * @param ListUploadFilesRequest
     * @return ListUploadFilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListUploadFiles.ts.html |here} to see how to use ListUploadFiles API.
     */
    listUploadFiles(listUploadFilesRequest: requests.ListUploadFilesRequest): Promise<responses.ListUploadFilesResponse>;
    /**
     * Gets list of warnings in an upload caused by incorrect configuration.
     * @param ListUploadWarningsRequest
     * @return ListUploadWarningsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListUploadWarnings.ts.html |here} to see how to use ListUploadWarnings API.
     */
    listUploadWarnings(listUploadWarningsRequest: requests.ListUploadWarningsRequest): Promise<responses.ListUploadWarningsResponse>;
    /**
     * Gets a list of all On-demand uploads.
     * To use this and other API operations, you must be authorized in an IAM policy.
     *
     * @param ListUploadsRequest
     * @return ListUploadsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListUploads.ts.html |here} to see how to use ListUploads API.
     */
    listUploads(listUploadsRequest: requests.ListUploadsRequest): Promise<responses.ListUploadsResponse>;
    /**
     * Obtains a list of warnings.  The list is filtered according to the filter criteria
     * specified by the user, and sorted according to the ordering criteria specified.
     *
     * @param ListWarningsRequest
     * @return ListWarningsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListWarnings.ts.html |here} to see how to use ListWarnings API.
     */
    listWarnings(listWarningsRequest: requests.ListWarningsRequest): Promise<responses.ListWarningsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Off-boards a tenant from Logging Analytics
     * @param OffboardNamespaceRequest
     * @return OffboardNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/OffboardNamespace.ts.html |here} to see how to use OffboardNamespace API.
     */
    offboardNamespace(offboardNamespaceRequest: requests.OffboardNamespaceRequest): Promise<responses.OffboardNamespaceResponse>;
    /**
     * On-boards a tenant to Logging Analytics.
     *
     * @param OnboardNamespaceRequest
     * @return OnboardNamespaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/OnboardNamespace.ts.html |here} to see how to use OnboardNamespace API.
     */
    onboardNamespace(onboardNamespaceRequest: requests.OnboardNamespaceRequest): Promise<responses.OnboardNamespaceResponse>;
    /**
     * Describe query
     * @param ParseQueryRequest
     * @return ParseQueryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ParseQuery.ts.html |here} to see how to use ParseQuery API.
     */
    parseQuery(parseQueryRequest: requests.ParseQueryRequest): Promise<responses.ParseQueryResponse>;
    /**
     * Pause the scheduled task specified by {scheduledTaskId}.
     *
     * @param PauseScheduledTaskRequest
     * @return PauseScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/PauseScheduledTask.ts.html |here} to see how to use PauseScheduledTask API.
     */
    pauseScheduledTask(pauseScheduledTaskRequest: requests.PauseScheduledTaskRequest): Promise<responses.PauseScheduledTaskResponse>;
    /**
     * This API submits a work request to purge data. Only data from log groups that the user has permission to delete
     * will be purged.  To purge all data, the user must have permission to all log groups.
     *
     * @param PurgeStorageDataRequest
     * @return PurgeStorageDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/PurgeStorageData.ts.html |here} to see how to use PurgeStorageData API.
     */
    purgeStorageData(purgeStorageDataRequest: requests.PurgeStorageDataRequest): Promise<responses.PurgeStorageDataResponse>;
    /**
     * Put the work request specified by {workRequestId} into the background. Backgrounded queries will preserve query results on query completion for up to 7 days for recall. After 7 days the results and query expire.
     * @param PutQueryWorkRequestBackgroundRequest
     * @return PutQueryWorkRequestBackgroundResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/PutQueryWorkRequestBackground.ts.html |here} to see how to use PutQueryWorkRequestBackground API.
     */
    putQueryWorkRequestBackground(putQueryWorkRequestBackgroundRequest: requests.PutQueryWorkRequestBackgroundRequest): Promise<responses.PutQueryWorkRequestBackgroundResponse>;
    /**
     * Performs a log analytics search, if shouldRunAsync is false returns the query results once they become available subject to 60 second timeout. If a query is subject to exceed that time then it should be run asynchronously. Asynchronous query submissions return the queryWorkRequestId to use for execution tracking, query submission lifecycle actions and to poll for query results.
     *
     * @param QueryRequest
     * @return QueryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/Query.ts.html |here} to see how to use Query API.
     */
    query(queryRequest: requests.QueryRequest): Promise<responses.QueryResponse>;
    /**
     * This API submits a work request to recall archived data based on time interval and data type.
     *
     * @param RecallArchivedDataRequest
     * @return RecallArchivedDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/RecallArchivedData.ts.html |here} to see how to use RecallArchivedData API.
     */
    recallArchivedData(recallArchivedDataRequest: requests.RecallArchivedDataRequest): Promise<responses.RecallArchivedDataResponse>;
    /**
     * register lookup
     * @param RegisterLookupRequest
     * @return RegisterLookupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/RegisterLookup.ts.html |here} to see how to use RegisterLookup API.
     */
    registerLookup(registerLookupRequest: requests.RegisterLookupRequest): Promise<responses.RegisterLookupResponse>;
    /**
     * This API submits a work request to release recalled data based on time interval and data type.
     *
     * @param ReleaseRecalledDataRequest
     * @return ReleaseRecalledDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ReleaseRecalledData.ts.html |here} to see how to use ReleaseRecalledData API.
     */
    releaseRecalledData(releaseRecalledDataRequest: requests.ReleaseRecalledDataRequest): Promise<responses.ReleaseRecalledDataResponse>;
    /**
     * Delete association between input source log analytics entity and destination entities.
     * @param RemoveEntityAssociationsRequest
     * @return RemoveEntityAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/RemoveEntityAssociations.ts.html |here} to see how to use RemoveEntityAssociations API.
     */
    removeEntityAssociations(removeEntityAssociationsRequest: requests.RemoveEntityAssociationsRequest): Promise<responses.RemoveEntityAssociationsResponse>;
    /**
     * Resume the scheduled task specified by {scheduledTaskId}.
     *
     * @param ResumeScheduledTaskRequest
     * @return ResumeScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ResumeScheduledTask.ts.html |here} to see how to use ResumeScheduledTask API.
     */
    resumeScheduledTask(resumeScheduledTaskRequest: requests.ResumeScheduledTaskRequest): Promise<responses.ResumeScheduledTaskResponse>;
    /**
     * Execute the saved search acceleration task in the foreground.
     * The ScheduledTask taskType must be ACCELERATION.
     * Optionally specify time range (timeStart and timeEnd). The default is all time.
     *
     * @param RunRequest
     * @return RunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/Run.ts.html |here} to see how to use Run API.
     */
    run(runRequest: requests.RunRequest): Promise<responses.RunResponse>;
    /**
     * Returns a context specific list of either commands, fields, or values to append to the end of the specified query string if applicable.
     * @param SuggestRequest
     * @return SuggestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/Suggest.ts.html |here} to see how to use Suggest API.
     */
    suggest(suggestRequest: requests.SuggestRequest): Promise<responses.SuggestResponse>;
    /**
     * Accepts a list of warnings.  Any unsuppressed warnings in the input list will
     * be suppressed.  Warnings in the input list which are already suppressed will
     * not be modified.
     *
     * @param SuppressWarningRequest
     * @return SuppressWarningResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/SuppressWarning.ts.html |here} to see how to use SuppressWarning API.
     */
    suppressWarning(suppressWarningRequest: requests.SuppressWarningRequest): Promise<responses.SuppressWarningResponse>;
    /**
     * test parser
     * @param TestParserRequest
     * @return TestParserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/TestParser.ts.html |here} to see how to use TestParser API.
     */
    testParser(testParserRequest: requests.TestParserRequest): Promise<responses.TestParserResponse>;
    /**
     * Accepts a list of warnings.  Any suppressed warnings in the input list will
     * be unsuppressed.  Warnings in the input list which are unsuppressed will
     * not be modified.
     *
     * @param UnsuppressWarningRequest
     * @return UnsuppressWarningResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UnsuppressWarning.ts.html |here} to see how to use UnsuppressWarning API.
     */
    unsuppressWarning(unsuppressWarningRequest: requests.UnsuppressWarningRequest): Promise<responses.UnsuppressWarningResponse>;
    /**
     * Update the log analytics entity with the given id.
     * @param UpdateLogAnalyticsEntityRequest
     * @return UpdateLogAnalyticsEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLogAnalyticsEntity.ts.html |here} to see how to use UpdateLogAnalyticsEntity API.
     */
    updateLogAnalyticsEntity(updateLogAnalyticsEntityRequest: requests.UpdateLogAnalyticsEntityRequest): Promise<responses.UpdateLogAnalyticsEntityResponse>;
    /**
     * Update custom log analytics entity type. Out of box entity types cannot be udpated.
     * @param UpdateLogAnalyticsEntityTypeRequest
     * @return UpdateLogAnalyticsEntityTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLogAnalyticsEntityType.ts.html |here} to see how to use UpdateLogAnalyticsEntityType API.
     */
    updateLogAnalyticsEntityType(updateLogAnalyticsEntityTypeRequest: requests.UpdateLogAnalyticsEntityTypeRequest): Promise<responses.UpdateLogAnalyticsEntityTypeResponse>;
    /**
     * Updates the Log-Analytics group with the given id.
     * @param UpdateLogAnalyticsLogGroupRequest
     * @return UpdateLogAnalyticsLogGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLogAnalyticsLogGroup.ts.html |here} to see how to use UpdateLogAnalyticsLogGroup API.
     */
    updateLogAnalyticsLogGroup(updateLogAnalyticsLogGroupRequest: requests.UpdateLogAnalyticsLogGroupRequest): Promise<responses.UpdateLogAnalyticsLogGroupResponse>;
    /**
     * Updates configuration of the object collection rule for the given id.
     * @param UpdateLogAnalyticsObjectCollectionRuleRequest
     * @return UpdateLogAnalyticsObjectCollectionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLogAnalyticsObjectCollectionRule.ts.html |here} to see how to use UpdateLogAnalyticsObjectCollectionRule API.
     */
    updateLogAnalyticsObjectCollectionRule(updateLogAnalyticsObjectCollectionRuleRequest: requests.UpdateLogAnalyticsObjectCollectionRuleRequest): Promise<responses.UpdateLogAnalyticsObjectCollectionRuleResponse>;
    /**
     * Updates the metadata of the specified lookup, such as the lookup description.
     *
     * @param UpdateLookupRequest
     * @return UpdateLookupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLookup.ts.html |here} to see how to use UpdateLookup API.
     */
    updateLookup(updateLookupRequest: requests.UpdateLookupRequest): Promise<responses.UpdateLookupResponse>;
    /**
     * Updates the specified lookup with the details provided.  This API will not update
     * lookup metadata (such as lookup description).
     *
     * @param UpdateLookupDataRequest
     * @return UpdateLookupDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateLookupData.ts.html |here} to see how to use UpdateLookupData API.
     */
    updateLookupData(updateLookupDataRequest: requests.UpdateLookupDataRequest): Promise<responses.UpdateLookupDataResponse>;
    /**
     * Update the scheduled task. Schedules may be updated only for taskType SAVED_SEARCH and PURGE.
     * @param UpdateScheduledTaskRequest
     * @return UpdateScheduledTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateScheduledTask.ts.html |here} to see how to use UpdateScheduledTask API.
     */
    updateScheduledTask(updateScheduledTaskRequest: requests.UpdateScheduledTaskRequest): Promise<responses.UpdateScheduledTaskResponse>;
    /**
     * This API updates the archiving configuration
     *
     * @param UpdateStorageRequest
     * @return UpdateStorageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpdateStorage.ts.html |here} to see how to use UpdateStorage API.
     */
    updateStorage(updateStorageRequest: requests.UpdateStorageRequest): Promise<responses.UpdateStorageResponse>;
    /**
     * Accepts log data for processing by Logging Analytics.
     *
     * @param UploadLogFileRequest
     * @return UploadLogFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UploadLogFile.ts.html |here} to see how to use UploadLogFile API.
     */
    uploadLogFile(uploadLogFileRequest: requests.UploadLogFileRequest): Promise<responses.UploadLogFileResponse>;
    /**
     * create or update associations for a source
     * @param UpsertAssociationsRequest
     * @return UpsertAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpsertAssociations.ts.html |here} to see how to use UpsertAssociations API.
     */
    upsertAssociations(upsertAssociationsRequest: requests.UpsertAssociationsRequest): Promise<responses.UpsertAssociationsResponse>;
    /**
     * Defines or update a field.
     * @param UpsertFieldRequest
     * @return UpsertFieldResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpsertField.ts.html |here} to see how to use UpsertField API.
     */
    upsertField(upsertFieldRequest: requests.UpsertFieldRequest): Promise<responses.UpsertFieldResponse>;
    /**
     * Define or update a label.
     * @param UpsertLabelRequest
     * @return UpsertLabelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpsertLabel.ts.html |here} to see how to use UpsertLabel API.
     */
    upsertLabel(upsertLabelRequest: requests.UpsertLabelRequest): Promise<responses.UpsertLabelResponse>;
    /**
     * Define or update parser
     * @param UpsertParserRequest
     * @return UpsertParserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpsertParser.ts.html |here} to see how to use UpsertParser API.
     */
    upsertParser(upsertParserRequest: requests.UpsertParserRequest): Promise<responses.UpsertParserResponse>;
    /**
     * Define or update a source
     * @param UpsertSourceRequest
     * @return UpsertSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/UpsertSource.ts.html |here} to see how to use UpsertSource API.
     */
    upsertSource(upsertSourceRequest: requests.UpsertSourceRequest): Promise<responses.UpsertSourceResponse>;
    /**
     * association parameter validation
     * @param ValidateAssociationParametersRequest
     * @return ValidateAssociationParametersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ValidateAssociationParameters.ts.html |here} to see how to use ValidateAssociationParameters API.
     */
    validateAssociationParameters(validateAssociationParametersRequest: requests.ValidateAssociationParametersRequest): Promise<responses.ValidateAssociationParametersResponse>;
    /**
     * Validates a log file to check whether it is eligible to be uploaded or not.
     * @param ValidateFileRequest
     * @return ValidateFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ValidateFile.ts.html |here} to see how to use ValidateFile API.
     */
    validateFile(validateFileRequest: requests.ValidateFileRequest): Promise<responses.ValidateFileResponse>;
    /**
     * Pre-define or update a source
     * @param ValidateSourceRequest
     * @return ValidateSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ValidateSource.ts.html |here} to see how to use ValidateSource API.
     */
    validateSource(validateSourceRequest: requests.ValidateSourceRequest): Promise<responses.ValidateSourceResponse>;
    /**
     * test extended fields
     * @param ValidateSourceExtendedFieldDetailsRequest
     * @return ValidateSourceExtendedFieldDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ValidateSourceExtendedFieldDetails.ts.html |here} to see how to use ValidateSourceExtendedFieldDetails API.
     */
    validateSourceExtendedFieldDetails(validateSourceExtendedFieldDetailsRequest: requests.ValidateSourceExtendedFieldDetailsRequest): Promise<responses.ValidateSourceExtendedFieldDetailsResponse>;
    /**
     * Validates the source mapping for a given file and provides match status and the parsed representation of log data.
     * @param ValidateSourceMappingRequest
     * @return ValidateSourceMappingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/loganalytics/ValidateSourceMapping.ts.html |here} to see how to use ValidateSourceMapping API.
     */
    validateSourceMapping(validateSourceMappingRequest: requests.ValidateSourceMappingRequest): Promise<responses.ValidateSourceMappingResponse>;
}
