/**
 * Management Agent API
 * API for Management Agent Cloud Service
 * OpenAPI spec version: 20200202
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { ManagementAgentWaiter } from "./managementagent-waiter";
export declare enum ManagementAgentApiKeys {
}
export declare class ManagementAgentClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ManagementAgentWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ManagementAgentWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ManagementAgentWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ManagementAgentWaiter;
    /**
     * User creates a new install key as part of this API.
     *
     * @param CreateManagementAgentInstallKeyRequest
     * @return CreateManagementAgentInstallKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/CreateManagementAgentInstallKey.ts.html |here} to see how to use CreateManagementAgentInstallKey API.
     */
    createManagementAgentInstallKey(createManagementAgentInstallKeyRequest: requests.CreateManagementAgentInstallKeyRequest): Promise<responses.CreateManagementAgentInstallKeyResponse>;
    /**
     * Deletes a Management Agent resource by identifier
     * @param DeleteManagementAgentRequest
     * @return DeleteManagementAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/DeleteManagementAgent.ts.html |here} to see how to use DeleteManagementAgent API.
     */
    deleteManagementAgent(deleteManagementAgentRequest: requests.DeleteManagementAgentRequest): Promise<responses.DeleteManagementAgentResponse>;
    /**
     * Deletes a Management Agent install Key resource by identifier
     * @param DeleteManagementAgentInstallKeyRequest
     * @return DeleteManagementAgentInstallKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/DeleteManagementAgentInstallKey.ts.html |here} to see how to use DeleteManagementAgentInstallKey API.
     */
    deleteManagementAgentInstallKey(deleteManagementAgentInstallKeyRequest: requests.DeleteManagementAgentInstallKeyRequest): Promise<responses.DeleteManagementAgentInstallKeyResponse>;
    /**
     * Cancel the work request with the given ID.
     * @param DeleteWorkRequestRequest
     * @return DeleteWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/DeleteWorkRequest.ts.html |here} to see how to use DeleteWorkRequest API.
     */
    deleteWorkRequest(deleteWorkRequestRequest: requests.DeleteWorkRequestRequest): Promise<responses.DeleteWorkRequestResponse>;
    /**
     * Deploys Plugins to a given list of agentIds.
     *
     * @param DeployPluginsRequest
     * @return DeployPluginsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/DeployPlugins.ts.html |here} to see how to use DeployPlugins API.
     */
    deployPlugins(deployPluginsRequest: requests.DeployPluginsRequest): Promise<responses.DeployPluginsResponse>;
    /**
     * Gets complete details of the inventory of a given agent id
     * @param GetManagementAgentRequest
     * @return GetManagementAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/GetManagementAgent.ts.html |here} to see how to use GetManagementAgent API.
     */
    getManagementAgent(getManagementAgentRequest: requests.GetManagementAgentRequest): Promise<responses.GetManagementAgentResponse>;
    /**
     * Gets complete details of the Agent install Key for a given key id
     * @param GetManagementAgentInstallKeyRequest
     * @return GetManagementAgentInstallKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/GetManagementAgentInstallKey.ts.html |here} to see how to use GetManagementAgentInstallKey API.
     */
    getManagementAgentInstallKey(getManagementAgentInstallKeyRequest: requests.GetManagementAgentInstallKeyRequest): Promise<responses.GetManagementAgentInstallKeyResponse>;
    /**
     * Returns a file with Management Agent install Key in it
     *
     * @param GetManagementAgentInstallKeyContentRequest
     * @return GetManagementAgentInstallKeyContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/GetManagementAgentInstallKeyContent.ts.html |here} to see how to use GetManagementAgentInstallKeyContent API.
     */
    getManagementAgentInstallKeyContent(getManagementAgentInstallKeyContentRequest: requests.GetManagementAgentInstallKeyContentRequest): Promise<responses.GetManagementAgentInstallKeyContentResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Lists the availability history records of Management Agent
     * @param ListAvailabilityHistoriesRequest
     * @return ListAvailabilityHistoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListAvailabilityHistories.ts.html |here} to see how to use ListAvailabilityHistories API.
     */
    listAvailabilityHistories(listAvailabilityHistoriesRequest: requests.ListAvailabilityHistoriesRequest): Promise<responses.ListAvailabilityHistoriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AvailabilityHistorySummary objects
     * contained in responses from the listAvailabilityHistories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAvailabilityHistories(request: requests.ListAvailabilityHistoriesRequest): AsyncIterableIterator<models.AvailabilityHistorySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAvailabilityHistories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAvailabilityHistoriesResponses(request: requests.ListAvailabilityHistoriesRequest): AsyncIterableIterator<responses.ListAvailabilityHistoriesResponse>;
    /**
     * Get supported agent image information
     *
     * @param ListManagementAgentImagesRequest
     * @return ListManagementAgentImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListManagementAgentImages.ts.html |here} to see how to use ListManagementAgentImages API.
     */
    listManagementAgentImages(listManagementAgentImagesRequest: requests.ListManagementAgentImagesRequest): Promise<responses.ListManagementAgentImagesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ManagementAgentImageSummary objects
     * contained in responses from the listManagementAgentImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentImages(request: requests.ListManagementAgentImagesRequest): AsyncIterableIterator<models.ManagementAgentImageSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listManagementAgentImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentImagesResponses(request: requests.ListManagementAgentImagesRequest): AsyncIterableIterator<responses.ListManagementAgentImagesResponse>;
    /**
     * Returns a list of Management Agent installed Keys.
     *
     * @param ListManagementAgentInstallKeysRequest
     * @return ListManagementAgentInstallKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListManagementAgentInstallKeys.ts.html |here} to see how to use ListManagementAgentInstallKeys API.
     */
    listManagementAgentInstallKeys(listManagementAgentInstallKeysRequest: requests.ListManagementAgentInstallKeysRequest): Promise<responses.ListManagementAgentInstallKeysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ManagementAgentInstallKeySummary objects
     * contained in responses from the listManagementAgentInstallKeys operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentInstallKeys(request: requests.ListManagementAgentInstallKeysRequest): AsyncIterableIterator<models.ManagementAgentInstallKeySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listManagementAgentInstallKeys operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentInstallKeysResponses(request: requests.ListManagementAgentInstallKeysRequest): AsyncIterableIterator<responses.ListManagementAgentInstallKeysResponse>;
    /**
     * Returns a list of managementAgentPlugins.
     *
     * @param ListManagementAgentPluginsRequest
     * @return ListManagementAgentPluginsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListManagementAgentPlugins.ts.html |here} to see how to use ListManagementAgentPlugins API.
     */
    listManagementAgentPlugins(listManagementAgentPluginsRequest: requests.ListManagementAgentPluginsRequest): Promise<responses.ListManagementAgentPluginsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ManagementAgentPluginSummary objects
     * contained in responses from the listManagementAgentPlugins operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentPlugins(request: requests.ListManagementAgentPluginsRequest): AsyncIterableIterator<models.ManagementAgentPluginSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listManagementAgentPlugins operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentPluginsResponses(request: requests.ListManagementAgentPluginsRequest): AsyncIterableIterator<responses.ListManagementAgentPluginsResponse>;
    /**
     * Returns a list of Management Agent.
     *
     * @param ListManagementAgentsRequest
     * @return ListManagementAgentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListManagementAgents.ts.html |here} to see how to use ListManagementAgents API.
     */
    listManagementAgents(listManagementAgentsRequest: requests.ListManagementAgentsRequest): Promise<responses.ListManagementAgentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ManagementAgentSummary objects
     * contained in responses from the listManagementAgents operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgents(request: requests.ListManagementAgentsRequest): AsyncIterableIterator<models.ManagementAgentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listManagementAgents operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllManagementAgentsResponses(request: requests.ListManagementAgentsRequest): AsyncIterableIterator<responses.ListManagementAgentsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * API to update the console managed properties of the Management Agent.
     *
     * @param UpdateManagementAgentRequest
     * @return UpdateManagementAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/UpdateManagementAgent.ts.html |here} to see how to use UpdateManagementAgent API.
     */
    updateManagementAgent(updateManagementAgentRequest: requests.UpdateManagementAgentRequest): Promise<responses.UpdateManagementAgentResponse>;
    /**
     * API to update the modifiable properties of the Management Agent install key.
     *
     * @param UpdateManagementAgentInstallKeyRequest
     * @return UpdateManagementAgentInstallKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementagent/UpdateManagementAgentInstallKey.ts.html |here} to see how to use UpdateManagementAgentInstallKey API.
     */
    updateManagementAgentInstallKey(updateManagementAgentInstallKeyRequest: requests.UpdateManagementAgentInstallKeyRequest): Promise<responses.UpdateManagementAgentInstallKeyResponse>;
}
