/**
 * ManagementDashboard API
 * API for the Management Dashboard micro-service. Use this API for dashboard and saved search metadata preservation and to perform  tasks such as creating a dashboard, creating a saved search, and obtaining a list of dashboards and saved searches in a compartment.
    

 * OpenAPI spec version: 20200901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
export declare enum DashxApisApiKeys {
}
export declare class DashxApisClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Moves the dashboard from the existing compartment to a new compartment.
     *
     * @param ChangeManagementDashboardsCompartmentRequest
     * @return ChangeManagementDashboardsCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ChangeManagementDashboardsCompartment.ts.html |here} to see how to use ChangeManagementDashboardsCompartment API.
     */
    changeManagementDashboardsCompartment(changeManagementDashboardsCompartmentRequest: requests.ChangeManagementDashboardsCompartmentRequest): Promise<responses.ChangeManagementDashboardsCompartmentResponse>;
    /**
     * Moves the saved search from the existing compartment to a new compartment.
     *
     * @param ChangeManagementSavedSearchesCompartmentRequest
     * @return ChangeManagementSavedSearchesCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ChangeManagementSavedSearchesCompartment.ts.html |here} to see how to use ChangeManagementSavedSearchesCompartment API.
     */
    changeManagementSavedSearchesCompartment(changeManagementSavedSearchesCompartmentRequest: requests.ChangeManagementSavedSearchesCompartmentRequest): Promise<responses.ChangeManagementSavedSearchesCompartmentResponse>;
    /**
     * Creates a new dashboard.  Limit for number of saved searches in a dashboard is 20.
     *
     * @param CreateManagementDashboardRequest
     * @return CreateManagementDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/CreateManagementDashboard.ts.html |here} to see how to use CreateManagementDashboard API.
     */
    createManagementDashboard(createManagementDashboardRequest: requests.CreateManagementDashboardRequest): Promise<responses.CreateManagementDashboardResponse>;
    /**
     * Creates a new saved search.
     *
     * @param CreateManagementSavedSearchRequest
     * @return CreateManagementSavedSearchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/CreateManagementSavedSearch.ts.html |here} to see how to use CreateManagementSavedSearch API.
     */
    createManagementSavedSearch(createManagementSavedSearchRequest: requests.CreateManagementSavedSearchRequest): Promise<responses.CreateManagementSavedSearchResponse>;
    /**
     * Deletes a Dashboard by ID.
     * @param DeleteManagementDashboardRequest
     * @return DeleteManagementDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/DeleteManagementDashboard.ts.html |here} to see how to use DeleteManagementDashboard API.
     */
    deleteManagementDashboard(deleteManagementDashboardRequest: requests.DeleteManagementDashboardRequest): Promise<responses.DeleteManagementDashboardResponse>;
    /**
     * Deletes a saved search by ID.
     * @param DeleteManagementSavedSearchRequest
     * @return DeleteManagementSavedSearchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/DeleteManagementSavedSearch.ts.html |here} to see how to use DeleteManagementSavedSearch API.
     */
    deleteManagementSavedSearch(deleteManagementSavedSearchRequest: requests.DeleteManagementSavedSearchRequest): Promise<responses.DeleteManagementSavedSearchResponse>;
    /**
     * Exports an array of dashboards and their saved searches.
     * @param ExportDashboardRequest
     * @return ExportDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ExportDashboard.ts.html |here} to see how to use ExportDashboard API.
     */
    exportDashboard(exportDashboardRequest: requests.ExportDashboardRequest): Promise<responses.ExportDashboardResponse>;
    /**
     * Gets a dashboard and its saved searches by ID.  Deleted or unauthorized saved searches are marked by tile's state property.
     * @param GetManagementDashboardRequest
     * @return GetManagementDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/GetManagementDashboard.ts.html |here} to see how to use GetManagementDashboard API.
     */
    getManagementDashboard(getManagementDashboardRequest: requests.GetManagementDashboardRequest): Promise<responses.GetManagementDashboardResponse>;
    /**
     * Gets a saved search by ID.
     * @param GetManagementSavedSearchRequest
     * @return GetManagementSavedSearchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/GetManagementSavedSearch.ts.html |here} to see how to use GetManagementSavedSearch API.
     */
    getManagementSavedSearch(getManagementSavedSearchRequest: requests.GetManagementSavedSearchRequest): Promise<responses.GetManagementSavedSearchResponse>;
    /**
     * Imports an array of dashboards and their saved searches.
     *
     * @param ImportDashboardRequest
     * @return ImportDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ImportDashboard.ts.html |here} to see how to use ImportDashboard API.
     */
    importDashboard(importDashboardRequest: requests.ImportDashboardRequest): Promise<responses.ImportDashboardResponse>;
    /**
     * Gets the list of dashboards and their saved searches in a compartment with pagination.  Returned properties are the summary.
     * @param ListManagementDashboardsRequest
     * @return ListManagementDashboardsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ListManagementDashboards.ts.html |here} to see how to use ListManagementDashboards API.
     */
    listManagementDashboards(listManagementDashboardsRequest: requests.ListManagementDashboardsRequest): Promise<responses.ListManagementDashboardsResponse>;
    /**
     * Gets the list of saved searches in a compartment with pagination.  Returned properties are the summary.
     * @param ListManagementSavedSearchesRequest
     * @return ListManagementSavedSearchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/ListManagementSavedSearches.ts.html |here} to see how to use ListManagementSavedSearches API.
     */
    listManagementSavedSearches(listManagementSavedSearchesRequest: requests.ListManagementSavedSearchesRequest): Promise<responses.ListManagementSavedSearchesResponse>;
    /**
     * Updates an existing dashboard identified by ID path parameter.  CompartmentId can be modified only by the changeCompartment API. Limit for number of saved searches in a dashboard is 20.
     *
     * @param UpdateManagementDashboardRequest
     * @return UpdateManagementDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/UpdateManagementDashboard.ts.html |here} to see how to use UpdateManagementDashboard API.
     */
    updateManagementDashboard(updateManagementDashboardRequest: requests.UpdateManagementDashboardRequest): Promise<responses.UpdateManagementDashboardResponse>;
    /**
     * Updates an existing saved search identified by ID path parameter.  CompartmentId can be modified only by the changeCompartment API.
     *
     * @param UpdateManagementSavedSearchRequest
     * @return UpdateManagementSavedSearchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/managementdashboard/UpdateManagementSavedSearch.ts.html |here} to see how to use UpdateManagementSavedSearch API.
     */
    updateManagementSavedSearch(updateManagementSavedSearchRequest: requests.UpdateManagementSavedSearchRequest): Promise<responses.UpdateManagementSavedSearchResponse>;
}
