/**
 * Marketplace Service API
 * Manage applications in Oracle Cloud Infrastructure Marketplace.
 * OpenAPI spec version: 20181001
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
export declare enum MarketplaceApiKeys {
}
export declare class MarketplaceClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Accepts a terms of use agreement for a specific package version of a listing. You must accept all
     * terms of use for a package before you can deploy the package.
     *
     * @param CreateAcceptedAgreementRequest
     * @return CreateAcceptedAgreementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/CreateAcceptedAgreement.ts.html |here} to see how to use CreateAcceptedAgreement API.
     */
    createAcceptedAgreement(createAcceptedAgreementRequest: requests.CreateAcceptedAgreementRequest): Promise<responses.CreateAcceptedAgreementResponse>;
    /**
     * Removes a previously accepted terms of use agreement from the list of agreements that Marketplace checks
     * before initiating a deployment. Listings in the Marketplace that require acceptance of the specified terms
     * of use can no longer be deployed, but existing deployments aren't affected.
     *
     * @param DeleteAcceptedAgreementRequest
     * @return DeleteAcceptedAgreementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/DeleteAcceptedAgreement.ts.html |here} to see how to use DeleteAcceptedAgreement API.
     */
    deleteAcceptedAgreement(deleteAcceptedAgreementRequest: requests.DeleteAcceptedAgreementRequest): Promise<responses.DeleteAcceptedAgreementResponse>;
    /**
     * Gets the details of a specific, previously accepted terms of use agreement.
     *
     * @param GetAcceptedAgreementRequest
     * @return GetAcceptedAgreementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/GetAcceptedAgreement.ts.html |here} to see how to use GetAcceptedAgreement API.
     */
    getAcceptedAgreement(getAcceptedAgreementRequest: requests.GetAcceptedAgreementRequest): Promise<responses.GetAcceptedAgreementResponse>;
    /**
     * Returns a terms of use agreement for a package with a time-based signature that can be used to
     * accept the agreement.
     *
     * @param GetAgreementRequest
     * @return GetAgreementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/GetAgreement.ts.html |here} to see how to use GetAgreement API.
     */
    getAgreement(getAgreementRequest: requests.GetAgreementRequest): Promise<responses.GetAgreementResponse>;
    /**
       * Gets detailed information about a listing, including the listing's name, version, description, and
  * resources.
  * <p>
  If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
  * you launch the instance, you also need to provide the image ID of the listing resource version that you want.
  * <p>
  Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
  * listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
  * The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
  * its signature, is returned in the response. With the signature for the terms of use agreement for the desired
  * listing resource version, create a subscription by issuing a
  * [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.
  * <p>
  To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
  * Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.
  *
       * @param GetListingRequest
       * @return GetListingResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/GetListing.ts.html |here} to see how to use GetListing API.
       */
    getListing(getListingRequest: requests.GetListingRequest): Promise<responses.GetListingResponse>;
    /**
       * Get the details of the specified version of a package, including information needed to launch the package.
  * <p>
  If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
  * you launch the instance, you also need to provide the image ID of the listing resource version that you want.
  * <p>
  Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
  * listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
  * The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
  * its signature, is returned in the response. With the signature for the terms of use agreement for the desired
  * listing resource version, create a subscription by issuing a
  * [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.
  * <p>
  To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
  * Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.
  *
       * @param GetPackageRequest
       * @return GetPackageResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/GetPackage.ts.html |here} to see how to use GetPackage API.
       */
    getPackage(getPackageRequest: requests.GetPackageRequest): Promise<responses.GetPackageResponse>;
    /**
     * Lists the terms of use agreements that have been accepted in the specified compartment.
     * You can filter results by specifying query parameters.
     *
     * @param ListAcceptedAgreementsRequest
     * @return ListAcceptedAgreementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListAcceptedAgreements.ts.html |here} to see how to use ListAcceptedAgreements API.
     */
    listAcceptedAgreements(listAcceptedAgreementsRequest: requests.ListAcceptedAgreementsRequest): Promise<responses.ListAcceptedAgreementsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AcceptedAgreementSummary objects
     * contained in responses from the listAcceptedAgreements operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAcceptedAgreements(request: requests.ListAcceptedAgreementsRequest): AsyncIterableIterator<models.AcceptedAgreementSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAcceptedAgreements operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAcceptedAgreementsResponses(request: requests.ListAcceptedAgreementsRequest): AsyncIterableIterator<responses.ListAcceptedAgreementsResponse>;
    /**
     * Returns the terms of use agreements that must be accepted before you can deploy the specified version of a package.
     *
     * @param ListAgreementsRequest
     * @return ListAgreementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListAgreements.ts.html |here} to see how to use ListAgreements API.
     */
    listAgreements(listAgreementsRequest: requests.ListAgreementsRequest): Promise<responses.ListAgreementsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AgreementSummary objects
     * contained in responses from the listAgreements operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAgreements(request: requests.ListAgreementsRequest): AsyncIterableIterator<models.AgreementSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAgreements operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAgreementsResponses(request: requests.ListAgreementsRequest): AsyncIterableIterator<responses.ListAgreementsResponse>;
    /**
     * Gets the list of all the categories for listings published to Oracle Cloud Infrastructure Marketplace. Categories apply
     * to the software product provided by the listing.
     *
     * @param ListCategoriesRequest
     * @return ListCategoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListCategories.ts.html |here} to see how to use ListCategories API.
     */
    listCategories(listCategoriesRequest: requests.ListCategoriesRequest): Promise<responses.ListCategoriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CategorySummary objects
     * contained in responses from the listCategories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCategories(request: requests.ListCategoriesRequest): AsyncIterableIterator<models.CategorySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCategories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCategoriesResponses(request: requests.ListCategoriesRequest): AsyncIterableIterator<responses.ListCategoriesResponse>;
    /**
       * Gets a list of listings from Oracle Cloud Infrastructure Marketplace by searching keywords and
  * filtering according to listing attributes.
  * <p>
  If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
  * you launch the instance, you also need to provide the image ID of the listing resource version that you want.
  * <p>
  Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
  * listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
  * The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
  * its signature, is returned in the response. With the signature for the terms of use agreement for the desired
  * listing resource version, create a subscription by issuing a
  * [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.
  * <p>
  To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
  * Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.
  *
       * @param ListListingsRequest
       * @return ListListingsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListListings.ts.html |here} to see how to use ListListings API.
       */
    listListings(listListingsRequest: requests.ListListingsRequest): Promise<responses.ListListingsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ListingSummary objects
     * contained in responses from the listListings operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllListings(request: requests.ListListingsRequest): AsyncIterableIterator<models.ListingSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listListings operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllListingsResponses(request: requests.ListListingsRequest): AsyncIterableIterator<responses.ListListingsResponse>;
    /**
       * Gets the list of packages for a listing.
  * <p>
  If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
  * you launch the instance, you also need to provide the image ID of the listing resource version that you want.
  * <p>
  Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
  * listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
  * The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
  * its signature, is returned in the response. With the signature for the terms of use agreement for the desired
  * listing resource version, create a subscription by issuing a
  * [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.
  * <p>
  To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
  * Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.
  *
       * @param ListPackagesRequest
       * @return ListPackagesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListPackages.ts.html |here} to see how to use ListPackages API.
       */
    listPackages(listPackagesRequest: requests.ListPackagesRequest): Promise<responses.ListPackagesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ListingPackageSummary objects
     * contained in responses from the listPackages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPackages(request: requests.ListPackagesRequest): AsyncIterableIterator<models.ListingPackageSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPackages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPackagesResponses(request: requests.ListPackagesRequest): AsyncIterableIterator<responses.ListPackagesResponse>;
    /**
     * Gets the list of all the publishers of listings available in Oracle Cloud Infrastructure Marketplace.
     *
     * @param ListPublishersRequest
     * @return ListPublishersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListPublishers.ts.html |here} to see how to use ListPublishers API.
     */
    listPublishers(listPublishersRequest: requests.ListPublishersRequest): Promise<responses.ListPublishersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PublisherSummary objects
     * contained in responses from the listPublishers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPublishers(request: requests.ListPublishersRequest): AsyncIterableIterator<models.PublisherSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPublishers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPublishersResponses(request: requests.ListPublishersRequest): AsyncIterableIterator<responses.ListPublishersResponse>;
    /**
     * Lists available types of reports for the compartment.
     * @param ListReportTypesRequest
     * @return ListReportTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListReportTypes.ts.html |here} to see how to use ListReportTypes API.
     */
    listReportTypes(listReportTypesRequest: requests.ListReportTypesRequest): Promise<responses.ListReportTypesResponse>;
    /**
     * Lists reports in the compartment that match the specified report type and date.
     * @param ListReportsRequest
     * @return ListReportsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListReports.ts.html |here} to see how to use ListReports API.
     */
    listReports(listReportsRequest: requests.ListReportsRequest): Promise<responses.ListReportsResponse>;
    /**
     * Returns list of all tax implications that current tenant may be liable to once they launch the listing.
     * @param ListTaxesRequest
     * @return ListTaxesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/ListTaxes.ts.html |here} to see how to use ListTaxes API.
     */
    listTaxes(listTaxesRequest: requests.ListTaxesRequest): Promise<responses.ListTaxesResponse>;
    /**
     * Updates the display name or tags associated with a listing's previously accepted terms of use agreement.
     *
     * @param UpdateAcceptedAgreementRequest
     * @return UpdateAcceptedAgreementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/marketplace/UpdateAcceptedAgreement.ts.html |here} to see how to use UpdateAcceptedAgreement API.
     */
    updateAcceptedAgreement(updateAcceptedAgreementRequest: requests.UpdateAcceptedAgreementRequest): Promise<responses.UpdateAcceptedAgreementResponse>;
}
