/**
 * Monitoring API
 * Use the Monitoring API to manage metric queries and alarms for assessing the health, capacity, and performance of your cloud resources.
Endpoints vary by operation. For PostMetric, use the `telemetry-ingestion` endpoints; for all other operations, use the `telemetry` endpoints.
For information about monitoring, see [Monitoring Overview](/iaas/Content/Monitoring/Concepts/monitoringoverview.htm).

 * OpenAPI spec version: 20180401
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { MonitoringWaiter } from "./monitoring-waiter";
export declare enum MonitoringApiKeys {
}
export declare class MonitoringClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": MonitoringWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new MonitoringWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): MonitoringWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): MonitoringWaiter;
    /**
       * Moves an alarm into a different compartment within the same tenancy.
  * <p>
  For information about moving resources between compartments, see [Moving Resources Between Compartments](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  *
       * @param ChangeAlarmCompartmentRequest
       * @return ChangeAlarmCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/ChangeAlarmCompartment.ts.html |here} to see how to use ChangeAlarmCompartment API.
       */
    changeAlarmCompartment(changeAlarmCompartmentRequest: requests.ChangeAlarmCompartmentRequest): Promise<responses.ChangeAlarmCompartmentResponse>;
    /**
       * Creates a new alarm in the specified compartment.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param CreateAlarmRequest
       * @return CreateAlarmResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/CreateAlarm.ts.html |here} to see how to use CreateAlarm API.
       */
    createAlarm(createAlarmRequest: requests.CreateAlarmRequest): Promise<responses.CreateAlarmResponse>;
    /**
       * Deletes the specified alarm.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param DeleteAlarmRequest
       * @return DeleteAlarmResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/DeleteAlarm.ts.html |here} to see how to use DeleteAlarm API.
       */
    deleteAlarm(deleteAlarmRequest: requests.DeleteAlarmRequest): Promise<responses.DeleteAlarmResponse>;
    /**
       * Gets the specified alarm.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param GetAlarmRequest
       * @return GetAlarmResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/GetAlarm.ts.html |here} to see how to use GetAlarm API.
       */
    getAlarm(getAlarmRequest: requests.GetAlarmRequest): Promise<responses.GetAlarmResponse>;
    /**
       * Get the history of the specified alarm.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param GetAlarmHistoryRequest
       * @return GetAlarmHistoryResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/GetAlarmHistory.ts.html |here} to see how to use GetAlarmHistory API.
       */
    getAlarmHistory(getAlarmHistoryRequest: requests.GetAlarmHistoryRequest): Promise<responses.GetAlarmHistoryResponse>;
    /**
       * Lists the alarms for the specified compartment.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param ListAlarmsRequest
       * @return ListAlarmsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/ListAlarms.ts.html |here} to see how to use ListAlarms API.
       */
    listAlarms(listAlarmsRequest: requests.ListAlarmsRequest): Promise<responses.ListAlarmsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AlarmSummary objects
     * contained in responses from the listAlarms operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlarms(request: requests.ListAlarmsRequest): AsyncIterableIterator<models.AlarmSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAlarms operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlarmsResponses(request: requests.ListAlarmsRequest): AsyncIterableIterator<responses.ListAlarmsResponse>;
    /**
       * List the status of each alarm in the specified compartment.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param ListAlarmsStatusRequest
       * @return ListAlarmsStatusResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/ListAlarmsStatus.ts.html |here} to see how to use ListAlarmsStatus API.
       */
    listAlarmsStatus(listAlarmsStatusRequest: requests.ListAlarmsStatusRequest): Promise<responses.ListAlarmsStatusResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AlarmStatusSummary objects
     * contained in responses from the listAlarmsStatus operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlarmsStatus(request: requests.ListAlarmsStatusRequest): AsyncIterableIterator<models.AlarmStatusSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAlarmsStatus operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlarmsStatusResponses(request: requests.ListAlarmsStatusRequest): AsyncIterableIterator<responses.ListAlarmsStatusResponse>;
    /**
       * Returns metric definitions that match the criteria specified in the request. Compartment OCID required.
  * For information about metrics, see [Metrics Overview](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#MetricsOverview).
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  Transactions Per Second (TPS) per-tenancy limit for this operation: 10.
  *
       * @param ListMetricsRequest
       * @return ListMetricsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/ListMetrics.ts.html |here} to see how to use ListMetrics API.
       */
    listMetrics(listMetricsRequest: requests.ListMetricsRequest): Promise<responses.ListMetricsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Metric objects
     * contained in responses from the listMetrics operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMetrics(request: requests.ListMetricsRequest): AsyncIterableIterator<models.Metric>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMetrics operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMetricsResponses(request: requests.ListMetricsRequest): AsyncIterableIterator<responses.ListMetricsResponse>;
    /**
       * Publishes raw metric data points to the Monitoring service.
  * For more information about publishing metrics, see [Publishing Custom Metrics](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Tasks/publishingcustommetrics.htm).
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  Per-call limits information follows.
  * <p>
  * Dimensions per metric group*. Maximum: 20. Minimum: 1.
  * * Unique metric streams*. Maximum: 50.
  * * Transactions Per Second (TPS) per-tenancy limit for this operation: 50.
  * <p>
  *A metric group is the combination of a given metric, metric namespace, and tenancy for the purpose of determining limits.
  * A dimension is a qualifier provided in a metric definition.
  * A metric stream is an individual set of aggregated data for a metric, typically specific to a resource.
  * For more information about metric-related concepts, see [Monitoring Concepts](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#concepts).
  * <p>
  The endpoints for this operation differ from other Monitoring operations. Replace the string `telemetry` with `telemetry-ingestion` in the endpoint, as in the following example:
  * <p>
  https://telemetry-ingestion.eu-frankfurt-1.oraclecloud.com
  *
       * @param PostMetricDataRequest
       * @return PostMetricDataResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/PostMetricData.ts.html |here} to see how to use PostMetricData API.
       */
    postMetricData(postMetricDataRequest: requests.PostMetricDataRequest): Promise<responses.PostMetricDataResponse>;
    /**
       * Removes any existing suppression for the specified alarm.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param RemoveAlarmSuppressionRequest
       * @return RemoveAlarmSuppressionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/RemoveAlarmSuppression.ts.html |here} to see how to use RemoveAlarmSuppression API.
       */
    removeAlarmSuppression(removeAlarmSuppressionRequest: requests.RemoveAlarmSuppressionRequest): Promise<responses.RemoveAlarmSuppressionResponse>;
    /**
       * Returns aggregated data that match the criteria specified in the request. Compartment OCID required.
  * For information on metric queries, see [Building Metric Queries](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Tasks/buildingqueries.htm).
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  Transactions Per Second (TPS) per-tenancy limit for this operation: 10.
  *
       * @param SummarizeMetricsDataRequest
       * @return SummarizeMetricsDataResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/SummarizeMetricsData.ts.html |here} to see how to use SummarizeMetricsData API.
       */
    summarizeMetricsData(summarizeMetricsDataRequest: requests.SummarizeMetricsDataRequest): Promise<responses.SummarizeMetricsDataResponse>;
    /**
       * Updates the specified alarm.
  * For important limits information, see [Limits on Monitoring](https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#Limits).
  * <p>
  This call is subject to a Monitoring limit that applies to the total number of requests across all alarm operations.
  * Monitoring might throttle this call to reject an otherwise valid request when the total rate of alarm operations exceeds 10 requests,
  * or transactions, per second (TPS) for a given tenancy.
  *
       * @param UpdateAlarmRequest
       * @return UpdateAlarmResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/monitoring/UpdateAlarm.ts.html |here} to see how to use UpdateAlarm API.
       */
    updateAlarm(updateAlarmRequest: requests.UpdateAlarmRequest): Promise<responses.UpdateAlarmResponse>;
}
