"use strict";
/**
 * Copyright (c) 2020, 2021 Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getContent = void 0;
const browser_blob_1 = require("./browser-blob");
const node_fs_blob_1 = require("./node-fs-blob");
/*
 * @Summary getBlob method to retreive proper type of blob
 *
 * @param Content
 * @param UploadOptions
 * @returns UploadableBlob Object
 */
function getContent(content, options) {
    const chunkSize = options.allowedMemoryUsage / options.maxConcurrentUploads;
    if (content.blob)
        return new browser_blob_1.BrowserBlob(content.blob, chunkSize);
    else if (content.filePath)
        return new node_fs_blob_1.NodeFSBlob(content.filePath, chunkSize);
    else
        throw Error("Unidentified Blob type Found");
}
exports.getContent = getContent;
//# sourceMappingURL=blob-factory.js.map