/**
 * Cloud Advisor API
 * APIs for managing Cloud Advisor. Cloud Advisor provides recommendations that help you maximize cost savings and improve the security posture of your tenancy.
 * OpenAPI spec version: 20200606
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { OptimizerWaiter } from "./optimizer-waiter";
export declare enum OptimizerApiKeys {
}
export declare class OptimizerClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OptimizerWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OptimizerWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OptimizerWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OptimizerWaiter;
    /**
     * Applies the specified recommendations to the resources.
     *
     * @param BulkApplyRecommendationsRequest
     * @return BulkApplyRecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/BulkApplyRecommendations.ts.html |here} to see how to use BulkApplyRecommendations API.
     */
    bulkApplyRecommendations(bulkApplyRecommendationsRequest: requests.BulkApplyRecommendationsRequest): Promise<responses.BulkApplyRecommendationsResponse>;
    /**
     * Creates a new profile.
     *
     * @param CreateProfileRequest
     * @return CreateProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/CreateProfile.ts.html |here} to see how to use CreateProfile API.
     */
    createProfile(createProfileRequest: requests.CreateProfileRequest): Promise<responses.CreateProfileResponse>;
    /**
     * Deletes the specified profile. Uses the profile's OCID to determine which profile to delete.
     *
     * @param DeleteProfileRequest
     * @return DeleteProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/DeleteProfile.ts.html |here} to see how to use DeleteProfile API.
     */
    deleteProfile(deleteProfileRequest: requests.DeleteProfileRequest): Promise<responses.DeleteProfileResponse>;
    /**
     * Gets the category that corresponds to the specified OCID.
     *
     * @param GetCategoryRequest
     * @return GetCategoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetCategory.ts.html |here} to see how to use GetCategory API.
     */
    getCategory(getCategoryRequest: requests.GetCategoryRequest): Promise<responses.GetCategoryResponse>;
    /**
     * Gets the Cloud Advisor enrollment status.
     *
     * @param GetEnrollmentStatusRequest
     * @return GetEnrollmentStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetEnrollmentStatus.ts.html |here} to see how to use GetEnrollmentStatus API.
     */
    getEnrollmentStatus(getEnrollmentStatusRequest: requests.GetEnrollmentStatusRequest): Promise<responses.GetEnrollmentStatusResponse>;
    /**
     * Gets the specified profile's information. Uses the profile's OCID to determine which profile to retrieve.
     *
     * @param GetProfileRequest
     * @return GetProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetProfile.ts.html |here} to see how to use GetProfile API.
     */
    getProfile(getProfileRequest: requests.GetProfileRequest): Promise<responses.GetProfileResponse>;
    /**
     * Gets the recommendation for the specified OCID.
     *
     * @param GetRecommendationRequest
     * @return GetRecommendationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetRecommendation.ts.html |here} to see how to use GetRecommendation API.
     */
    getRecommendation(getRecommendationRequest: requests.GetRecommendationRequest): Promise<responses.GetRecommendationResponse>;
    /**
     * Gets the resource action that corresponds to the specified OCID.
     *
     * @param GetResourceActionRequest
     * @return GetResourceActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetResourceAction.ts.html |here} to see how to use GetResourceAction API.
     */
    getResourceAction(getResourceActionRequest: requests.GetResourceActionRequest): Promise<responses.GetResourceActionResponse>;
    /**
     * Gets the status of the work request associated with the specified ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Lists the supported Cloud Advisor categories.
     *
     * @param ListCategoriesRequest
     * @return ListCategoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListCategories.ts.html |here} to see how to use ListCategories API.
     */
    listCategories(listCategoriesRequest: requests.ListCategoriesRequest): Promise<responses.ListCategoriesResponse>;
    /**
     * Lists the Cloud Advisor enrollment statuses.
     *
     * @param ListEnrollmentStatusesRequest
     * @return ListEnrollmentStatusesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListEnrollmentStatuses.ts.html |here} to see how to use ListEnrollmentStatuses API.
     */
    listEnrollmentStatuses(listEnrollmentStatusesRequest: requests.ListEnrollmentStatusesRequest): Promise<responses.ListEnrollmentStatusesResponse>;
    /**
     * Lists changes to the recommendations based on user activity.
     * For example, lists when recommendations have been implemented, dismissed, postponed, or reactivated.
     *
     * @param ListHistoriesRequest
     * @return ListHistoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListHistories.ts.html |here} to see how to use ListHistories API.
     */
    listHistories(listHistoriesRequest: requests.ListHistoriesRequest): Promise<responses.ListHistoriesResponse>;
    /**
     * Lists the existing profiles.
     *
     * @param ListProfilesRequest
     * @return ListProfilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListProfiles.ts.html |here} to see how to use ListProfiles API.
     */
    listProfiles(listProfilesRequest: requests.ListProfilesRequest): Promise<responses.ListProfilesResponse>;
    /**
     * Lists the Cloud Advisor recommendations that are currently supported in the specified category.
     *
     * @param ListRecommendationsRequest
     * @return ListRecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListRecommendations.ts.html |here} to see how to use ListRecommendations API.
     */
    listRecommendations(listRecommendationsRequest: requests.ListRecommendationsRequest): Promise<responses.ListRecommendationsResponse>;
    /**
     * Lists the Cloud Advisor resource actions that are supported by the specified recommendation.
     *
     * @param ListResourceActionsRequest
     * @return ListResourceActionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListResourceActions.ts.html |here} to see how to use ListResourceActions API.
     */
    listResourceActions(listResourceActionsRequest: requests.ListResourceActionsRequest): Promise<responses.ListResourceActionsResponse>;
    /**
     * Lists errors associated with the specified work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Lists the logs associated with the specified work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in the tenancy. The tenancy is the root compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the enrollment status of the tenancy.
     *
     * @param UpdateEnrollmentStatusRequest
     * @return UpdateEnrollmentStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/UpdateEnrollmentStatus.ts.html |here} to see how to use UpdateEnrollmentStatus API.
     */
    updateEnrollmentStatus(updateEnrollmentStatusRequest: requests.UpdateEnrollmentStatusRequest): Promise<responses.UpdateEnrollmentStatusResponse>;
    /**
     * Updates the specified profile. Uses the profile's OCID to determine which profile to update.
     *
     * @param UpdateProfileRequest
     * @return UpdateProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/UpdateProfile.ts.html |here} to see how to use UpdateProfile API.
     */
    updateProfile(updateProfileRequest: requests.UpdateProfileRequest): Promise<responses.UpdateProfileResponse>;
    /**
     * Updates the recommendation that corresponds to the specified OCID.
     * Use this operation to implement the following actions:
     * <p>
     * Postpone recommendation
     *   * Dismiss recommendation
     *   * Reactivate recommendation
     *
     * @param UpdateRecommendationRequest
     * @return UpdateRecommendationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/UpdateRecommendation.ts.html |here} to see how to use UpdateRecommendation API.
     */
    updateRecommendation(updateRecommendationRequest: requests.UpdateRecommendationRequest): Promise<responses.UpdateRecommendationResponse>;
    /**
     * Updates the resource action that corresponds to the specified OCID.
     * Use this operation to implement the following actions:
     * <p>
     * Postpone resource action
     *   * Ignore resource action
     *   * Reactivate resource action
     *
     * @param UpdateResourceActionRequest
     * @return UpdateResourceActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/optimizer/UpdateResourceAction.ts.html |here} to see how to use UpdateResourceAction API.
     */
    updateResourceAction(updateResourceActionRequest: requests.UpdateResourceActionRequest): Promise<responses.UpdateResourceActionResponse>;
}
