/**
 * Secrets Management API
 * API for managing secrets.
 * OpenAPI spec version: 20180608
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { VaultsWaiter } from "./vaults-waiter";
export declare enum VaultsApiKeys {
}
export declare class VaultsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": VaultsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new VaultsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): VaultsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): VaultsWaiter;
    /**
     * Cancels the pending deletion of the specified secret. Canceling
     * a scheduled deletion restores the secret's lifecycle state to what
     * it was before you scheduled the secret for deletion.
     *
     * @param CancelSecretDeletionRequest
     * @return CancelSecretDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/CancelSecretDeletion.ts.html |here} to see how to use CancelSecretDeletion API.
     */
    cancelSecretDeletion(cancelSecretDeletionRequest: requests.CancelSecretDeletionRequest): Promise<responses.CancelSecretDeletionResponse>;
    /**
     * Cancels the scheduled deletion of a secret version.
     * @param CancelSecretVersionDeletionRequest
     * @return CancelSecretVersionDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/CancelSecretVersionDeletion.ts.html |here} to see how to use CancelSecretVersionDeletion API.
     */
    cancelSecretVersionDeletion(cancelSecretVersionDeletionRequest: requests.CancelSecretVersionDeletionRequest): Promise<responses.CancelSecretVersionDeletionResponse>;
    /**
       * Moves a secret into a different compartment within the same tenancy. For information about
  * moving resources between compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When provided, if-match is checked against the ETag values of the secret.
  *
       * @param ChangeSecretCompartmentRequest
       * @return ChangeSecretCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/ChangeSecretCompartment.ts.html |here} to see how to use ChangeSecretCompartment API.
       */
    changeSecretCompartment(changeSecretCompartmentRequest: requests.ChangeSecretCompartmentRequest): Promise<responses.ChangeSecretCompartmentResponse>;
    /**
       * Creates a new secret according to the details of the request.
  * <p>
  This operation is not supported by the Oracle Cloud Infrastructure Terraform Provider.
  *
       * @param CreateSecretRequest
       * @return CreateSecretResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/CreateSecret.ts.html |here} to see how to use CreateSecret API.
       */
    createSecret(createSecretRequest: requests.CreateSecretRequest): Promise<responses.CreateSecretResponse>;
    /**
     * Gets information about the specified secret.
     * @param GetSecretRequest
     * @return GetSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/GetSecret.ts.html |here} to see how to use GetSecret API.
     */
    getSecret(getSecretRequest: requests.GetSecretRequest): Promise<responses.GetSecretResponse>;
    /**
     * Gets information about the specified version of a secret.
     *
     * @param GetSecretVersionRequest
     * @return GetSecretVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/GetSecretVersion.ts.html |here} to see how to use GetSecretVersion API.
     */
    getSecretVersion(getSecretVersionRequest: requests.GetSecretVersionRequest): Promise<responses.GetSecretVersionResponse>;
    /**
     * Lists all secret versions for the specified secret.
     * @param ListSecretVersionsRequest
     * @return ListSecretVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/ListSecretVersions.ts.html |here} to see how to use ListSecretVersions API.
     */
    listSecretVersions(listSecretVersionsRequest: requests.ListSecretVersionsRequest): Promise<responses.ListSecretVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SecretVersionSummary objects
     * contained in responses from the listSecretVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecretVersions(request: requests.ListSecretVersionsRequest): AsyncIterableIterator<models.SecretVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSecretVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecretVersionsResponses(request: requests.ListSecretVersionsRequest): AsyncIterableIterator<responses.ListSecretVersionsResponse>;
    /**
     * Lists all secrets in the specified vault and compartment.
     * @param ListSecretsRequest
     * @return ListSecretsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/ListSecrets.ts.html |here} to see how to use ListSecrets API.
     */
    listSecrets(listSecretsRequest: requests.ListSecretsRequest): Promise<responses.ListSecretsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SecretSummary objects
     * contained in responses from the listSecrets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecrets(request: requests.ListSecretsRequest): AsyncIterableIterator<models.SecretSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSecrets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecretsResponses(request: requests.ListSecretsRequest): AsyncIterableIterator<responses.ListSecretsResponse>;
    /**
     * Schedules the deletion of the specified secret. This sets the lifecycle state of the secret
     * to `PENDING_DELETION` and then deletes it after the specified retention period ends.
     *
     * @param ScheduleSecretDeletionRequest
     * @return ScheduleSecretDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/ScheduleSecretDeletion.ts.html |here} to see how to use ScheduleSecretDeletion API.
     */
    scheduleSecretDeletion(scheduleSecretDeletionRequest: requests.ScheduleSecretDeletionRequest): Promise<responses.ScheduleSecretDeletionResponse>;
    /**
     * Schedules the deletion of the specified secret version. This deletes it after the specified retention period ends. You can only
     * delete a secret version if the secret version rotation state is marked as `DEPRECATED`.
     *
     * @param ScheduleSecretVersionDeletionRequest
     * @return ScheduleSecretVersionDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/ScheduleSecretVersionDeletion.ts.html |here} to see how to use ScheduleSecretVersionDeletion API.
     */
    scheduleSecretVersionDeletion(scheduleSecretVersionDeletionRequest: requests.ScheduleSecretVersionDeletionRequest): Promise<responses.ScheduleSecretVersionDeletionResponse>;
    /**
       * Updates the properties of a secret. Specifically, you can update the version number of the secret to make
  * that version number the current version. You can also update a secret's description, its free-form or defined tags, rules
  * and the secret contents. Updating the secret content automatically creates a new secret version. You cannot, however, update the current secret version number and the secret contents and the rules at the
  * same time. Furthermore, the secret must in an `ACTIVE` lifecycle state to be updated.
  * <p>
  This operation is not supported by the Oracle Cloud Infrastructure Terraform Provider.
  *
       * @param UpdateSecretRequest
       * @return UpdateSecretResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.15.1/vault/UpdateSecret.ts.html |here} to see how to use UpdateSecret API.
       */
    updateSecret(updateSecretRequest: requests.UpdateSecretRequest): Promise<responses.UpdateSecretResponse>;
}
