/**
 * Web Application Acceleration and Security Services API
 * OCI Web Application Acceleration and Security Services
 * OpenAPI spec version: 20181116
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Health checks monitor the status of your origin servers and only route traffic to the origins that pass the health check. If the health check fails, origin is automatically removed from the load balancing.
 * There is roughly one health check per EDGE POP per period. Any checks that pass will be reported as \"healthy\".
 */
export interface HealthCheck {
    /**
     * Enables or disables the health checks.
     */
    "isEnabled"?: boolean;
    /**
     * An HTTP verb (i.e. HEAD, GET, or POST) to use when performing the health check.
     */
    "method"?: HealthCheck.Method;
    /**
     * Path to visit on your origins when performing the health check.
     */
    "path"?: string;
    /**
     * HTTP header fields to include in health check requests, expressed as `\"name\": \"value\"` properties. Because HTTP header field names are case-insensitive, any use of names that are case-insensitive equal to other names will be rejected. If Host is not specified, requests will include a Host header field with value matching the policy's protected domain. If User-Agent is not specified, requests will include a User-Agent header field with value \"waf health checks\".
     * <p>
     **Note:** The only currently-supported header fields are Host and User-Agent.
     */
    "headers"?: {
        [key: string]: string;
    };
    /**
     * The HTTP response codes that signify a healthy state.
     * - **2XX:** Success response code group.
     * - **3XX:** Redirection response code group.
     * - **4XX:** Client errors response code group.
     * - **5XX:** Server errors response code group.
     */
    "expectedResponseCodeGroup"?: Array<HealthCheck.ExpectedResponseCodeGroup>;
    /**
     * Enables or disables additional check for predefined text in addition to response code.
     */
    "isResponseTextCheckEnabled"?: boolean;
    /**
     * Health check will search for the given text in a case-sensitive manner within the response body and will fail if the text is not found.
     */
    "expectedResponseText"?: string;
    /**
     * Time between health checks of an individual origin server, in seconds. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "intervalInSeconds"?: number;
    /**
     * Response timeout represents wait time until request is considered failed, in seconds. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "timeoutInSeconds"?: number;
    /**
     * Number of successful health checks after which the server is marked up. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "healthyThreshold"?: number;
    /**
     * Number of failed health checks after which the server is marked down. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "unhealthyThreshold"?: number;
}
export declare namespace HealthCheck {
    enum Method {
        Get = "GET",
        Head = "HEAD",
        Post = "POST",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ExpectedResponseCodeGroup {
        _2Xx = "2XX",
        _3Xx = "3XX",
        _4Xx = "4XX",
        _5Xx = "5XX",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: HealthCheck): object;
}
